-- MySQL dump 10.13  Distrib 8.0.28, for macos10.15 (x86_64)
--
-- Host: localhost    Database: prha
-- ------------------------------------------------------
-- Server version	8.0.28

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!50503 SET NAMES utf8mb4 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `alembic_version`
--

DROP TABLE IF EXISTS `alembic_version`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `alembic_version` (
  `version_num` varchar(32) NOT NULL,
  PRIMARY KEY (`version_num`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `alembic_version`
--

LOCK TABLES `alembic_version` WRITE;
/*!40000 ALTER TABLE `alembic_version` DISABLE KEYS */;
INSERT INTO `alembic_version` VALUES ('5b467f7af3f6');
/*!40000 ALTER TABLE `alembic_version` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `asset_keys`
--

DROP TABLE IF EXISTS `asset_keys`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `asset_keys` (
  `id` int NOT NULL AUTO_INCREMENT,
  `asset_key` varchar(512) DEFAULT NULL,
  `last_materialization` text,
  `last_run_id` varchar(255) DEFAULT NULL,
  `asset_details` text,
  `wipe_timestamp` timestamp(6) NULL DEFAULT NULL,
  `last_materialization_timestamp` timestamp(6) NULL DEFAULT NULL,
  `tags` text,
  `create_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  PRIMARY KEY (`id`),
  UNIQUE KEY `asset_key` (`asset_key`)
) ENGINE=InnoDB AUTO_INCREMENT=70 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `asset_keys`
--

LOCK TABLES `asset_keys` WRITE;
/*!40000 ALTER TABLE `asset_keys` DISABLE KEYS */;
INSERT INTO `asset_keys` VALUES (49,'[\"log_file\", \"bx_new_run_3\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bx_new_run_3\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bx_new_run_3\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1609955736.963252, \"mtime\": 1609955736.963252, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','3cbf76a0-8586-41df-9a10-961353c26f1f',NULL,NULL,'2022-03-25 04:41:22.027097',NULL,'2022-03-24 14:41:22.105595'),(50,'[\"log_file\", \"bx_new_run_4\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bx_new_run_4\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bx_new_run_4\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1610388763.2417717, \"mtime\": 1610388763.2417717, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85',NULL,NULL,'2022-03-25 04:41:24.957979',NULL,'2022-03-24 14:41:25.032221'),(51,'[\"log_file\", \"bx_new_run\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bx_new_run\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bx_new_run\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1608060793.3515544, \"mtime\": 1608060793.3515544, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','d4cffd6f-2e01-47ef-bb72-90d2a9e84e22',NULL,NULL,'2022-03-25 04:41:27.707949',NULL,'2022-03-24 14:41:27.805714'),(52,'[\"log_file\", \"bx_new_run_2\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bx_new_run_2\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bx_new_run_2\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1608060796.9405777, \"mtime\": 1608060796.9405777, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','f62982b8-3037-468e-a94e-032f68011e77',NULL,NULL,'2022-03-25 04:41:30.160455',NULL,'2022-03-24 14:41:30.256330'),(53,'[\"log_file\", \"foooawoiefj\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"foooawoiefj\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/foooawoiefj\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1645197413.2837281, \"mtime\": 1645197413.2837281, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','66d03d20-ef6b-40eb-92e3-e7c17033831a',NULL,NULL,'2022-03-25 04:41:32.711284',NULL,'2022-03-24 14:41:32.809643'),(54,'[\"log_file\", \"demo.1\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"demo.1\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/demo.1\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1606341124.944769, \"mtime\": 1606341124.944769, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','dc459868-808c-4476-adf7-548b1f42f45c',NULL,NULL,'2022-03-25 04:41:35.258977',NULL,'2022-03-24 14:41:35.355841'),(55,'[\"log_file\", \"boopppp\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"boopppp\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/boopppp\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607487853.6962564, \"mtime\": 1607487853.6962564, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','e641587a-ac48-4a95-8208-81990c416d8d',NULL,NULL,'2022-03-25 04:41:37.929342',NULL,'2022-03-24 14:41:38.026182'),(56,'[\"log_file\", \"blawiejfoj\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"blawiejfoj\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/blawiejfoj\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1647625969.2538514, \"mtime\": 1647625969.2538514, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','69be6d22-e418-4e86-8fd7-6bfaac2a44dd',NULL,NULL,'2022-03-25 04:41:40.457637',NULL,'2022-03-24 14:41:40.536047'),(57,'[\"log_file\", \"b.out\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"b.out\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/b.out\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1605834003.3638573, \"mtime\": 1605834003.363826, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','e737f12e-dadf-4295-9ce1-ec3f43d84238',NULL,NULL,'2022-03-25 04:41:42.911012',NULL,'2022-03-24 14:41:43.006272'),(58,'[\"log_file\", \"show_run_key_3\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"show_run_key_3\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/show_run_key_3\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1606942458.8674397, \"mtime\": 1606942458.8674, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','06c52e01-4d6e-41e1-997c-38207bf5c267',NULL,NULL,'2022-03-25 04:41:45.511591',NULL,'2022-03-24 14:41:45.606975'),(59,'[\"log_file\", \"show_run_key_2\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"show_run_key_2\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/show_run_key_2\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1606840685.1579385, \"mtime\": 1606840685.1579385, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','84b8c995-a9d8-40e7-9887-5188e07fc31c',NULL,NULL,'2022-03-25 04:41:47.934396',NULL,'2022-03-24 14:41:48.027615'),(60,'[\"log_file\", \"a.out\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"a.out\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/a.out\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1605833207.4776378, \"mtime\": 1605833207.4776378, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','184e6db1-23a0-42a7-9bff-8ea1cf922193',NULL,NULL,'2022-03-25 04:41:50.535794',NULL,'2022-03-24 14:41:50.628594'),(61,'[\"log_file\", \"boop\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"boop\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/boop\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607484774.6155019, \"mtime\": 1607484774.6155019, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','30340bb3-53fd-4755-aac9-ca22c4b56c4f',NULL,NULL,'2022-03-25 04:41:53.078701',NULL,'2022-03-24 14:41:53.159303'),(62,'[\"log_file\", \"bxxxxffff\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bxxxxffff\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bxxxxffff\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607996899.666524, \"mtime\": 1607996899.666524, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','16362f52-dd3d-43a5-be74-2bd3d3bca219',NULL,NULL,'2022-03-25 04:41:55.705127',NULL,'2022-03-24 14:41:55.781100'),(63,'[\"log_file\", \"blahfjfjf\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"blahfjfjf\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/blahfjfjf\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1606840555.9826365, \"mtime\": 1606840555.9826365, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','a395a21d-4197-4952-914d-039258b35b4e',NULL,NULL,'2022-03-25 04:41:58.180158',NULL,'2022-03-24 14:41:58.273367'),(64,'[\"log_file\", \"boop3\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"boop3\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/boop3\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607484790.7801318, \"mtime\": 1607484790.7801318, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','2460e183-ee8c-4fa3-a963-c0fca3cf60d6',NULL,NULL,'2022-03-25 04:42:00.587079',NULL,'2022-03-24 14:42:00.682709'),(65,'[\"log_file\", \"booppppppp\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"booppppppp\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/booppppppp\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607487856.5426033, \"mtime\": 1607487856.5426033, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','286d69c1-263f-46ca-bdeb-bdb2cff627d0',NULL,NULL,'2022-03-25 04:42:03.079219',NULL,'2022-03-24 14:42:03.177477'),(66,'[\"log_file\", \"bxxxxf\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bxxxxf\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bxxxxf\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607635587.0286214, \"mtime\": 1607635587.0286214, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','b002ddcb-ddd5-4b57-9911-e4ea234f9b71',NULL,NULL,'2022-03-25 04:42:06.187034',NULL,'2022-03-24 14:42:06.283362'),(67,'[\"log_file\", \"boop2\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"boop2\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/boop2\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607484775.9602463, \"mtime\": 1607484775.9602463, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','64cb1e86-9461-4a54-8f1b-22042d76566f',NULL,NULL,'2022-03-25 04:42:09.030139',NULL,'2022-03-24 14:42:09.111018'),(68,'[\"log_file\", \"show_run_key\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"show_run_key\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/show_run_key\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1606840644.290511, \"mtime\": 1606840644.290511, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','f5ea6efb-0306-4138-af6a-1087b57f10b5',NULL,NULL,'2022-03-25 04:42:11.638116',NULL,'2022-03-24 14:42:11.732594'),(69,'[\"log_file\", \"bxxx\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bxxx\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bxxx\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607635580.3826091, \"mtime\": 1607635580.3826091, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}','9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad',NULL,NULL,'2022-03-25 04:42:14.212559',NULL,'2022-03-24 14:42:14.334308');
/*!40000 ALTER TABLE `asset_keys` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `bulk_actions`
--

DROP TABLE IF EXISTS `bulk_actions`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `bulk_actions` (
  `id` int NOT NULL AUTO_INCREMENT,
  `key` varchar(32) NOT NULL,
  `status` varchar(255) NOT NULL,
  `timestamp` timestamp(6) NOT NULL,
  `body` text,
  PRIMARY KEY (`id`),
  UNIQUE KEY `key` (`key`),
  KEY `idx_bulk_actions_status` (`status`(32)),
  KEY `idx_bulk_actions` (`key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `bulk_actions`
--

LOCK TABLES `bulk_actions` WRITE;
/*!40000 ALTER TABLE `bulk_actions` DISABLE KEYS */;
/*!40000 ALTER TABLE `bulk_actions` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `daemon_heartbeats`
--

DROP TABLE IF EXISTS `daemon_heartbeats`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `daemon_heartbeats` (
  `daemon_type` varchar(255) NOT NULL,
  `daemon_id` varchar(255) DEFAULT NULL,
  `timestamp` timestamp(6) NOT NULL,
  `body` text,
  UNIQUE KEY `daemon_type` (`daemon_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `daemon_heartbeats`
--

LOCK TABLES `daemon_heartbeats` WRITE;
/*!40000 ALTER TABLE `daemon_heartbeats` DISABLE KEYS */;
INSERT INTO `daemon_heartbeats` VALUES ('BACKFILL','f98605a6-8f93-438e-a49e-1d745c0831fc','2022-03-25 04:42:13.637021','{\"__class__\": \"DaemonHeartbeat\", \"daemon_id\": \"f98605a6-8f93-438e-a49e-1d745c0831fc\", \"daemon_type\": \"BACKFILL\", \"errors\": [], \"timestamp\": 1648158133.637021}'),('SCHEDULER','f98605a6-8f93-438e-a49e-1d745c0831fc','2022-03-25 04:42:20.957734','{\"__class__\": \"DaemonHeartbeat\", \"daemon_id\": \"f98605a6-8f93-438e-a49e-1d745c0831fc\", \"daemon_type\": \"SCHEDULER\", \"errors\": [], \"timestamp\": 1648158140.957734}'),('SENSOR','f98605a6-8f93-438e-a49e-1d745c0831fc','2022-03-25 04:41:48.730528','{\"__class__\": \"DaemonHeartbeat\", \"daemon_id\": \"f98605a6-8f93-438e-a49e-1d745c0831fc\", \"daemon_type\": \"SENSOR\", \"errors\": [], \"timestamp\": 1648158108.730528}');
/*!40000 ALTER TABLE `daemon_heartbeats` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `event_logs`
--

DROP TABLE IF EXISTS `event_logs`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `event_logs` (
  `id` int NOT NULL AUTO_INCREMENT,
  `run_id` varchar(255) DEFAULT NULL,
  `event` text NOT NULL,
  `dagster_event_type` text,
  `timestamp` timestamp(6) NULL DEFAULT NULL,
  `step_key` text,
  `asset_key` text,
  `partition` text,
  PRIMARY KEY (`id`),
  KEY `idx_run_id` (`run_id`),
  KEY `idx_asset_key` (`asset_key`(32)),
  KEY `idx_step_key` (`step_key`(32)),
  KEY `idx_asset_partition` (`asset_key`(64),`partition`(64)),
  KEY `idx_event_type` (`dagster_event_type`(64),`id`)
) ENGINE=InnoDB AUTO_INCREMENT=934 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `event_logs`
--

LOCK TABLES `event_logs` WRITE;
/*!40000 ALTER TABLE `event_logs` DISABLE KEYS */;
INSERT INTO `event_logs` VALUES (469,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": null, \"timestamp\": 1648158077.80862, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:17.808620',NULL,NULL,NULL),(470,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": null, \"timestamp\": 1648158078.555878, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:18.555878',NULL,NULL,NULL),(471,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23077\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23077).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": null, \"timestamp\": 1648158080.1069179, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:20.106918',NULL,NULL,NULL),(472,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": null, \"timestamp\": 1648158080.456838, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:20.456838',NULL,NULL,NULL),(473,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23078\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23078).\", \"pid\": null, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": null, \"timestamp\": 1648158080.587381, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:20.587381',NULL,NULL,NULL),(474,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23077, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": null, \"timestamp\": 1648158081.637843, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:21.637843',NULL,NULL,NULL),(475,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23077\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23077)\", \"pid\": 23077, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": null, \"timestamp\": 1648158081.783006, \"user_message\": \"Executing steps in process (pid: 23077)\"}','ENGINE_EVENT','2022-03-25 04:41:21.783006',NULL,NULL,NULL),(476,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23077, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": \"read_file\", \"timestamp\": 1648158081.814362, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:21.814362','read_file',NULL,NULL),(477,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.05ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23077, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": \"read_file\", \"timestamp\": 1648158081.85816, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:21.858160','read_file',NULL,NULL),(478,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_3:1609955736.963252\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23077, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": \"read_file\", \"timestamp\": 1648158081.914558, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:21.914558','read_file',NULL,NULL),(479,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_3:1609955736.963252\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23077, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": \"read_file\", \"timestamp\": 1648158081.9586718, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:21.958672','read_file',NULL,NULL),(480,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": \"read_file\", \"timestamp\": 1648158081.987533, \"user_message\": \"Found file bx_new_run_3\"}',NULL,'2022-03-25 04:41:21.987533','read_file',NULL,NULL),(481,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bx_new_run_3\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bx_new_run_3\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1609955736.963252, \"mtime\": 1609955736.963252, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_3:1609955736.963252\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file bx_new_run_3.\", \"pid\": 23077, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": \"read_file\", \"timestamp\": 1648158082.027097, \"user_message\": \"Materialized value log_file bx_new_run_3.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:22.027097','read_file','[\"log_file\", \"bx_new_run_3\"]',NULL),(482,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_3:1609955736.963252\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23077, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": \"read_file\", \"timestamp\": 1648158082.110098, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:22.110098','read_file',NULL,NULL),(483,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"unreliable_pipeline\\\".\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": null, \"timestamp\": 1648158082.1478631, \"user_message\": \"Started execution of run for \\\"unreliable_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:22.147863',NULL,NULL,NULL),(484,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_3:1609955736.963252\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23077, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": \"read_file\", \"timestamp\": 1648158082.13617, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:22.136170','read_file',NULL,NULL),(485,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 193.4918600000004}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_3:1609955736.963252\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 193ms.\", \"pid\": 23077, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": \"read_file\", \"timestamp\": 1648158082.180741, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 193ms.\"}','STEP_SUCCESS','2022-03-25 04:41:22.180741','read_file',NULL,NULL),(486,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23077\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23077) in 403ms\", \"pid\": 23077, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": null, \"timestamp\": 1648158082.214232, \"user_message\": \"Finished steps in process (pid: 23077) in 403ms\"}','ENGINE_EVENT','2022-03-25 04:41:22.214232',NULL,NULL,NULL),(487,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23077, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": null, \"timestamp\": 1648158082.257382, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:22.257382',NULL,NULL,NULL),(488,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23078\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'unreliable_start\', \'one\', \'two\', \'three\', \'four\', \'five\', \'six\', \'seven\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23078)\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": null, \"timestamp\": 1648158082.283381, \"user_message\": \"Executing steps in process (pid: 23078)\"}','ENGINE_EVENT','2022-03-25 04:41:22.283381',NULL,NULL,NULL),(489,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": null, \"timestamp\": 1648158082.317226, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:22.317226',NULL,NULL,NULL),(490,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.fs_io_manager\", \"name\": \"PickledObjectFilesystemIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.06ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": null, \"timestamp\": 1648158082.3577769, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:22.357777',NULL,NULL,NULL),(491,'3cbf76a0-8586-41df-9a10-961353c26f1f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23077).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"step_key\": null, \"timestamp\": 1648158082.378612, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:22.378612',NULL,NULL,NULL),(492,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"unreliable_start\", \"step_keys\": [\"unreliable_start\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"unreliable_start\", \"step_key\": \"unreliable_start\"}, \"message\": \"Started capturing logs for step: unreliable_start.\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"unreliable_start\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}}, \"step_key\": \"unreliable_start\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"unreliable_start\", \"timestamp\": 1648158082.408159, \"user_message\": \"Started capturing logs for step: unreliable_start.\"}','LOGS_CAPTURED','2022-03-25 04:41:22.408159','unreliable_start',NULL,NULL),(493,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"unreliable_start\", \"step_key\": \"unreliable_start\"}, \"message\": \"Started execution of step \\\"unreliable_start\\\".\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"unreliable_start\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}}, \"step_key\": \"unreliable_start\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"unreliable_start\", \"timestamp\": 1648158082.462083, \"user_message\": \"Started execution of step \\\"unreliable_start\\\".\"}','STEP_START','2022-03-25 04:41:22.462083','unreliable_start',NULL,NULL),(494,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"unreliable_start\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"unreliable_start\", \"step_key\": \"unreliable_start\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"unreliable_start\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}}, \"step_key\": \"unreliable_start\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"unreliable_start\", \"timestamp\": 1648158082.510653, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:22.510653','unreliable_start',NULL,NULL),(495,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"unreliable_start\", \"timestamp\": 1648158082.561596, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/eaa207df-08ba-4834-ae00-d0ca1e8cac71/unreliable_start/result\"}',NULL,'2022-03-25 04:41:22.561596','unreliable_start',NULL,NULL),(496,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"unreliable_start\", \"step_key\": \"unreliable_start\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"unreliable_start\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}}, \"step_key\": \"unreliable_start\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"unreliable_start\", \"timestamp\": 1648158082.608303, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:22.608303','unreliable_start',NULL,NULL),(497,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 127.84165400000003}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"unreliable_start\", \"step_key\": \"unreliable_start\"}, \"message\": \"Finished execution of step \\\"unreliable_start\\\" in 127ms.\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"unreliable_start\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}}, \"step_key\": \"unreliable_start\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"unreliable_start\", \"timestamp\": 1648158082.6369832, \"user_message\": \"Finished execution of step \\\"unreliable_start\\\" in 127ms.\"}','STEP_SUCCESS','2022-03-25 04:41:22.636983','unreliable_start',NULL,NULL),(498,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"one\", \"step_keys\": [\"one\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Started capturing logs for step: one.\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"one\", \"timestamp\": 1648158082.707289, \"user_message\": \"Started capturing logs for step: one.\"}','LOGS_CAPTURED','2022-03-25 04:41:22.707289','one',NULL,NULL),(499,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Started execution of step \\\"one\\\".\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"one\", \"timestamp\": 1648158082.760449, \"user_message\": \"Started execution of step \\\"one\\\".\"}','STEP_START','2022-03-25 04:41:22.760449','one',NULL,NULL),(500,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"one\", \"timestamp\": 1648158082.807264, \"user_message\": \"Loading file from: /Users/prha/dagster/storage/eaa207df-08ba-4834-ae00-d0ca1e8cac71/unreliable_start/result\"}',NULL,'2022-03-25 04:41:22.807264','one',NULL,NULL),(501,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23083\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23083).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": null, \"timestamp\": 1648158082.80959, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:22.809590',NULL,NULL,NULL),(502,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"LoadedInputData\", \"input_name\": \"num\", \"manager_key\": \"io_manager\", \"upstream_output_name\": \"result\", \"upstream_step_key\": \"unreliable_start\"}, \"event_type_value\": \"LOADED_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"unreliable_start\\\"\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"one\", \"timestamp\": 1648158082.8361359, \"user_message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"unreliable_start\\\"\"}','LOADED_INPUT','2022-03-25 04:41:22.836136','one',NULL,NULL),(503,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepInputData\", \"input_name\": \"num\", \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"num\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"one\", \"timestamp\": 1648158082.886039, \"user_message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_INPUT','2022-03-25 04:41:22.886039','one',NULL,NULL),(504,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"one\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"one\", \"timestamp\": 1648158082.928405, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:22.928405','one',NULL,NULL),(505,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"one\", \"timestamp\": 1648158082.958817, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/eaa207df-08ba-4834-ae00-d0ca1e8cac71/one/result\"}',NULL,'2022-03-25 04:41:22.958817','one',NULL,NULL),(506,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"one\", \"timestamp\": 1648158083.008044, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:23.008044','one',NULL,NULL),(507,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 127.38748299999969}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Finished execution of step \\\"one\\\" in 127ms.\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"one\", \"timestamp\": 1648158083.055221, \"user_message\": \"Finished execution of step \\\"one\\\" in 127ms.\"}','STEP_SUCCESS','2022-03-25 04:41:23.055221','one',NULL,NULL),(508,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"two\", \"step_keys\": [\"two\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Started capturing logs for step: two.\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"two\", \"timestamp\": 1648158083.111445, \"user_message\": \"Started capturing logs for step: two.\"}','LOGS_CAPTURED','2022-03-25 04:41:23.111445','two',NULL,NULL),(509,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Started execution of step \\\"two\\\".\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"two\", \"timestamp\": 1648158083.158945, \"user_message\": \"Started execution of step \\\"two\\\".\"}','STEP_START','2022-03-25 04:41:23.158945','two',NULL,NULL),(510,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": null, \"timestamp\": 1648158083.205426, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:23.205426',NULL,NULL,NULL),(511,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"two\", \"timestamp\": 1648158083.207825, \"user_message\": \"Loading file from: /Users/prha/dagster/storage/eaa207df-08ba-4834-ae00-d0ca1e8cac71/one/result\"}',NULL,'2022-03-25 04:41:23.207825','two',NULL,NULL),(512,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"LoadedInputData\", \"input_name\": \"num\", \"manager_key\": \"io_manager\", \"upstream_output_name\": \"result\", \"upstream_step_key\": \"one\"}, \"event_type_value\": \"LOADED_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"one\\\"\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"two\", \"timestamp\": 1648158083.2359302, \"user_message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"one\\\"\"}','LOADED_INPUT','2022-03-25 04:41:23.235930','two',NULL,NULL),(513,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepInputData\", \"input_name\": \"num\", \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"num\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"two\", \"timestamp\": 1648158083.279379, \"user_message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_INPUT','2022-03-25 04:41:23.279379','two',NULL,NULL),(514,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"two\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"two\", \"timestamp\": 1648158083.3108869, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:23.310887','two',NULL,NULL),(515,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"two\", \"timestamp\": 1648158083.368777, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/eaa207df-08ba-4834-ae00-d0ca1e8cac71/two/result\"}',NULL,'2022-03-25 04:41:23.368777','two',NULL,NULL),(516,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"two\", \"timestamp\": 1648158083.4135392, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:23.413539','two',NULL,NULL),(517,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 151.9179349999993}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Finished execution of step \\\"two\\\" in 151ms.\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"two\", \"timestamp\": 1648158083.462232, \"user_message\": \"Finished execution of step \\\"two\\\" in 151ms.\"}','STEP_SUCCESS','2022-03-25 04:41:23.462232','two',NULL,NULL),(518,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"three\", \"step_keys\": [\"three\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Started capturing logs for step: three.\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"three\", \"timestamp\": 1648158083.550648, \"user_message\": \"Started capturing logs for step: three.\"}','LOGS_CAPTURED','2022-03-25 04:41:23.550648','three',NULL,NULL),(519,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Started execution of step \\\"three\\\".\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"three\", \"timestamp\": 1648158083.60735, \"user_message\": \"Started execution of step \\\"three\\\".\"}','STEP_START','2022-03-25 04:41:23.607350','three',NULL,NULL),(520,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"three\", \"timestamp\": 1648158083.637475, \"user_message\": \"Loading file from: /Users/prha/dagster/storage/eaa207df-08ba-4834-ae00-d0ca1e8cac71/two/result\"}',NULL,'2022-03-25 04:41:23.637475','three',NULL,NULL),(521,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"LoadedInputData\", \"input_name\": \"num\", \"manager_key\": \"io_manager\", \"upstream_output_name\": \"result\", \"upstream_step_key\": \"two\"}, \"event_type_value\": \"LOADED_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"two\\\"\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"three\", \"timestamp\": 1648158083.684108, \"user_message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"two\\\"\"}','LOADED_INPUT','2022-03-25 04:41:23.684108','three',NULL,NULL),(522,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepInputData\", \"input_name\": \"num\", \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"num\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"three\", \"timestamp\": 1648158083.714154, \"user_message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_INPUT','2022-03-25 04:41:23.714154','three',NULL,NULL),(523,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"three\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"three\", \"timestamp\": 1648158083.759966, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:23.759966','three',NULL,NULL),(524,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"three\", \"timestamp\": 1648158083.806297, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/eaa207df-08ba-4834-ae00-d0ca1e8cac71/three/result\"}',NULL,'2022-03-25 04:41:23.806297','three',NULL,NULL),(525,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"three\", \"timestamp\": 1648158083.8347251, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:23.834725','three',NULL,NULL),(526,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 120.4767999999996}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Finished execution of step \\\"three\\\" in 120ms.\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"three\", \"timestamp\": 1648158083.879377, \"user_message\": \"Finished execution of step \\\"three\\\" in 120ms.\"}','STEP_SUCCESS','2022-03-25 04:41:23.879377','three',NULL,NULL),(527,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"four\", \"step_keys\": [\"four\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"four\", \"step_key\": \"four\"}, \"message\": \"Started capturing logs for step: four.\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"four\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}}, \"step_key\": \"four\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"four\", \"timestamp\": 1648158083.9406662, \"user_message\": \"Started capturing logs for step: four.\"}','LOGS_CAPTURED','2022-03-25 04:41:23.940666','four',NULL,NULL),(528,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"four\", \"step_key\": \"four\"}, \"message\": \"Started execution of step \\\"four\\\".\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"four\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}}, \"step_key\": \"four\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"four\", \"timestamp\": 1648158083.981469, \"user_message\": \"Started execution of step \\\"four\\\".\"}','STEP_START','2022-03-25 04:41:23.981469','four',NULL,NULL),(529,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"four\", \"timestamp\": 1648158084.010274, \"user_message\": \"Loading file from: /Users/prha/dagster/storage/eaa207df-08ba-4834-ae00-d0ca1e8cac71/three/result\"}',NULL,'2022-03-25 04:41:24.010274','four',NULL,NULL),(530,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"LoadedInputData\", \"input_name\": \"num\", \"manager_key\": \"io_manager\", \"upstream_output_name\": \"result\", \"upstream_step_key\": \"three\"}, \"event_type_value\": \"LOADED_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"four\", \"step_key\": \"four\"}, \"message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"three\\\"\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"four\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}}, \"step_key\": \"four\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"four\", \"timestamp\": 1648158084.055991, \"user_message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"three\\\"\"}','LOADED_INPUT','2022-03-25 04:41:24.055991','four',NULL,NULL),(531,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepInputData\", \"input_name\": \"num\", \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"num\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"four\", \"step_key\": \"four\"}, \"message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"four\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}}, \"step_key\": \"four\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"four\", \"timestamp\": 1648158084.204736, \"user_message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_INPUT','2022-03-25 04:41:24.204736','four',NULL,NULL),(532,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepFailureData\", \"error\": {\"__class__\": \"SerializableErrorInfo\", \"cause\": {\"__class__\": \"SerializableErrorInfo\", \"cause\": null, \"cls_name\": \"Exception\", \"message\": \"Exception: blah\\n\", \"stack\": [\"  File \\\"/Users/prha/code/dagster/python_modules/dagster/dagster/core/execution/plan/utils.py\\\", line 47, in solid_execution_error_boundary\\n    yield\\n\", \"  File \\\"/Users/prha/code/dagster/python_modules/dagster/dagster/utils/__init__.py\\\", line 398, in iterate_with_context\\n    next_output = next(iterator)\\n\", \"  File \\\"/Users/prha/code/dagster/python_modules/dagster/dagster/core/execution/plan/compute_generator.py\\\", line 65, in _coerce_solid_compute_fn_to_iterator\\n    result = fn(context, **kwargs) if context_arg_provided else fn(**kwargs)\\n\", \"  File \\\"/Users/prha/code/dagster/python_modules/dagster-test/dagster_test/toys/unreliable.py\\\", line 18, in unreliable\\n    raise Exception(\\\"blah\\\")\\n\"]}, \"cls_name\": \"DagsterExecutionStepExecutionError\", \"message\": \"dagster.core.errors.DagsterExecutionStepExecutionError: Error occurred while executing solid \\\"four\\\":\\n\", \"stack\": [\"  File \\\"/Users/prha/code/dagster/python_modules/dagster/dagster/core/execution/plan/execute_plan.py\\\", line 232, in dagster_event_sequence_for_step\\n    for step_event in check.generator(step_events):\\n\", \"  File \\\"/Users/prha/code/dagster/python_modules/dagster/dagster/core/execution/plan/execute_step.py\\\", line 342, in core_dagster_event_sequence_for_step\\n    for user_event in check.generator(\\n\", \"  File \\\"/Users/prha/code/dagster/python_modules/dagster/dagster/core/execution/plan/execute_step.py\\\", line 69, in _step_output_error_checked_user_event_sequence\\n    for user_event in user_event_sequence:\\n\", \"  File \\\"/Users/prha/code/dagster/python_modules/dagster/dagster/core/execution/plan/compute.py\\\", line 169, in execute_core_compute\\n    for step_output in _yield_compute_results(step_context, inputs, compute_fn):\\n\", \"  File \\\"/Users/prha/code/dagster/python_modules/dagster/dagster/core/execution/plan/compute.py\\\", line 137, in _yield_compute_results\\n    for event in iterate_with_context(\\n\", \"  File \\\"/Users/prha/code/dagster/python_modules/dagster/dagster/utils/__init__.py\\\", line 400, in iterate_with_context\\n    return\\n\", \"  File \\\"/Users/prha/.pyenv/versions/3.8.7/lib/python3.8/contextlib.py\\\", line 131, in __exit__\\n    self.gen.throw(type, value, traceback)\\n\", \"  File \\\"/Users/prha/code/dagster/python_modules/dagster/dagster/core/execution/plan/utils.py\\\", line 73, in solid_execution_error_boundary\\n    raise error_cls(\\n\"]}, \"error_source\": {\"__enum__\": \"ErrorSource.USER_CODE_ERROR\"}, \"user_failure_data\": null}, \"event_type_value\": \"STEP_FAILURE\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:41:00+00:00\', \'dagster/partition\': \'2020-01-05\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-05\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_name\": \"four\", \"step_key\": \"four\"}, \"message\": \"Execution of step \\\"four\\\" failed.\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"four\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}}, \"step_key\": \"four\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 40, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"four\", \"timestamp\": 1648158084.313625, \"user_message\": \"Execution of step \\\"four\\\" failed.\"}','STEP_FAILURE','2022-03-25 04:41:24.313625','four',NULL,NULL),(533,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 40, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"five\", \"timestamp\": 1648158084.36798, \"user_message\": \"Dependencies for step five failed: [\'four\']. Not executing.\"}',NULL,'2022-03-25 04:41:24.367980','five',NULL,NULL),(534,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 40, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"six\", \"timestamp\": 1648158084.408226, \"user_message\": \"Dependencies for step six were not executed: [\'five\']. Not executing.\"}',NULL,'2022-03-25 04:41:24.408226','six',NULL,NULL),(535,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 40, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": \"seven\", \"timestamp\": 1648158084.4343622, \"user_message\": \"Dependencies for step seven were not executed: [\'six\']. Not executing.\"}',NULL,'2022-03-25 04:41:24.434362','seven',NULL,NULL),(536,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23078\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'unreliable_start\', \'one\', \'two\', \'three\', \'four\', \'five\', \'six\', \'seven\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23078) in 2.15s\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": null, \"timestamp\": 1648158084.461246, \"user_message\": \"Finished steps in process (pid: 23078) in 2.15s\"}','ENGINE_EVENT','2022-03-25 04:41:24.461246',NULL,NULL,NULL),(537,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"PipelineFailureData\", \"error\": null}, \"event_type_value\": \"PIPELINE_FAILURE\", \"logging_tags\": {}, \"message\": \"Execution of run for \\\"unreliable_pipeline\\\" failed. Steps failed: [\'four\'].\", \"pid\": 23078, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 40, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": null, \"timestamp\": 1648158084.504357, \"user_message\": \"Execution of run for \\\"unreliable_pipeline\\\" failed. Steps failed: [\'four\'].\"}','PIPELINE_FAILURE','2022-03-25 04:41:24.504357',NULL,NULL,NULL),(538,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23083, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": null, \"timestamp\": 1648158084.516663, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:24.516663',NULL,NULL,NULL),(539,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23078).\", \"pid\": null, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"step_key\": null, \"timestamp\": 1648158084.659664, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:24.659664',NULL,NULL,NULL),(540,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23083\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23083)\", \"pid\": 23083, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": null, \"timestamp\": 1648158084.7084959, \"user_message\": \"Executing steps in process (pid: 23083)\"}','ENGINE_EVENT','2022-03-25 04:41:24.708496',NULL,NULL,NULL),(541,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23083, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": \"read_file\", \"timestamp\": 1648158084.737772, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:24.737772','read_file',NULL,NULL),(542,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.05ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23083, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": \"read_file\", \"timestamp\": 1648158084.778246, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:24.778246','read_file',NULL,NULL),(543,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_4:1610388763.2417717\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23083, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": \"read_file\", \"timestamp\": 1648158084.845056, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:24.845056','read_file',NULL,NULL),(544,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_4:1610388763.2417717\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23083, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": \"read_file\", \"timestamp\": 1648158084.882327, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:24.882327','read_file',NULL,NULL),(545,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": \"read_file\", \"timestamp\": 1648158084.913147, \"user_message\": \"Found file bx_new_run_4\"}',NULL,'2022-03-25 04:41:24.913147','read_file',NULL,NULL),(546,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bx_new_run_4\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bx_new_run_4\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1610388763.2417717, \"mtime\": 1610388763.2417717, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_4:1610388763.2417717\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file bx_new_run_4.\", \"pid\": 23083, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": \"read_file\", \"timestamp\": 1648158084.957979, \"user_message\": \"Materialized value log_file bx_new_run_4.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:24.957979','read_file','[\"log_file\", \"bx_new_run_4\"]',NULL),(547,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_4:1610388763.2417717\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23083, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": \"read_file\", \"timestamp\": 1648158085.0372999, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:25.037300','read_file',NULL,NULL),(548,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_4:1610388763.2417717\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23083, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": \"read_file\", \"timestamp\": 1648158085.079637, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:25.079637','read_file',NULL,NULL),(549,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 198.94078700000063}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_4:1610388763.2417717\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 198ms.\", \"pid\": 23083, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": \"read_file\", \"timestamp\": 1648158085.1116412, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 198ms.\"}','STEP_SUCCESS','2022-03-25 04:41:25.111641','read_file',NULL,NULL),(550,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23083\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23083) in 429ms\", \"pid\": 23083, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": null, \"timestamp\": 1648158085.1636422, \"user_message\": \"Finished steps in process (pid: 23083) in 429ms\"}','ENGINE_EVENT','2022-03-25 04:41:25.163642',NULL,NULL,NULL),(551,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23083, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": null, \"timestamp\": 1648158085.207327, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:25.207327',NULL,NULL,NULL),(552,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23083).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"step_key\": null, \"timestamp\": 1648158085.308723, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:25.308723',NULL,NULL,NULL),(553,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23188\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23188).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": null, \"timestamp\": 1648158085.879788, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:25.879788',NULL,NULL,NULL),(554,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": null, \"timestamp\": 1648158086.1799848, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:26.179985',NULL,NULL,NULL),(555,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23188, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": null, \"timestamp\": 1648158087.335393, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:27.335393',NULL,NULL,NULL),(556,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23188\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23188)\", \"pid\": 23188, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": null, \"timestamp\": 1648158087.4808152, \"user_message\": \"Executing steps in process (pid: 23188)\"}','ENGINE_EVENT','2022-03-25 04:41:27.480815',NULL,NULL,NULL),(557,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23188, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": \"read_file\", \"timestamp\": 1648158087.512543, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:27.512543','read_file',NULL,NULL),(558,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.04ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23188, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": \"read_file\", \"timestamp\": 1648158087.5562382, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:27.556238','read_file',NULL,NULL),(559,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run:1608060793.3515544\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23188, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": \"read_file\", \"timestamp\": 1648158087.607331, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:27.607331','read_file',NULL,NULL),(560,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run:1608060793.3515544\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23188, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": \"read_file\", \"timestamp\": 1648158087.6562939, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:27.656294','read_file',NULL,NULL),(561,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": \"read_file\", \"timestamp\": 1648158087.6819909, \"user_message\": \"Found file bx_new_run\"}',NULL,'2022-03-25 04:41:27.681991','read_file',NULL,NULL),(562,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bx_new_run\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bx_new_run\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1608060793.3515544, \"mtime\": 1608060793.3515544, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run:1608060793.3515544\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file bx_new_run.\", \"pid\": 23188, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": \"read_file\", \"timestamp\": 1648158087.7079492, \"user_message\": \"Materialized value log_file bx_new_run.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:27.707949','read_file','[\"log_file\", \"bx_new_run\"]',NULL),(563,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run:1608060793.3515544\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23188, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": \"read_file\", \"timestamp\": 1648158087.8089511, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:27.808951','read_file',NULL,NULL),(564,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run:1608060793.3515544\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23188, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": \"read_file\", \"timestamp\": 1648158087.835406, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:27.835406','read_file',NULL,NULL),(565,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 197.0972820000001}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run:1608060793.3515544\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 197ms.\", \"pid\": 23188, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": \"read_file\", \"timestamp\": 1648158087.8788218, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 197ms.\"}','STEP_SUCCESS','2022-03-25 04:41:27.878822','read_file',NULL,NULL),(566,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23188\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23188) in 403ms\", \"pid\": 23188, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": null, \"timestamp\": 1648158087.913409, \"user_message\": \"Finished steps in process (pid: 23188) in 403ms\"}','ENGINE_EVENT','2022-03-25 04:41:27.913409',NULL,NULL,NULL),(567,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23188, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": null, \"timestamp\": 1648158087.956544, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:27.956544',NULL,NULL,NULL),(568,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23188).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"step_key\": null, \"timestamp\": 1648158088.0587368, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:28.058737',NULL,NULL,NULL),(569,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23282\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23282).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": null, \"timestamp\": 1648158088.3107462, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:28.310746',NULL,NULL,NULL),(570,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": null, \"timestamp\": 1648158088.627232, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:28.627232',NULL,NULL,NULL),(571,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23282, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": null, \"timestamp\": 1648158089.785032, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:29.785032',NULL,NULL,NULL),(572,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23282\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23282)\", \"pid\": 23282, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": null, \"timestamp\": 1648158089.931348, \"user_message\": \"Executing steps in process (pid: 23282)\"}','ENGINE_EVENT','2022-03-25 04:41:29.931348',NULL,NULL,NULL),(573,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23282, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": \"read_file\", \"timestamp\": 1648158089.9640372, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:29.964037','read_file',NULL,NULL),(574,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.04ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23282, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": \"read_file\", \"timestamp\": 1648158090.006419, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:30.006419','read_file',NULL,NULL),(575,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_2:1608060796.9405777\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23282, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": \"read_file\", \"timestamp\": 1648158090.0569139, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:30.056914','read_file',NULL,NULL),(576,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_2:1608060796.9405777\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23282, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": \"read_file\", \"timestamp\": 1648158090.105484, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:30.105484','read_file',NULL,NULL),(577,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": \"read_file\", \"timestamp\": 1648158090.133402, \"user_message\": \"Found file bx_new_run_2\"}',NULL,'2022-03-25 04:41:30.133402','read_file',NULL,NULL),(578,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bx_new_run_2\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bx_new_run_2\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1608060796.9405777, \"mtime\": 1608060796.9405777, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_2:1608060796.9405777\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file bx_new_run_2.\", \"pid\": 23282, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": \"read_file\", \"timestamp\": 1648158090.160455, \"user_message\": \"Materialized value log_file bx_new_run_2.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:30.160455','read_file','[\"log_file\", \"bx_new_run_2\"]',NULL),(579,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_2:1608060796.9405777\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23282, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": \"read_file\", \"timestamp\": 1648158090.260921, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:30.260921','read_file',NULL,NULL),(580,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_2:1608060796.9405777\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23282, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": \"read_file\", \"timestamp\": 1648158090.305841, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:30.305841','read_file',NULL,NULL),(581,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 199.96485099999984}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bx_new_run_2:1608060796.9405777\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 199ms.\", \"pid\": 23282, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": \"read_file\", \"timestamp\": 1648158090.333088, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 199ms.\"}','STEP_SUCCESS','2022-03-25 04:41:30.333088','read_file',NULL,NULL),(582,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23282\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23282) in 407ms\", \"pid\": 23282, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": null, \"timestamp\": 1648158090.368185, \"user_message\": \"Finished steps in process (pid: 23282) in 407ms\"}','ENGINE_EVENT','2022-03-25 04:41:30.368185',NULL,NULL,NULL),(583,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23282, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": null, \"timestamp\": 1648158090.407925, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:30.407925',NULL,NULL,NULL),(584,'f62982b8-3037-468e-a94e-032f68011e77','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23282).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"step_key\": null, \"timestamp\": 1648158090.508224, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:30.508224',NULL,NULL,NULL),(585,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23289\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23289).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": null, \"timestamp\": 1648158090.862237, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:30.862237',NULL,NULL,NULL),(586,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": null, \"timestamp\": 1648158091.183037, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:31.183037',NULL,NULL,NULL),(587,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23289, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": null, \"timestamp\": 1648158092.3445241, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:32.344524',NULL,NULL,NULL),(588,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23289\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23289)\", \"pid\": 23289, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": null, \"timestamp\": 1648158092.479954, \"user_message\": \"Executing steps in process (pid: 23289)\"}','ENGINE_EVENT','2022-03-25 04:41:32.479954',NULL,NULL,NULL),(589,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23289, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": \"read_file\", \"timestamp\": 1648158092.516598, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:32.516598','read_file',NULL,NULL),(590,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.05ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23289, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": \"read_file\", \"timestamp\": 1648158092.558144, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:32.558144','read_file',NULL,NULL),(591,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'foooawoiefj:1645197413.2837281\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23289, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": \"read_file\", \"timestamp\": 1648158092.609601, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:32.609601','read_file',NULL,NULL),(592,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'foooawoiefj:1645197413.2837281\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23289, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": \"read_file\", \"timestamp\": 1648158092.657769, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:32.657769','read_file',NULL,NULL),(593,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": \"read_file\", \"timestamp\": 1648158092.6836202, \"user_message\": \"Found file foooawoiefj\"}',NULL,'2022-03-25 04:41:32.683620','read_file',NULL,NULL),(594,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"foooawoiefj\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/foooawoiefj\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1645197413.2837281, \"mtime\": 1645197413.2837281, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'foooawoiefj:1645197413.2837281\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file foooawoiefj.\", \"pid\": 23289, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": \"read_file\", \"timestamp\": 1648158092.711284, \"user_message\": \"Materialized value log_file foooawoiefj.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:32.711284','read_file','[\"log_file\", \"foooawoiefj\"]',NULL),(595,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'foooawoiefj:1645197413.2837281\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23289, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": \"read_file\", \"timestamp\": 1648158092.813298, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:32.813298','read_file',NULL,NULL),(596,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'foooawoiefj:1645197413.2837281\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23289, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": \"read_file\", \"timestamp\": 1648158092.857413, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:32.857413','read_file',NULL,NULL),(597,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 202.00315599999996}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'foooawoiefj:1645197413.2837281\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 202ms.\", \"pid\": 23289, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": \"read_file\", \"timestamp\": 1648158092.8853881, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 202ms.\"}','STEP_SUCCESS','2022-03-25 04:41:32.885388','read_file',NULL,NULL),(598,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23289\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23289) in 421ms\", \"pid\": 23289, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": null, \"timestamp\": 1648158092.9343748, \"user_message\": \"Finished steps in process (pid: 23289) in 421ms\"}','ENGINE_EVENT','2022-03-25 04:41:32.934375',NULL,NULL,NULL),(599,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23289, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": null, \"timestamp\": 1648158092.961986, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:32.961986',NULL,NULL,NULL),(600,'66d03d20-ef6b-40eb-92e3-e7c17033831a','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23289).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"step_key\": null, \"timestamp\": 1648158093.0825229, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:33.082523',NULL,NULL,NULL),(601,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23296\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23296).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": null, \"timestamp\": 1648158093.3368168, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:33.336817',NULL,NULL,NULL),(602,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": null, \"timestamp\": 1648158093.657023, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:33.657023',NULL,NULL,NULL),(603,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23296, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": null, \"timestamp\": 1648158094.8832471, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:34.883247',NULL,NULL,NULL),(604,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23296\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23296)\", \"pid\": 23296, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": null, \"timestamp\": 1648158095.008758, \"user_message\": \"Executing steps in process (pid: 23296)\"}','ENGINE_EVENT','2022-03-25 04:41:35.008758',NULL,NULL,NULL),(605,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23296, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": \"read_file\", \"timestamp\": 1648158095.058845, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:35.058845','read_file',NULL,NULL),(606,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.05ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23296, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": \"read_file\", \"timestamp\": 1648158095.086473, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:35.086473','read_file',NULL,NULL),(607,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'demo.1:1606341124.944769\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23296, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": \"read_file\", \"timestamp\": 1648158095.152857, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:35.152857','read_file',NULL,NULL),(608,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'demo.1:1606341124.944769\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23296, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": \"read_file\", \"timestamp\": 1648158095.18519, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:35.185190','read_file',NULL,NULL),(609,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": \"read_file\", \"timestamp\": 1648158095.230923, \"user_message\": \"Found file demo.1\"}',NULL,'2022-03-25 04:41:35.230923','read_file',NULL,NULL),(610,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"demo.1\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/demo.1\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1606341124.944769, \"mtime\": 1606341124.944769, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'demo.1:1606341124.944769\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file demo.1.\", \"pid\": 23296, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": \"read_file\", \"timestamp\": 1648158095.258977, \"user_message\": \"Materialized value log_file demo.1.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:35.258977','read_file','[\"log_file\", \"demo.1\"]',NULL),(611,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'demo.1:1606341124.944769\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23296, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": \"read_file\", \"timestamp\": 1648158095.3597, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:35.359700','read_file',NULL,NULL),(612,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'demo.1:1606341124.944769\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23296, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": \"read_file\", \"timestamp\": 1648158095.388041, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:35.388041','read_file',NULL,NULL),(613,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 197.75639399999977}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'demo.1:1606341124.944769\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 197ms.\", \"pid\": 23296, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": \"read_file\", \"timestamp\": 1648158095.428421, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 197ms.\"}','STEP_SUCCESS','2022-03-25 04:41:35.428421','read_file',NULL,NULL),(614,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23296\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23296) in 408ms\", \"pid\": 23296, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": null, \"timestamp\": 1648158095.464025, \"user_message\": \"Finished steps in process (pid: 23296) in 408ms\"}','ENGINE_EVENT','2022-03-25 04:41:35.464025',NULL,NULL,NULL),(615,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23296, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": null, \"timestamp\": 1648158095.507411, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:35.507411',NULL,NULL,NULL),(616,'dc459868-808c-4476-adf7-548b1f42f45c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23296).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"step_key\": null, \"timestamp\": 1648158095.610442, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:35.610442',NULL,NULL,NULL),(617,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23382\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23382).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": null, \"timestamp\": 1648158095.9820101, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:35.982010',NULL,NULL,NULL),(618,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": null, \"timestamp\": 1648158096.2785642, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:36.278564',NULL,NULL,NULL),(619,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23382, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": null, \"timestamp\": 1648158097.54, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:37.540000',NULL,NULL,NULL),(620,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23382\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23382)\", \"pid\": 23382, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": null, \"timestamp\": 1648158097.681988, \"user_message\": \"Executing steps in process (pid: 23382)\"}','ENGINE_EVENT','2022-03-25 04:41:37.681988',NULL,NULL,NULL),(621,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23382, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": \"read_file\", \"timestamp\": 1648158097.714646, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:37.714646','read_file',NULL,NULL),(622,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.05ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23382, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": \"read_file\", \"timestamp\": 1648158097.75828, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:37.758280','read_file',NULL,NULL),(623,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boopppp:1607487853.6962564\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23382, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": \"read_file\", \"timestamp\": 1648158097.811279, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:37.811279','read_file',NULL,NULL),(624,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boopppp:1607487853.6962564\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23382, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": \"read_file\", \"timestamp\": 1648158097.8590841, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:37.859084','read_file',NULL,NULL),(625,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": \"read_file\", \"timestamp\": 1648158097.887508, \"user_message\": \"Found file boopppp\"}',NULL,'2022-03-25 04:41:37.887508','read_file',NULL,NULL),(626,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"boopppp\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/boopppp\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607487853.6962564, \"mtime\": 1607487853.6962564, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boopppp:1607487853.6962564\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file boopppp.\", \"pid\": 23382, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": \"read_file\", \"timestamp\": 1648158097.929342, \"user_message\": \"Materialized value log_file boopppp.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:37.929342','read_file','[\"log_file\", \"boopppp\"]',NULL),(627,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boopppp:1607487853.6962564\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23382, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": \"read_file\", \"timestamp\": 1648158098.029525, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:38.029525','read_file',NULL,NULL),(628,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boopppp:1607487853.6962564\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23382, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": \"read_file\", \"timestamp\": 1648158098.0585961, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:38.058596','read_file',NULL,NULL),(629,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 199.11672500000012}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boopppp:1607487853.6962564\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 199ms.\", \"pid\": 23382, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": \"read_file\", \"timestamp\": 1648158098.086407, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 199ms.\"}','STEP_SUCCESS','2022-03-25 04:41:38.086407','read_file',NULL,NULL),(630,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23382\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23382) in 423ms\", \"pid\": 23382, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": null, \"timestamp\": 1648158098.134319, \"user_message\": \"Finished steps in process (pid: 23382) in 423ms\"}','ENGINE_EVENT','2022-03-25 04:41:38.134319',NULL,NULL,NULL),(631,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23382, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": null, \"timestamp\": 1648158098.161802, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:38.161802',NULL,NULL,NULL),(632,'e641587a-ac48-4a95-8208-81990c416d8d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23382).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"step_key\": null, \"timestamp\": 1648158098.306011, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:38.306011',NULL,NULL,NULL),(633,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23472\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23472).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": null, \"timestamp\": 1648158098.536543, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:38.536543',NULL,NULL,NULL),(634,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": null, \"timestamp\": 1648158098.907372, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:38.907372',NULL,NULL,NULL),(635,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23472, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": null, \"timestamp\": 1648158100.091785, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:40.091785',NULL,NULL,NULL),(636,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23472\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23472)\", \"pid\": 23472, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": null, \"timestamp\": 1648158100.229841, \"user_message\": \"Executing steps in process (pid: 23472)\"}','ENGINE_EVENT','2022-03-25 04:41:40.229841',NULL,NULL,NULL),(637,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23472, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": \"read_file\", \"timestamp\": 1648158100.261227, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:40.261227','read_file',NULL,NULL),(638,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.04ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23472, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": \"read_file\", \"timestamp\": 1648158100.286128, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:40.286128','read_file',NULL,NULL),(639,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'blawiejfoj:1647625969.2538514\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23472, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": \"read_file\", \"timestamp\": 1648158100.352829, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:40.352829','read_file',NULL,NULL),(640,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'blawiejfoj:1647625969.2538514\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23472, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": \"read_file\", \"timestamp\": 1648158100.3845482, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:40.384548','read_file',NULL,NULL),(641,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": \"read_file\", \"timestamp\": 1648158100.428331, \"user_message\": \"Found file blawiejfoj\"}',NULL,'2022-03-25 04:41:40.428331','read_file',NULL,NULL),(642,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"blawiejfoj\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/blawiejfoj\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1647625969.2538514, \"mtime\": 1647625969.2538514, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'blawiejfoj:1647625969.2538514\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file blawiejfoj.\", \"pid\": 23472, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": \"read_file\", \"timestamp\": 1648158100.457637, \"user_message\": \"Materialized value log_file blawiejfoj.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:40.457637','read_file','[\"log_file\", \"blawiejfoj\"]',NULL),(643,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'blawiejfoj:1647625969.2538514\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23472, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": \"read_file\", \"timestamp\": 1648158100.556475, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:40.556475','read_file',NULL,NULL),(644,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'blawiejfoj:1647625969.2538514\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23472, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": \"read_file\", \"timestamp\": 1648158100.584129, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:40.584129','read_file',NULL,NULL),(645,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 183.56233200000017}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'blawiejfoj:1647625969.2538514\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 183ms.\", \"pid\": 23472, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": \"read_file\", \"timestamp\": 1648158100.611657, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 183ms.\"}','STEP_SUCCESS','2022-03-25 04:41:40.611657','read_file',NULL,NULL),(646,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23472\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23472) in 403ms\", \"pid\": 23472, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": null, \"timestamp\": 1648158100.6611671, \"user_message\": \"Finished steps in process (pid: 23472) in 403ms\"}','ENGINE_EVENT','2022-03-25 04:41:40.661167',NULL,NULL,NULL),(647,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23472, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": null, \"timestamp\": 1648158100.7045429, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:40.704543',NULL,NULL,NULL),(648,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23472).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"step_key\": null, \"timestamp\": 1648158100.808768, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:40.808768',NULL,NULL,NULL),(649,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23479\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23479).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": null, \"timestamp\": 1648158101.059346, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:41.059346',NULL,NULL,NULL),(650,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": null, \"timestamp\": 1648158101.3858838, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:41.385884',NULL,NULL,NULL),(651,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23479, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": null, \"timestamp\": 1648158102.542084, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:42.542084',NULL,NULL,NULL),(652,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23479\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23479)\", \"pid\": 23479, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": null, \"timestamp\": 1648158102.6802938, \"user_message\": \"Executing steps in process (pid: 23479)\"}','ENGINE_EVENT','2022-03-25 04:41:42.680294',NULL,NULL,NULL),(653,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23479, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": \"read_file\", \"timestamp\": 1648158102.71223, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:42.712230','read_file',NULL,NULL),(654,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.04ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23479, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": \"read_file\", \"timestamp\": 1648158102.755996, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:42.755996','read_file',NULL,NULL),(655,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'b.out:1605834003.363826\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23479, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": \"read_file\", \"timestamp\": 1648158102.80354, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:42.803540','read_file',NULL,NULL),(656,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'b.out:1605834003.363826\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23479, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": \"read_file\", \"timestamp\": 1648158102.854827, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:42.854827','read_file',NULL,NULL),(657,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": \"read_file\", \"timestamp\": 1648158102.883371, \"user_message\": \"Found file b.out\"}',NULL,'2022-03-25 04:41:42.883371','read_file',NULL,NULL),(658,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"b.out\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/b.out\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1605834003.3638573, \"mtime\": 1605834003.363826, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'b.out:1605834003.363826\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file b.out.\", \"pid\": 23479, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": \"read_file\", \"timestamp\": 1648158102.9110122, \"user_message\": \"Materialized value log_file b.out.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:42.911012','read_file','[\"log_file\", \"b.out\"]',NULL),(659,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'b.out:1605834003.363826\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23479, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": \"read_file\", \"timestamp\": 1648158103.011462, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:43.011462','read_file',NULL,NULL),(660,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'b.out:1605834003.363826\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23479, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": \"read_file\", \"timestamp\": 1648158103.055945, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:43.055945','read_file',NULL,NULL),(661,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 200.1014750000003}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'b.out:1605834003.363826\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 200ms.\", \"pid\": 23479, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": \"read_file\", \"timestamp\": 1648158103.0832372, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 200ms.\"}','STEP_SUCCESS','2022-03-25 04:41:43.083237','read_file',NULL,NULL),(662,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23479\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23479) in 408ms\", \"pid\": 23479, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": null, \"timestamp\": 1648158103.116588, \"user_message\": \"Finished steps in process (pid: 23479) in 408ms\"}','ENGINE_EVENT','2022-03-25 04:41:43.116588',NULL,NULL,NULL),(663,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23479, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": null, \"timestamp\": 1648158103.1578088, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:43.157809',NULL,NULL,NULL),(664,'e737f12e-dadf-4295-9ce1-ec3f43d84238','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23479).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"step_key\": null, \"timestamp\": 1648158103.282105, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:43.282105',NULL,NULL,NULL),(665,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23486\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23486).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": null, \"timestamp\": 1648158103.610774, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:43.610774',NULL,NULL,NULL),(666,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": null, \"timestamp\": 1648158103.883497, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:43.883497',NULL,NULL,NULL),(667,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23486, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": null, \"timestamp\": 1648158105.136081, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:45.136081',NULL,NULL,NULL),(668,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23486\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23486)\", \"pid\": 23486, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": null, \"timestamp\": 1648158105.279617, \"user_message\": \"Executing steps in process (pid: 23486)\"}','ENGINE_EVENT','2022-03-25 04:41:45.279617',NULL,NULL,NULL),(669,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23486, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": \"read_file\", \"timestamp\": 1648158105.311798, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:45.311798','read_file',NULL,NULL),(670,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.04ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23486, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": \"read_file\", \"timestamp\": 1648158105.356096, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:45.356096','read_file',NULL,NULL),(671,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key_3:1606942458.8674\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23486, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": \"read_file\", \"timestamp\": 1648158105.406337, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:45.406337','read_file',NULL,NULL),(672,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key_3:1606942458.8674\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23486, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": \"read_file\", \"timestamp\": 1648158105.4550972, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:45.455097','read_file',NULL,NULL),(673,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": \"read_file\", \"timestamp\": 1648158105.483527, \"user_message\": \"Found file show_run_key_3\"}',NULL,'2022-03-25 04:41:45.483527','read_file',NULL,NULL),(674,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"show_run_key_3\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/show_run_key_3\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1606942458.8674397, \"mtime\": 1606942458.8674, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key_3:1606942458.8674\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file show_run_key_3.\", \"pid\": 23486, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": \"read_file\", \"timestamp\": 1648158105.511591, \"user_message\": \"Materialized value log_file show_run_key_3.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:45.511591','read_file','[\"log_file\", \"show_run_key_3\"]',NULL),(675,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key_3:1606942458.8674\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23486, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": \"read_file\", \"timestamp\": 1648158105.612061, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:45.612061','read_file',NULL,NULL),(676,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key_3:1606942458.8674\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23486, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": \"read_file\", \"timestamp\": 1648158105.6382878, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:45.638288','read_file',NULL,NULL),(677,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 196.05950400000037}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key_3:1606942458.8674\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 196ms.\", \"pid\": 23486, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": \"read_file\", \"timestamp\": 1648158105.6792839, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 196ms.\"}','STEP_SUCCESS','2022-03-25 04:41:45.679284','read_file',NULL,NULL),(678,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23486\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23486) in 406ms\", \"pid\": 23486, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": null, \"timestamp\": 1648158105.714908, \"user_message\": \"Finished steps in process (pid: 23486) in 406ms\"}','ENGINE_EVENT','2022-03-25 04:41:45.714908',NULL,NULL,NULL),(679,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23486, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": null, \"timestamp\": 1648158105.75875, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:45.758750',NULL,NULL,NULL),(680,'06c52e01-4d6e-41e1-997c-38207bf5c267','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23486).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"step_key\": null, \"timestamp\": 1648158105.880746, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:45.880746',NULL,NULL,NULL),(681,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23493\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23493).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": null, \"timestamp\": 1648158106.035948, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:46.035948',NULL,NULL,NULL),(682,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": null, \"timestamp\": 1648158106.380935, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:46.380935',NULL,NULL,NULL),(683,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23493, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": null, \"timestamp\": 1648158107.5661561, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:47.566156',NULL,NULL,NULL),(684,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23493\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23493)\", \"pid\": 23493, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": null, \"timestamp\": 1648158107.7074208, \"user_message\": \"Executing steps in process (pid: 23493)\"}','ENGINE_EVENT','2022-03-25 04:41:47.707421',NULL,NULL,NULL),(685,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23493, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": \"read_file\", \"timestamp\": 1648158107.736077, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:47.736077','read_file',NULL,NULL),(686,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.05ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23493, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": \"read_file\", \"timestamp\": 1648158107.779258, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:47.779258','read_file',NULL,NULL),(687,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key_2:1606840685.1579385\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23493, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": \"read_file\", \"timestamp\": 1648158107.833141, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:47.833141','read_file',NULL,NULL),(688,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key_2:1606840685.1579385\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23493, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": \"read_file\", \"timestamp\": 1648158107.880207, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:47.880207','read_file',NULL,NULL),(689,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": \"read_file\", \"timestamp\": 1648158107.908701, \"user_message\": \"Found file show_run_key_2\"}',NULL,'2022-03-25 04:41:47.908701','read_file',NULL,NULL),(690,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"show_run_key_2\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/show_run_key_2\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1606840685.1579385, \"mtime\": 1606840685.1579385, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key_2:1606840685.1579385\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file show_run_key_2.\", \"pid\": 23493, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": \"read_file\", \"timestamp\": 1648158107.9343958, \"user_message\": \"Materialized value log_file show_run_key_2.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:47.934396','read_file','[\"log_file\", \"show_run_key_2\"]',NULL),(691,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key_2:1606840685.1579385\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23493, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": \"read_file\", \"timestamp\": 1648158108.031175, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:48.031175','read_file',NULL,NULL),(692,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key_2:1606840685.1579385\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23493, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": \"read_file\", \"timestamp\": 1648158108.0595012, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:48.059501','read_file',NULL,NULL),(693,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 179.00151599999958}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key_2:1606840685.1579385\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 179ms.\", \"pid\": 23493, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": \"read_file\", \"timestamp\": 1648158108.087279, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 179ms.\"}','STEP_SUCCESS','2022-03-25 04:41:48.087279','read_file',NULL,NULL),(694,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23493\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23493) in 401ms\", \"pid\": 23493, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": null, \"timestamp\": 1648158108.134489, \"user_message\": \"Finished steps in process (pid: 23493) in 401ms\"}','ENGINE_EVENT','2022-03-25 04:41:48.134489',NULL,NULL,NULL),(695,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23493, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": null, \"timestamp\": 1648158108.161246, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:48.161246',NULL,NULL,NULL),(696,'84b8c995-a9d8-40e7-9887-5188e07fc31c','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23493).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"step_key\": null, \"timestamp\": 1648158108.2838788, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:48.283879',NULL,NULL,NULL),(697,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23666\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23666).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": null, \"timestamp\": 1648158108.662847, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:48.662847',NULL,NULL,NULL),(698,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": null, \"timestamp\": 1648158109.034692, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:49.034692',NULL,NULL,NULL),(699,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23666, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": null, \"timestamp\": 1648158110.1668942, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:50.166894',NULL,NULL,NULL),(700,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23666\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23666)\", \"pid\": 23666, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": null, \"timestamp\": 1648158110.3089888, \"user_message\": \"Executing steps in process (pid: 23666)\"}','ENGINE_EVENT','2022-03-25 04:41:50.308989',NULL,NULL,NULL),(701,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23666, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": \"read_file\", \"timestamp\": 1648158110.359217, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:50.359217','read_file',NULL,NULL),(702,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.04ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23666, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": \"read_file\", \"timestamp\": 1648158110.384959, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:50.384959','read_file',NULL,NULL),(703,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'a.out:1605833207.4776378\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23666, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": \"read_file\", \"timestamp\": 1648158110.437026, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:50.437026','read_file',NULL,NULL),(704,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'a.out:1605833207.4776378\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23666, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": \"read_file\", \"timestamp\": 1648158110.480482, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:50.480482','read_file',NULL,NULL),(705,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": \"read_file\", \"timestamp\": 1648158110.5087721, \"user_message\": \"Found file a.out\"}',NULL,'2022-03-25 04:41:50.508772','read_file',NULL,NULL),(706,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"a.out\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/a.out\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1605833207.4776378, \"mtime\": 1605833207.4776378, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'a.out:1605833207.4776378\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file a.out.\", \"pid\": 23666, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": \"read_file\", \"timestamp\": 1648158110.535794, \"user_message\": \"Materialized value log_file a.out.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:50.535794','read_file','[\"log_file\", \"a.out\"]',NULL),(707,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'a.out:1605833207.4776378\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23666, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": \"read_file\", \"timestamp\": 1648158110.631917, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:50.631917','read_file',NULL,NULL),(708,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'a.out:1605833207.4776378\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23666, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": \"read_file\", \"timestamp\": 1648158110.6596448, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:50.659645','read_file',NULL,NULL),(709,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 179.0015730000003}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'a.out:1605833207.4776378\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 179ms.\", \"pid\": 23666, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": \"read_file\", \"timestamp\": 1648158110.6873522, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 179ms.\"}','STEP_SUCCESS','2022-03-25 04:41:50.687352','read_file',NULL,NULL),(710,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23666\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23666) in 379ms\", \"pid\": 23666, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": null, \"timestamp\": 1648158110.734952, \"user_message\": \"Finished steps in process (pid: 23666) in 379ms\"}','ENGINE_EVENT','2022-03-25 04:41:50.734952',NULL,NULL,NULL),(711,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23666, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": null, \"timestamp\": 1648158110.761642, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:50.761642',NULL,NULL,NULL),(712,'184e6db1-23a0-42a7-9bff-8ea1cf922193','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23666).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"step_key\": null, \"timestamp\": 1648158110.8819041, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:50.881904',NULL,NULL,NULL),(713,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23673\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23673).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": null, \"timestamp\": 1648158111.233084, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:51.233084',NULL,NULL,NULL),(714,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": null, \"timestamp\": 1648158111.557102, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:51.557102',NULL,NULL,NULL),(715,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23673, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": null, \"timestamp\": 1648158112.6885178, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:52.688518',NULL,NULL,NULL),(716,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23673\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23673)\", \"pid\": 23673, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": null, \"timestamp\": 1648158112.830993, \"user_message\": \"Executing steps in process (pid: 23673)\"}','ENGINE_EVENT','2022-03-25 04:41:52.830993',NULL,NULL,NULL),(717,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23673, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": \"read_file\", \"timestamp\": 1648158112.8651872, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:52.865187','read_file',NULL,NULL),(718,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.05ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23673, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": \"read_file\", \"timestamp\": 1648158112.9085171, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:52.908517','read_file',NULL,NULL),(719,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop:1607484774.6155019\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23673, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": \"read_file\", \"timestamp\": 1648158112.960354, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:52.960354','read_file',NULL,NULL),(720,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop:1607484774.6155019\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23673, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": \"read_file\", \"timestamp\": 1648158113.0097878, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:53.009788','read_file',NULL,NULL),(721,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": \"read_file\", \"timestamp\": 1648158113.0371, \"user_message\": \"Found file boop\"}',NULL,'2022-03-25 04:41:53.037100','read_file',NULL,NULL),(722,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"boop\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/boop\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607484774.6155019, \"mtime\": 1607484774.6155019, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop:1607484774.6155019\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file boop.\", \"pid\": 23673, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": \"read_file\", \"timestamp\": 1648158113.078701, \"user_message\": \"Materialized value log_file boop.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:53.078701','read_file','[\"log_file\", \"boop\"]',NULL),(723,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop:1607484774.6155019\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23673, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": \"read_file\", \"timestamp\": 1648158113.1641998, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:53.164200','read_file',NULL,NULL),(724,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop:1607484774.6155019\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23673, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": \"read_file\", \"timestamp\": 1648158113.230518, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:53.230518','read_file',NULL,NULL),(725,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 223.0520600000001}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop:1607484774.6155019\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 223ms.\", \"pid\": 23673, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": \"read_file\", \"timestamp\": 1648158113.259856, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 223ms.\"}','STEP_SUCCESS','2022-03-25 04:41:53.259856','read_file',NULL,NULL),(726,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23673\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23673) in 431ms\", \"pid\": 23673, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": null, \"timestamp\": 1648158113.293314, \"user_message\": \"Finished steps in process (pid: 23673) in 431ms\"}','ENGINE_EVENT','2022-03-25 04:41:53.293314',NULL,NULL,NULL),(727,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23673, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": null, \"timestamp\": 1648158113.327989, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:53.327989',NULL,NULL,NULL),(728,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23673).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"step_key\": null, \"timestamp\": 1648158113.433415, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:53.433415',NULL,NULL,NULL),(729,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23680\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23680).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": null, \"timestamp\": 1648158113.7611148, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:53.761115',NULL,NULL,NULL),(730,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": null, \"timestamp\": 1648158114.059176, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:54.059176',NULL,NULL,NULL),(731,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23680, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": null, \"timestamp\": 1648158115.316679, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:55.316679',NULL,NULL,NULL),(732,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23680\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23680)\", \"pid\": 23680, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": null, \"timestamp\": 1648158115.4557922, \"user_message\": \"Executing steps in process (pid: 23680)\"}','ENGINE_EVENT','2022-03-25 04:41:55.455792',NULL,NULL,NULL),(733,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23680, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": \"read_file\", \"timestamp\": 1648158115.490338, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:55.490338','read_file',NULL,NULL),(734,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.04ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23680, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": \"read_file\", \"timestamp\": 1648158115.529581, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:55.529581','read_file',NULL,NULL),(735,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxxxffff:1607996899.666524\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23680, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": \"read_file\", \"timestamp\": 1648158115.5832589, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:55.583259','read_file',NULL,NULL),(736,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxxxffff:1607996899.666524\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23680, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": \"read_file\", \"timestamp\": 1648158115.630259, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:55.630259','read_file',NULL,NULL),(737,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": \"read_file\", \"timestamp\": 1648158115.659679, \"user_message\": \"Found file bxxxxffff\"}',NULL,'2022-03-25 04:41:55.659679','read_file',NULL,NULL),(738,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bxxxxffff\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bxxxxffff\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607996899.666524, \"mtime\": 1607996899.666524, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxxxffff:1607996899.666524\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file bxxxxffff.\", \"pid\": 23680, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": \"read_file\", \"timestamp\": 1648158115.705127, \"user_message\": \"Materialized value log_file bxxxxffff.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:55.705127','read_file','[\"log_file\", \"bxxxxffff\"]',NULL),(739,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxxxffff:1607996899.666524\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23680, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": \"read_file\", \"timestamp\": 1648158115.784487, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:55.784487','read_file',NULL,NULL),(740,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxxxffff:1607996899.666524\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23680, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": \"read_file\", \"timestamp\": 1648158115.8115351, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:55.811535','read_file',NULL,NULL),(741,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 177.15447100000014}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxxxffff:1607996899.666524\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 177ms.\", \"pid\": 23680, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": \"read_file\", \"timestamp\": 1648158115.83651, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 177ms.\"}','STEP_SUCCESS','2022-03-25 04:41:55.836510','read_file',NULL,NULL),(742,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23680\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23680) in 397ms\", \"pid\": 23680, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": null, \"timestamp\": 1648158115.8841422, \"user_message\": \"Finished steps in process (pid: 23680) in 397ms\"}','ENGINE_EVENT','2022-03-25 04:41:55.884142',NULL,NULL,NULL),(743,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23680, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": null, \"timestamp\": 1648158115.911474, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:55.911474',NULL,NULL,NULL),(744,'16362f52-dd3d-43a5-be74-2bd3d3bca219','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23680).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"step_key\": null, \"timestamp\": 1648158116.057771, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:56.057771',NULL,NULL,NULL),(745,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23687\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23687).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": null, \"timestamp\": 1648158116.286651, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:56.286651',NULL,NULL,NULL),(746,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": null, \"timestamp\": 1648158116.560246, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:56.560246',NULL,NULL,NULL),(747,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23687, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": null, \"timestamp\": 1648158117.785395, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:41:57.785395',NULL,NULL,NULL),(748,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23687\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23687)\", \"pid\": 23687, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": null, \"timestamp\": 1648158117.928457, \"user_message\": \"Executing steps in process (pid: 23687)\"}','ENGINE_EVENT','2022-03-25 04:41:57.928457',NULL,NULL,NULL),(749,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23687, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": \"read_file\", \"timestamp\": 1648158117.963954, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:57.963954','read_file',NULL,NULL),(750,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.05ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23687, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": \"read_file\", \"timestamp\": 1648158118.00863, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:41:58.008630','read_file',NULL,NULL),(751,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'blahfjfjf:1606840555.9826365\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23687, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": \"read_file\", \"timestamp\": 1648158118.059743, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:41:58.059743','read_file',NULL,NULL),(752,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'blahfjfjf:1606840555.9826365\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23687, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": \"read_file\", \"timestamp\": 1648158118.1087391, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:41:58.108739','read_file',NULL,NULL),(753,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": \"read_file\", \"timestamp\": 1648158118.1357682, \"user_message\": \"Found file blahfjfjf\"}',NULL,'2022-03-25 04:41:58.135768','read_file',NULL,NULL),(754,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"blahfjfjf\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/blahfjfjf\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1606840555.9826365, \"mtime\": 1606840555.9826365, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'blahfjfjf:1606840555.9826365\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file blahfjfjf.\", \"pid\": 23687, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": \"read_file\", \"timestamp\": 1648158118.180158, \"user_message\": \"Materialized value log_file blahfjfjf.\"}','ASSET_MATERIALIZATION','2022-03-25 04:41:58.180158','read_file','[\"log_file\", \"blahfjfjf\"]',NULL),(755,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'blahfjfjf:1606840555.9826365\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23687, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": \"read_file\", \"timestamp\": 1648158118.2769642, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:41:58.276964','read_file',NULL,NULL),(756,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'blahfjfjf:1606840555.9826365\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23687, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": \"read_file\", \"timestamp\": 1648158118.3090072, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:41:58.309007','read_file',NULL,NULL),(757,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 200.20796900000005}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'blahfjfjf:1606840555.9826365\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 200ms.\", \"pid\": 23687, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": \"read_file\", \"timestamp\": 1648158118.335681, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 200ms.\"}','STEP_SUCCESS','2022-03-25 04:41:58.335681','read_file',NULL,NULL),(758,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23687\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23687) in 424ms\", \"pid\": 23687, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": null, \"timestamp\": 1648158118.3847628, \"user_message\": \"Finished steps in process (pid: 23687) in 424ms\"}','ENGINE_EVENT','2022-03-25 04:41:58.384763',NULL,NULL,NULL),(759,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23687, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": null, \"timestamp\": 1648158118.4126348, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:41:58.412635',NULL,NULL,NULL),(760,'a395a21d-4197-4952-914d-039258b35b4e','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23687).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"step_key\": null, \"timestamp\": 1648158118.531363, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:58.531363',NULL,NULL,NULL),(761,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23856\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23856).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": null, \"timestamp\": 1648158118.71216, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:41:58.712160',NULL,NULL,NULL),(762,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": null, \"timestamp\": 1648158119.0583968, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:41:59.058397',NULL,NULL,NULL),(763,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23856, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": null, \"timestamp\": 1648158120.215808, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:42:00.215808',NULL,NULL,NULL),(764,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23856\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23856)\", \"pid\": 23856, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": null, \"timestamp\": 1648158120.358231, \"user_message\": \"Executing steps in process (pid: 23856)\"}','ENGINE_EVENT','2022-03-25 04:42:00.358231',NULL,NULL,NULL),(765,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23856, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": \"read_file\", \"timestamp\": 1648158120.388078, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:00.388078','read_file',NULL,NULL),(766,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.04ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23856, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": \"read_file\", \"timestamp\": 1648158120.4282491, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:00.428249','read_file',NULL,NULL),(767,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop3:1607484790.7801318\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23856, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": \"read_file\", \"timestamp\": 1648158120.4841971, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:42:00.484197','read_file',NULL,NULL),(768,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop3:1607484790.7801318\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23856, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": \"read_file\", \"timestamp\": 1648158120.53304, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:42:00.533040','read_file',NULL,NULL),(769,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": \"read_file\", \"timestamp\": 1648158120.559415, \"user_message\": \"Found file boop3\"}',NULL,'2022-03-25 04:42:00.559415','read_file',NULL,NULL),(770,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"boop3\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/boop3\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607484790.7801318, \"mtime\": 1607484790.7801318, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop3:1607484790.7801318\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file boop3.\", \"pid\": 23856, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": \"read_file\", \"timestamp\": 1648158120.5870788, \"user_message\": \"Materialized value log_file boop3.\"}','ASSET_MATERIALIZATION','2022-03-25 04:42:00.587079','read_file','[\"log_file\", \"boop3\"]',NULL),(771,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop3:1607484790.7801318\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23856, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": \"read_file\", \"timestamp\": 1648158120.685963, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:00.685963','read_file',NULL,NULL),(772,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop3:1607484790.7801318\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23856, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": \"read_file\", \"timestamp\": 1648158120.726532, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:00.726532','read_file',NULL,NULL),(773,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 199.00048100000012}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop3:1607484790.7801318\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 199ms.\", \"pid\": 23856, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": \"read_file\", \"timestamp\": 1648158120.758101, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 199ms.\"}','STEP_SUCCESS','2022-03-25 04:42:00.758101','read_file',NULL,NULL),(774,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23856\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23856) in 405ms\", \"pid\": 23856, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": null, \"timestamp\": 1648158120.7899451, \"user_message\": \"Finished steps in process (pid: 23856) in 405ms\"}','ENGINE_EVENT','2022-03-25 04:42:00.789945',NULL,NULL,NULL),(775,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23856, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": null, \"timestamp\": 1648158120.82898, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:42:00.828980',NULL,NULL,NULL),(776,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23856).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"step_key\": null, \"timestamp\": 1648158120.9318368, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:00.931837',NULL,NULL,NULL),(777,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23863\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23863).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": null, \"timestamp\": 1648158121.161251, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:01.161251',NULL,NULL,NULL),(778,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": null, \"timestamp\": 1648158121.6609228, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:42:01.660923',NULL,NULL,NULL),(779,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": null, \"timestamp\": 1648158121.832454, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:42:01.832454',NULL,NULL,NULL),(780,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23863, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": null, \"timestamp\": 1648158122.6878211, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:42:02.687821',NULL,NULL,NULL),(781,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23863\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23863)\", \"pid\": 23863, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": null, \"timestamp\": 1648158122.829043, \"user_message\": \"Executing steps in process (pid: 23863)\"}','ENGINE_EVENT','2022-03-25 04:42:02.829043',NULL,NULL,NULL),(782,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23863, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": \"read_file\", \"timestamp\": 1648158122.866202, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:02.866202','read_file',NULL,NULL),(783,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.04ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23863, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": \"read_file\", \"timestamp\": 1648158122.908727, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:02.908727','read_file',NULL,NULL),(784,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'booppppppp:1607487856.5426033\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23863, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": \"read_file\", \"timestamp\": 1648158122.9599948, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:42:02.959995','read_file',NULL,NULL),(785,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'booppppppp:1607487856.5426033\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23863, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": \"read_file\", \"timestamp\": 1648158123.010394, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:42:03.010394','read_file',NULL,NULL),(786,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": \"read_file\", \"timestamp\": 1648158123.037374, \"user_message\": \"Found file booppppppp\"}',NULL,'2022-03-25 04:42:03.037374','read_file',NULL,NULL),(787,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"booppppppp\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/booppppppp\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607487856.5426033, \"mtime\": 1607487856.5426033, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'booppppppp:1607487856.5426033\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file booppppppp.\", \"pid\": 23863, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": \"read_file\", \"timestamp\": 1648158123.0792189, \"user_message\": \"Materialized value log_file booppppppp.\"}','ASSET_MATERIALIZATION','2022-03-25 04:42:03.079219','read_file','[\"log_file\", \"booppppppp\"]',NULL),(788,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'booppppppp:1607487856.5426033\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23863, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": \"read_file\", \"timestamp\": 1648158123.180717, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:03.180717','read_file',NULL,NULL),(789,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'booppppppp:1607487856.5426033\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23863, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": \"read_file\", \"timestamp\": 1648158123.2114382, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:03.211438','read_file',NULL,NULL),(790,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 219.01684000000012}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'booppppppp:1607487856.5426033\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 219ms.\", \"pid\": 23863, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": \"read_file\", \"timestamp\": 1648158123.256125, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 219ms.\"}','STEP_SUCCESS','2022-03-25 04:42:03.256125','read_file',NULL,NULL),(791,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23863\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23863) in 428ms\", \"pid\": 23863, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": null, \"timestamp\": 1648158123.289678, \"user_message\": \"Finished steps in process (pid: 23863) in 428ms\"}','ENGINE_EVENT','2022-03-25 04:42:03.289678',NULL,NULL,NULL),(792,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23863, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": null, \"timestamp\": 1648158123.329005, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:42:03.329005',NULL,NULL,NULL),(793,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23863).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"step_key\": null, \"timestamp\": 1648158123.433045, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:03.433045',NULL,NULL,NULL),(794,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23870\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23870).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": null, \"timestamp\": 1648158124.2061582, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:04.206158',NULL,NULL,NULL),(795,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23871\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23871).\", \"pid\": null, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": null, \"timestamp\": 1648158124.280145, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:04.280145',NULL,NULL,NULL),(796,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": null, \"timestamp\": 1648158124.657418, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:42:04.657418',NULL,NULL,NULL),(797,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23870, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": null, \"timestamp\": 1648158125.785954, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:42:05.785954',NULL,NULL,NULL),(798,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"unreliable_pipeline\\\".\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": null, \"timestamp\": 1648158125.8494642, \"user_message\": \"Started execution of run for \\\"unreliable_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:42:05.849464',NULL,NULL,NULL),(799,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23870\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23870)\", \"pid\": 23870, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": null, \"timestamp\": 1648158125.9346812, \"user_message\": \"Executing steps in process (pid: 23870)\"}','ENGINE_EVENT','2022-03-25 04:42:05.934681',NULL,NULL,NULL),(800,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23870, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": \"read_file\", \"timestamp\": 1648158125.9678679, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:05.967868','read_file',NULL,NULL),(801,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23871\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'unreliable_start\', \'one\', \'two\', \'three\', \'four\', \'five\', \'six\', \'seven\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23871)\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": null, \"timestamp\": 1648158125.988121, \"user_message\": \"Executing steps in process (pid: 23871)\"}','ENGINE_EVENT','2022-03-25 04:42:05.988121',NULL,NULL,NULL),(802,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.06ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23870, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": \"read_file\", \"timestamp\": 1648158126.008986, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:06.008986','read_file',NULL,NULL),(803,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": null, \"timestamp\": 1648158126.037622, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:06.037622',NULL,NULL,NULL),(804,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.fs_io_manager\", \"name\": \"PickledObjectFilesystemIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.07ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": null, \"timestamp\": 1648158126.0810208, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:06.081021',NULL,NULL,NULL),(805,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxxxf:1607635587.0286214\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23870, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": \"read_file\", \"timestamp\": 1648158126.0617821, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:42:06.061782','read_file',NULL,NULL),(806,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxxxf:1607635587.0286214\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23870, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": \"read_file\", \"timestamp\": 1648158126.110323, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:42:06.110323','read_file',NULL,NULL),(807,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"unreliable_start\", \"step_keys\": [\"unreliable_start\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"unreliable_start\", \"step_key\": \"unreliable_start\"}, \"message\": \"Started capturing logs for step: unreliable_start.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"unreliable_start\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}}, \"step_key\": \"unreliable_start\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"unreliable_start\", \"timestamp\": 1648158126.134538, \"user_message\": \"Started capturing logs for step: unreliable_start.\"}','LOGS_CAPTURED','2022-03-25 04:42:06.134538','unreliable_start',NULL,NULL),(808,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": \"read_file\", \"timestamp\": 1648158126.158514, \"user_message\": \"Found file bxxxxf\"}',NULL,'2022-03-25 04:42:06.158514','read_file',NULL,NULL),(809,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"unreliable_start\", \"step_key\": \"unreliable_start\"}, \"message\": \"Started execution of step \\\"unreliable_start\\\".\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"unreliable_start\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}}, \"step_key\": \"unreliable_start\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"unreliable_start\", \"timestamp\": 1648158126.1835022, \"user_message\": \"Started execution of step \\\"unreliable_start\\\".\"}','STEP_START','2022-03-25 04:42:06.183502','unreliable_start',NULL,NULL),(810,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bxxxxf\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bxxxxf\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607635587.0286214, \"mtime\": 1607635587.0286214, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxxxf:1607635587.0286214\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file bxxxxf.\", \"pid\": 23870, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": \"read_file\", \"timestamp\": 1648158126.1870341, \"user_message\": \"Materialized value log_file bxxxxf.\"}','ASSET_MATERIALIZATION','2022-03-25 04:42:06.187034','read_file','[\"log_file\", \"bxxxxf\"]',NULL),(811,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"unreliable_start\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"unreliable_start\", \"step_key\": \"unreliable_start\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"unreliable_start\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}}, \"step_key\": \"unreliable_start\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"unreliable_start\", \"timestamp\": 1648158126.213291, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:06.213291','unreliable_start',NULL,NULL),(812,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"unreliable_start\", \"timestamp\": 1648158126.25924, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/unreliable_start/result\"}',NULL,'2022-03-25 04:42:06.259240','unreliable_start',NULL,NULL),(813,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxxxf:1607635587.0286214\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23870, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": \"read_file\", \"timestamp\": 1648158126.287196, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:06.287196','read_file',NULL,NULL),(814,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"unreliable_start\", \"step_key\": \"unreliable_start\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"unreliable_start\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}}, \"step_key\": \"unreliable_start\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"unreliable_start\", \"timestamp\": 1648158126.286253, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:06.286253','unreliable_start',NULL,NULL),(815,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 117.93441699999985}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"unreliable_start\", \"step_key\": \"unreliable_start\"}, \"message\": \"Finished execution of step \\\"unreliable_start\\\" in 117ms.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"unreliable_start\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"unreliable_start\", \"parent\": null}}, \"step_key\": \"unreliable_start\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"unreliable_start\", \"timestamp\": 1648158126.330196, \"user_message\": \"Finished execution of step \\\"unreliable_start\\\" in 117ms.\"}','STEP_SUCCESS','2022-03-25 04:42:06.330196','unreliable_start',NULL,NULL),(816,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxxxf:1607635587.0286214\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23870, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": \"read_file\", \"timestamp\": 1648158126.330266, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:06.330266','read_file',NULL,NULL),(817,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 200.85802500000005}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxxxf:1607635587.0286214\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 200ms.\", \"pid\": 23870, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": \"read_file\", \"timestamp\": 1648158126.359097, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 200ms.\"}','STEP_SUCCESS','2022-03-25 04:42:06.359097','read_file',NULL,NULL),(818,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23870\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23870) in 428ms\", \"pid\": 23870, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": null, \"timestamp\": 1648158126.393143, \"user_message\": \"Finished steps in process (pid: 23870) in 428ms\"}','ENGINE_EVENT','2022-03-25 04:42:06.393143',NULL,NULL,NULL),(819,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"one\", \"step_keys\": [\"one\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Started capturing logs for step: one.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"one\", \"timestamp\": 1648158126.3867981, \"user_message\": \"Started capturing logs for step: one.\"}','LOGS_CAPTURED','2022-03-25 04:42:06.386798','one',NULL,NULL),(820,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23870, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": null, \"timestamp\": 1648158126.42994, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:42:06.429940',NULL,NULL,NULL),(821,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Started execution of step \\\"one\\\".\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"one\", \"timestamp\": 1648158126.432641, \"user_message\": \"Started execution of step \\\"one\\\".\"}','STEP_START','2022-03-25 04:42:06.432641','one',NULL,NULL),(822,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"one\", \"timestamp\": 1648158126.4617758, \"user_message\": \"Loading file from: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/unreliable_start/result\"}',NULL,'2022-03-25 04:42:06.461776','one',NULL,NULL),(823,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"LoadedInputData\", \"input_name\": \"num\", \"manager_key\": \"io_manager\", \"upstream_output_name\": \"result\", \"upstream_step_key\": \"unreliable_start\"}, \"event_type_value\": \"LOADED_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"unreliable_start\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"one\", \"timestamp\": 1648158126.5065129, \"user_message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"unreliable_start\\\"\"}','LOADED_INPUT','2022-03-25 04:42:06.506513','one',NULL,NULL),(824,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepInputData\", \"input_name\": \"num\", \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"num\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"one\", \"timestamp\": 1648158126.534486, \"user_message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_INPUT','2022-03-25 04:42:06.534486','one',NULL,NULL),(825,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23870).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"step_key\": null, \"timestamp\": 1648158126.556042, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:06.556042',NULL,NULL,NULL),(826,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"one\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"one\", \"timestamp\": 1648158126.563421, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:06.563421','one',NULL,NULL),(827,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"one\", \"timestamp\": 1648158126.607866, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/one/result\"}',NULL,'2022-03-25 04:42:06.607866','one',NULL,NULL),(828,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"one\", \"timestamp\": 1648158126.636852, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:06.636852','one',NULL,NULL),(829,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 121.2969890000002}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"one\", \"step_key\": \"one\"}, \"message\": \"Finished execution of step \\\"one\\\" in 121ms.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"one\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"one\", \"parent\": null}}, \"step_key\": \"one\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"one\", \"timestamp\": 1648158126.684087, \"user_message\": \"Finished execution of step \\\"one\\\" in 121ms.\"}','STEP_SUCCESS','2022-03-25 04:42:06.684087','one',NULL,NULL),(830,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"two\", \"step_keys\": [\"two\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Started capturing logs for step: two.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"two\", \"timestamp\": 1648158126.7458801, \"user_message\": \"Started capturing logs for step: two.\"}','LOGS_CAPTURED','2022-03-25 04:42:06.745880','two',NULL,NULL),(831,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Started execution of step \\\"two\\\".\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"two\", \"timestamp\": 1648158126.786262, \"user_message\": \"Started execution of step \\\"two\\\".\"}','STEP_START','2022-03-25 04:42:06.786262','two',NULL,NULL),(832,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"two\", \"timestamp\": 1648158126.833597, \"user_message\": \"Loading file from: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/one/result\"}',NULL,'2022-03-25 04:42:06.833597','two',NULL,NULL),(833,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"LoadedInputData\", \"input_name\": \"num\", \"manager_key\": \"io_manager\", \"upstream_output_name\": \"result\", \"upstream_step_key\": \"one\"}, \"event_type_value\": \"LOADED_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"one\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"two\", \"timestamp\": 1648158126.86438, \"user_message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"one\\\"\"}','LOADED_INPUT','2022-03-25 04:42:06.864380','two',NULL,NULL),(834,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepInputData\", \"input_name\": \"num\", \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"num\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"two\", \"timestamp\": 1648158126.9097102, \"user_message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_INPUT','2022-03-25 04:42:06.909710','two',NULL,NULL),(835,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"two\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"two\", \"timestamp\": 1648158126.956139, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:06.956139','two',NULL,NULL),(836,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"two\", \"timestamp\": 1648158126.984703, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/two/result\"}',NULL,'2022-03-25 04:42:06.984703','two',NULL,NULL),(837,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23899\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 23899).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": null, \"timestamp\": 1648158127.0061069, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:07.006107',NULL,NULL,NULL),(838,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"two\", \"timestamp\": 1648158127.0122712, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:07.012271','two',NULL,NULL),(839,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 100.0225420000005}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"two\", \"step_key\": \"two\"}, \"message\": \"Finished execution of step \\\"two\\\" in 100ms.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"two\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"two\", \"parent\": null}}, \"step_key\": \"two\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"two\", \"timestamp\": 1648158127.055551, \"user_message\": \"Finished execution of step \\\"two\\\" in 100ms.\"}','STEP_SUCCESS','2022-03-25 04:42:07.055551','two',NULL,NULL),(840,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"three\", \"step_keys\": [\"three\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Started capturing logs for step: three.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"three\", \"timestamp\": 1648158127.110379, \"user_message\": \"Started capturing logs for step: three.\"}','LOGS_CAPTURED','2022-03-25 04:42:07.110379','three',NULL,NULL),(841,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Started execution of step \\\"three\\\".\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"three\", \"timestamp\": 1648158127.162, \"user_message\": \"Started execution of step \\\"three\\\".\"}','STEP_START','2022-03-25 04:42:07.162000','three',NULL,NULL),(842,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"three\", \"timestamp\": 1648158127.211676, \"user_message\": \"Loading file from: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/two/result\"}',NULL,'2022-03-25 04:42:07.211676','three',NULL,NULL),(843,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"LoadedInputData\", \"input_name\": \"num\", \"manager_key\": \"io_manager\", \"upstream_output_name\": \"result\", \"upstream_step_key\": \"two\"}, \"event_type_value\": \"LOADED_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"two\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"three\", \"timestamp\": 1648158127.257233, \"user_message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"two\\\"\"}','LOADED_INPUT','2022-03-25 04:42:07.257233','three',NULL,NULL),(844,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepInputData\", \"input_name\": \"num\", \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"num\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"three\", \"timestamp\": 1648158127.287657, \"user_message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_INPUT','2022-03-25 04:42:07.287657','three',NULL,NULL),(845,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"three\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"three\", \"timestamp\": 1648158127.33124, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:07.331240','three',NULL,NULL),(846,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"three\", \"timestamp\": 1648158127.359105, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/three/result\"}',NULL,'2022-03-25 04:42:07.359105','three',NULL,NULL),(847,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": null, \"timestamp\": 1648158127.383615, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:42:07.383615',NULL,NULL,NULL),(848,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"three\", \"timestamp\": 1648158127.38638, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:07.386380','three',NULL,NULL),(849,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 101.09246800000005}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"three\", \"step_key\": \"three\"}, \"message\": \"Finished execution of step \\\"three\\\" in 101ms.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"three\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"three\", \"parent\": null}}, \"step_key\": \"three\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"three\", \"timestamp\": 1648158127.4312692, \"user_message\": \"Finished execution of step \\\"three\\\" in 101ms.\"}','STEP_SUCCESS','2022-03-25 04:42:07.431269','three',NULL,NULL),(850,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"four\", \"step_keys\": [\"four\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"four\", \"step_key\": \"four\"}, \"message\": \"Started capturing logs for step: four.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"four\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}}, \"step_key\": \"four\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"four\", \"timestamp\": 1648158127.4867682, \"user_message\": \"Started capturing logs for step: four.\"}','LOGS_CAPTURED','2022-03-25 04:42:07.486768','four',NULL,NULL),(851,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"four\", \"step_key\": \"four\"}, \"message\": \"Started execution of step \\\"four\\\".\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"four\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}}, \"step_key\": \"four\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"four\", \"timestamp\": 1648158127.5323389, \"user_message\": \"Started execution of step \\\"four\\\".\"}','STEP_START','2022-03-25 04:42:07.532339','four',NULL,NULL),(852,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"four\", \"timestamp\": 1648158127.56024, \"user_message\": \"Loading file from: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/three/result\"}',NULL,'2022-03-25 04:42:07.560240','four',NULL,NULL),(853,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"LoadedInputData\", \"input_name\": \"num\", \"manager_key\": \"io_manager\", \"upstream_output_name\": \"result\", \"upstream_step_key\": \"three\"}, \"event_type_value\": \"LOADED_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"four\", \"step_key\": \"four\"}, \"message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"three\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"four\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}}, \"step_key\": \"four\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"four\", \"timestamp\": 1648158127.587084, \"user_message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"three\\\"\"}','LOADED_INPUT','2022-03-25 04:42:07.587084','four',NULL,NULL),(854,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepInputData\", \"input_name\": \"num\", \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"num\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"four\", \"step_key\": \"four\"}, \"message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"four\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}}, \"step_key\": \"four\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"four\", \"timestamp\": 1648158127.62922, \"user_message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_INPUT','2022-03-25 04:42:07.629220','four',NULL,NULL),(855,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"four\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"four\", \"step_key\": \"four\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"four\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}}, \"step_key\": \"four\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"four\", \"timestamp\": 1648158127.6601632, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:07.660163','four',NULL,NULL),(856,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"four\", \"timestamp\": 1648158127.713855, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/four/result\"}',NULL,'2022-03-25 04:42:07.713855','four',NULL,NULL),(857,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"four\", \"step_key\": \"four\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"four\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}}, \"step_key\": \"four\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"four\", \"timestamp\": 1648158127.7574232, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:07.757423','four',NULL,NULL),(858,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 126.23474499999965}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"four\", \"step_key\": \"four\"}, \"message\": \"Finished execution of step \\\"four\\\" in 126ms.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"four\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"four\", \"parent\": null}}, \"step_key\": \"four\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"four\", \"timestamp\": 1648158127.78565, \"user_message\": \"Finished execution of step \\\"four\\\" in 126ms.\"}','STEP_SUCCESS','2022-03-25 04:42:07.785650','four',NULL,NULL),(859,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"five\", \"step_keys\": [\"five\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"five\", \"step_key\": \"five\"}, \"message\": \"Started capturing logs for step: five.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"five\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}}, \"step_key\": \"five\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"five\", \"timestamp\": 1648158127.8592792, \"user_message\": \"Started capturing logs for step: five.\"}','LOGS_CAPTURED','2022-03-25 04:42:07.859279','five',NULL,NULL),(860,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"five\", \"step_key\": \"five\"}, \"message\": \"Started execution of step \\\"five\\\".\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"five\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}}, \"step_key\": \"five\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"five\", \"timestamp\": 1648158127.909385, \"user_message\": \"Started execution of step \\\"five\\\".\"}','STEP_START','2022-03-25 04:42:07.909385','five',NULL,NULL),(861,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"five\", \"timestamp\": 1648158127.938839, \"user_message\": \"Loading file from: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/four/result\"}',NULL,'2022-03-25 04:42:07.938839','five',NULL,NULL),(862,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"LoadedInputData\", \"input_name\": \"num\", \"manager_key\": \"io_manager\", \"upstream_output_name\": \"result\", \"upstream_step_key\": \"four\"}, \"event_type_value\": \"LOADED_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"five\", \"step_key\": \"five\"}, \"message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"four\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"five\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}}, \"step_key\": \"five\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"five\", \"timestamp\": 1648158127.979873, \"user_message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"four\\\"\"}','LOADED_INPUT','2022-03-25 04:42:07.979873','five',NULL,NULL),(863,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepInputData\", \"input_name\": \"num\", \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"num\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"five\", \"step_key\": \"five\"}, \"message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"five\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}}, \"step_key\": \"five\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"five\", \"timestamp\": 1648158128.009305, \"user_message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_INPUT','2022-03-25 04:42:08.009305','five',NULL,NULL),(864,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"five\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"five\", \"step_key\": \"five\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"five\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}}, \"step_key\": \"five\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"five\", \"timestamp\": 1648158128.038474, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:08.038474','five',NULL,NULL),(865,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"five\", \"timestamp\": 1648158128.079031, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/five/result\"}',NULL,'2022-03-25 04:42:08.079031','five',NULL,NULL),(866,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"five\", \"step_key\": \"five\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"five\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}}, \"step_key\": \"five\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"five\", \"timestamp\": 1648158128.109138, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:08.109138','five',NULL,NULL),(867,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 99.27439700000029}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"five\", \"step_key\": \"five\"}, \"message\": \"Finished execution of step \\\"five\\\" in 99ms.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"five\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"five\", \"parent\": null}}, \"step_key\": \"five\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"five\", \"timestamp\": 1648158128.13709, \"user_message\": \"Finished execution of step \\\"five\\\" in 99ms.\"}','STEP_SUCCESS','2022-03-25 04:42:08.137090','five',NULL,NULL),(868,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"six\", \"step_keys\": [\"six\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"six\", \"step_key\": \"six\"}, \"message\": \"Started capturing logs for step: six.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"six\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}}, \"step_key\": \"six\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"six\", \"timestamp\": 1648158128.206429, \"user_message\": \"Started capturing logs for step: six.\"}','LOGS_CAPTURED','2022-03-25 04:42:08.206429','six',NULL,NULL),(869,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"six\", \"step_key\": \"six\"}, \"message\": \"Started execution of step \\\"six\\\".\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"six\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}}, \"step_key\": \"six\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"six\", \"timestamp\": 1648158128.255821, \"user_message\": \"Started execution of step \\\"six\\\".\"}','STEP_START','2022-03-25 04:42:08.255821','six',NULL,NULL),(870,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"six\", \"timestamp\": 1648158128.2844212, \"user_message\": \"Loading file from: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/five/result\"}',NULL,'2022-03-25 04:42:08.284421','six',NULL,NULL),(871,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"LoadedInputData\", \"input_name\": \"num\", \"manager_key\": \"io_manager\", \"upstream_output_name\": \"result\", \"upstream_step_key\": \"five\"}, \"event_type_value\": \"LOADED_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"six\", \"step_key\": \"six\"}, \"message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"five\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"six\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}}, \"step_key\": \"six\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"six\", \"timestamp\": 1648158128.313886, \"user_message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"five\\\"\"}','LOADED_INPUT','2022-03-25 04:42:08.313886','six',NULL,NULL),(872,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepInputData\", \"input_name\": \"num\", \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"num\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"six\", \"step_key\": \"six\"}, \"message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"six\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}}, \"step_key\": \"six\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"six\", \"timestamp\": 1648158128.359186, \"user_message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_INPUT','2022-03-25 04:42:08.359186','six',NULL,NULL),(873,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"six\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"six\", \"step_key\": \"six\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"six\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}}, \"step_key\": \"six\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"six\", \"timestamp\": 1648158128.3890638, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:08.389064','six',NULL,NULL),(874,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"six\", \"timestamp\": 1648158128.431513, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/six/result\"}',NULL,'2022-03-25 04:42:08.431513','six',NULL,NULL),(875,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"six\", \"step_key\": \"six\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"six\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}}, \"step_key\": \"six\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"six\", \"timestamp\": 1648158128.4588459, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:08.458846','six',NULL,NULL),(876,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 98.14411799999957}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"six\", \"step_key\": \"six\"}, \"message\": \"Finished execution of step \\\"six\\\" in 98ms.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"six\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"six\", \"parent\": null}}, \"step_key\": \"six\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"six\", \"timestamp\": 1648158128.486588, \"user_message\": \"Finished execution of step \\\"six\\\" in 98ms.\"}','STEP_SUCCESS','2022-03-25 04:42:08.486588','six',NULL,NULL),(877,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"seven\", \"step_keys\": [\"seven\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"seven\", \"step_key\": \"seven\"}, \"message\": \"Started capturing logs for step: seven.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"seven\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}}, \"step_key\": \"seven\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"seven\", \"timestamp\": 1648158128.554999, \"user_message\": \"Started capturing logs for step: seven.\"}','LOGS_CAPTURED','2022-03-25 04:42:08.554999','seven',NULL,NULL),(878,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"seven\", \"step_key\": \"seven\"}, \"message\": \"Started execution of step \\\"seven\\\".\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"seven\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}}, \"step_key\": \"seven\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"seven\", \"timestamp\": 1648158128.5885282, \"user_message\": \"Started execution of step \\\"seven\\\".\"}','STEP_START','2022-03-25 04:42:08.588528','seven',NULL,NULL),(879,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"seven\", \"timestamp\": 1648158128.631435, \"user_message\": \"Loading file from: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/six/result\"}',NULL,'2022-03-25 04:42:08.631435','seven',NULL,NULL),(880,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23899, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": null, \"timestamp\": 1648158128.6404428, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:42:08.640443',NULL,NULL,NULL),(881,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"LoadedInputData\", \"input_name\": \"num\", \"manager_key\": \"io_manager\", \"upstream_output_name\": \"result\", \"upstream_step_key\": \"six\"}, \"event_type_value\": \"LOADED_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"seven\", \"step_key\": \"seven\"}, \"message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"six\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"seven\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}}, \"step_key\": \"seven\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"seven\", \"timestamp\": 1648158128.6588402, \"user_message\": \"Loaded input \\\"num\\\" using input manager \\\"io_manager\\\", from output \\\"result\\\" of step \\\"six\\\"\"}','LOADED_INPUT','2022-03-25 04:42:08.658840','seven',NULL,NULL),(882,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepInputData\", \"input_name\": \"num\", \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"num\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_INPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"seven\", \"step_key\": \"seven\"}, \"message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"seven\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}}, \"step_key\": \"seven\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"seven\", \"timestamp\": 1648158128.6862621, \"user_message\": \"Got input \\\"num\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_INPUT','2022-03-25 04:42:08.686262','seven',NULL,NULL),(883,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"seven\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"seven\", \"step_key\": \"seven\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"seven\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}}, \"step_key\": \"seven\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"seven\", \"timestamp\": 1648158128.731041, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:08.731041','seven',NULL,NULL),(884,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"seven\", \"timestamp\": 1648158128.7594829, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/c0220f79-6278-4b74-97df-456406c27a2d/seven/result\"}',NULL,'2022-03-25 04:42:08.759483','seven',NULL,NULL),(885,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23899\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 23899)\", \"pid\": 23899, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": null, \"timestamp\": 1648158128.7845461, \"user_message\": \"Executing steps in process (pid: 23899)\"}','ENGINE_EVENT','2022-03-25 04:42:08.784546',NULL,NULL,NULL),(886,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"seven\", \"step_key\": \"seven\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"seven\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}}, \"step_key\": \"seven\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"seven\", \"timestamp\": 1648158128.786651, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:08.786651','seven',NULL,NULL),(887,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 100.12312499999965}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"unreliable_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'.dagster/scheduled_execution_time\': \'2022-03-24T21:42:00+00:00\', \'dagster/partition\': \'2020-01-12\', \'dagster/partition_set\': \'unreliable_weekly\', \'dagster/run_key\': \'2020-01-12\', \'dagster/schedule_name\': \'backfill_unreliable_weekly\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_name\": \"seven\", \"step_key\": \"seven\"}, \"message\": \"Finished execution of step \\\"seven\\\" in 100ms.\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"seven\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"seven\", \"parent\": null}}, \"step_key\": \"seven\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": \"seven\", \"timestamp\": 1648158128.830561, \"user_message\": \"Finished execution of step \\\"seven\\\" in 100ms.\"}','STEP_SUCCESS','2022-03-25 04:42:08.830561','seven',NULL,NULL),(888,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 23899, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": \"read_file\", \"timestamp\": 1648158128.8154812, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:08.815481','read_file',NULL,NULL),(889,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.05ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 23899, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": \"read_file\", \"timestamp\": 1648158128.859305, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:08.859305','read_file',NULL,NULL),(890,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23871\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'unreliable_start\', \'one\', \'two\', \'three\', \'four\', \'five\', \'six\', \'seven\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23871) in 2.83s\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": null, \"timestamp\": 1648158128.8645692, \"user_message\": \"Finished steps in process (pid: 23871) in 2.83s\"}','ENGINE_EVENT','2022-03-25 04:42:08.864569',NULL,NULL,NULL),(891,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"unreliable_pipeline\\\".\", \"pid\": 23871, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": null, \"timestamp\": 1648158128.9095318, \"user_message\": \"Finished execution of run for \\\"unreliable_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:42:08.909532',NULL,NULL,NULL),(892,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop2:1607484775.9602463\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 23899, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": \"read_file\", \"timestamp\": 1648158128.9123409, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:42:08.912341','read_file',NULL,NULL),(893,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop2:1607484775.9602463\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 23899, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": \"read_file\", \"timestamp\": 1648158128.960026, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:42:08.960026','read_file',NULL,NULL),(894,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": \"read_file\", \"timestamp\": 1648158128.988949, \"user_message\": \"Found file boop2\"}',NULL,'2022-03-25 04:42:08.988949','read_file',NULL,NULL),(895,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"boop2\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/boop2\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607484775.9602463, \"mtime\": 1607484775.9602463, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop2:1607484775.9602463\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file boop2.\", \"pid\": 23899, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": \"read_file\", \"timestamp\": 1648158129.030139, \"user_message\": \"Materialized value log_file boop2.\"}','ASSET_MATERIALIZATION','2022-03-25 04:42:09.030139','read_file','[\"log_file\", \"boop2\"]',NULL),(896,'c0220f79-6278-4b74-97df-456406c27a2d','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23871).\", \"pid\": null, \"pipeline_name\": \"unreliable_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"unreliable_pipeline\", \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"step_key\": null, \"timestamp\": 1648158129.036747, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:09.036747',NULL,NULL,NULL),(897,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop2:1607484775.9602463\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 23899, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": \"read_file\", \"timestamp\": 1648158129.11496, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:09.114960','read_file',NULL,NULL),(898,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop2:1607484775.9602463\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 23899, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": \"read_file\", \"timestamp\": 1648158129.1609, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:09.160900','read_file',NULL,NULL),(899,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 221.42740800000027}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'boop2:1607484775.9602463\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 221ms.\", \"pid\": 23899, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": \"read_file\", \"timestamp\": 1648158129.210102, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 221ms.\"}','STEP_SUCCESS','2022-03-25 04:42:09.210102','read_file',NULL,NULL),(900,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"23899\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 23899) in 453ms\", \"pid\": 23899, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": null, \"timestamp\": 1648158129.2656052, \"user_message\": \"Finished steps in process (pid: 23899) in 453ms\"}','ENGINE_EVENT','2022-03-25 04:42:09.265605',NULL,NULL,NULL),(901,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 23899, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": null, \"timestamp\": 1648158129.308743, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:42:09.308743',NULL,NULL,NULL),(902,'64cb1e86-9461-4a54-8f1b-22042d76566f','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 23899).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"step_key\": null, \"timestamp\": 1648158129.43593, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:09.435930',NULL,NULL,NULL),(903,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"24069\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 24069).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": null, \"timestamp\": 1648158129.78262, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:09.782620',NULL,NULL,NULL),(904,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": null, \"timestamp\": 1648158130.0781262, \"user_message\": \"\"}','PIPELINE_STARTING','2022-03-25 04:42:10.078126',NULL,NULL,NULL),(905,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 24069, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": null, \"timestamp\": 1648158131.268383, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:42:11.268383',NULL,NULL,NULL),(906,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"24069\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 24069)\", \"pid\": 24069, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": null, \"timestamp\": 1648158131.409704, \"user_message\": \"Executing steps in process (pid: 24069)\"}','ENGINE_EVENT','2022-03-25 04:42:11.409704',NULL,NULL,NULL),(907,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 24069, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": \"read_file\", \"timestamp\": 1648158131.44159, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:11.441590','read_file',NULL,NULL),(908,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.05ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 24069, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": \"read_file\", \"timestamp\": 1648158131.480153, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:11.480153','read_file',NULL,NULL),(909,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key:1606840644.290511\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 24069, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": \"read_file\", \"timestamp\": 1648158131.535382, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:42:11.535382','read_file',NULL,NULL),(910,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key:1606840644.290511\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 24069, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": \"read_file\", \"timestamp\": 1648158131.581588, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:42:11.581588','read_file',NULL,NULL),(911,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": \"read_file\", \"timestamp\": 1648158131.609945, \"user_message\": \"Found file show_run_key\"}',NULL,'2022-03-25 04:42:11.609945','read_file',NULL,NULL),(912,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"show_run_key\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/show_run_key\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1606840644.290511, \"mtime\": 1606840644.290511, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key:1606840644.290511\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file show_run_key.\", \"pid\": 24069, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": \"read_file\", \"timestamp\": 1648158131.6381161, \"user_message\": \"Materialized value log_file show_run_key.\"}','ASSET_MATERIALIZATION','2022-03-25 04:42:11.638116','read_file','[\"log_file\", \"show_run_key\"]',NULL),(913,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key:1606840644.290511\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 24069, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": \"read_file\", \"timestamp\": 1648158131.738142, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:11.738142','read_file',NULL,NULL),(914,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key:1606840644.290511\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 24069, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": \"read_file\", \"timestamp\": 1648158131.780051, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:11.780051','read_file',NULL,NULL),(915,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 199.72442499999988}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'show_run_key:1606840644.290511\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 199ms.\", \"pid\": 24069, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": \"read_file\", \"timestamp\": 1648158131.8093739, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 199ms.\"}','STEP_SUCCESS','2022-03-25 04:42:11.809374','read_file',NULL,NULL),(916,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"24069\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 24069) in 405ms\", \"pid\": 24069, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": null, \"timestamp\": 1648158131.8430989, \"user_message\": \"Finished steps in process (pid: 24069) in 405ms\"}','ENGINE_EVENT','2022-03-25 04:42:11.843099',NULL,NULL,NULL),(917,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 24069, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": null, \"timestamp\": 1648158131.879491, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:42:11.879491',NULL,NULL,NULL),(918,'f5ea6efb-0306-4138-af6a-1087b57f10b5','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 24069).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"step_key\": null, \"timestamp\": 1648158131.985483, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:11.985483',NULL,NULL,NULL),(919,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"24089\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 24089).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": null, \"timestamp\": 1648158132.311478, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:12.311478',NULL,NULL,NULL),(920,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 24089, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": null, \"timestamp\": 1648158133.818742, \"user_message\": \"Started execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_START','2022-03-25 04:42:13.818742',NULL,NULL,NULL),(921,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"24089\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 24089)\", \"pid\": 24089, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": null, \"timestamp\": 1648158133.98793, \"user_message\": \"Executing steps in process (pid: 24089)\"}','ENGINE_EVENT','2022-03-25 04:42:13.987930',NULL,NULL,NULL),(922,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 24089, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": \"read_file\", \"timestamp\": 1648158134.033356, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:14.033356','read_file',NULL,NULL),(923,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.mem_io_manager\", \"name\": \"InMemoryIOManager\"}, \"label\": \"io_manager\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"0.04ms\"}, \"label\": \"io_manager:init_time\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 24089, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": \"read_file\", \"timestamp\": 1648158134.061013, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-03-25 04:42:14.061013','read_file',NULL,NULL),(924,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"read_file\", \"step_keys\": [\"read_file\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxx:1607635580.3826091\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started capturing logs for step: read_file.\", \"pid\": 24089, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": \"read_file\", \"timestamp\": 1648158134.1124191, \"user_message\": \"Started capturing logs for step: read_file.\"}','LOGS_CAPTURED','2022-03-25 04:42:14.112419','read_file',NULL,NULL),(925,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxx:1607635580.3826091\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Started execution of step \\\"read_file\\\".\", \"pid\": 24089, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": \"read_file\", \"timestamp\": 1648158134.1601338, \"user_message\": \"Started execution of step \\\"read_file\\\".\"}','STEP_START','2022-03-25 04:42:14.160134','read_file',NULL,NULL),(926,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": \"read_file\", \"timestamp\": 1648158134.18523, \"user_message\": \"Found file bxxx\"}',NULL,'2022-03-25 04:42:14.185230','read_file',NULL,NULL),(927,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"log_file\", \"bxxx\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/Users/prha/dagster_sensor_data/bxxx\"}, \"label\": \"path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"ctime\": 1607635580.3826091, \"mtime\": 1607635580.3826091, \"size\": 0}}, \"label\": \"File status\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxx:1607635580.3826091\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Materialized value log_file bxxx.\", \"pid\": 24089, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": \"read_file\", \"timestamp\": 1648158134.2125592, \"user_message\": \"Materialized value log_file bxxx.\"}','ASSET_MATERIALIZATION','2022-03-25 04:42:14.212559','read_file','[\"log_file\", \"bxxx\"]',NULL),(928,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"read_file\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxx:1607635580.3826091\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 24089, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": \"read_file\", \"timestamp\": 1648158134.337952, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-03-25 04:42:14.337952','read_file',NULL,NULL),(929,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxx:1607635580.3826091\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 24089, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": \"read_file\", \"timestamp\": 1648158134.381551, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-03-25 04:42:14.381551','read_file',NULL,NULL),(930,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 224.49495200000013}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"log_file_pipeline\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\', \'dagster/run_key\': \'bxxx:1607635580.3826091\', \'dagster/sensor_name\': \'toy_file_sensor\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"solid_name\": \"read_file\", \"step_key\": \"read_file\"}, \"message\": \"Finished execution of step \\\"read_file\\\" in 224ms.\", \"pid\": 24089, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"read_file\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"read_file\", \"parent\": null}}, \"step_key\": \"read_file\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": \"read_file\", \"timestamp\": 1648158134.409419, \"user_message\": \"Finished execution of step \\\"read_file\\\" in 224ms.\"}','STEP_SUCCESS','2022-03-25 04:42:14.409419','read_file',NULL,NULL),(931,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"24089\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'read_file\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 24089) in 412ms\", \"pid\": 24089, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": null, \"timestamp\": 1648158134.4427671, \"user_message\": \"Finished steps in process (pid: 24089) in 412ms\"}','ENGINE_EVENT','2022-03-25 04:42:14.442767',NULL,NULL,NULL),(932,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\", \"pid\": 24089, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": null, \"timestamp\": 1648158134.481245, \"user_message\": \"Finished execution of run for \\\"log_file_pipeline\\\".\"}','PIPELINE_SUCCESS','2022-03-25 04:42:14.481245',NULL,NULL,NULL),(933,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 24089).\", \"pid\": null, \"pipeline_name\": \"log_file_pipeline\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"log_file_pipeline\", \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"step_key\": null, \"timestamp\": 1648158134.587135, \"user_message\": \"\"}','ENGINE_EVENT','2022-03-25 04:42:14.587135',NULL,NULL,NULL);
/*!40000 ALTER TABLE `event_logs` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `instance_info`
--

DROP TABLE IF EXISTS `instance_info`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `instance_info` (
  `run_storage_id` text
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `instance_info`
--

LOCK TABLES `instance_info` WRITE;
/*!40000 ALTER TABLE `instance_info` DISABLE KEYS */;
INSERT INTO `instance_info` VALUES ('146b2f8d-c180-490a-a830-be4d8714ea42');
/*!40000 ALTER TABLE `instance_info` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `instigators`
--

DROP TABLE IF EXISTS `instigators`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `instigators` (
  `id` int NOT NULL AUTO_INCREMENT,
  `selector_id` varchar(255) DEFAULT NULL,
  `repository_selector_id` varchar(255) DEFAULT NULL,
  `status` varchar(63) DEFAULT NULL,
  `instigator_type` varchar(63) DEFAULT NULL,
  `instigator_body` text,
  `create_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `update_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  PRIMARY KEY (`id`),
  UNIQUE KEY `selector_id` (`selector_id`),
  KEY `ix_instigators_instigator_type` (`instigator_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `instigators`
--

LOCK TABLES `instigators` WRITE;
/*!40000 ALTER TABLE `instigators` DISABLE KEYS */;
/*!40000 ALTER TABLE `instigators` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `job_ticks`
--

DROP TABLE IF EXISTS `job_ticks`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `job_ticks` (
  `id` int NOT NULL AUTO_INCREMENT,
  `job_origin_id` varchar(255) DEFAULT NULL,
  `status` varchar(63) DEFAULT NULL,
  `type` varchar(63) DEFAULT NULL,
  `timestamp` timestamp(6) NULL DEFAULT NULL,
  `tick_body` text,
  `create_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `update_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `selector_id` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `idx_job_tick_timestamp` (`job_origin_id`,`timestamp`),
  KEY `idx_job_tick_status` (`job_origin_id`(32),`status`(32)),
  KEY `ix_job_ticks_job_origin_id` (`job_origin_id`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `job_ticks`
--

LOCK TABLES `job_ticks` WRITE;
/*!40000 ALTER TABLE `job_ticks` DISABLE KEYS */;
INSERT INTO `job_ticks` VALUES (1,'4ba36b86479c292cebefc94beb49c115c6b70a6b','SUCCESS','SENSOR','2022-03-25 04:41:17.314027','{\"__class__\": \"TickData\", \"cursor\": null, \"error\": null, \"failure_count\": 0, \"job_name\": \"toy_file_sensor\", \"job_origin_id\": \"4ba36b86479c292cebefc94beb49c115c6b70a6b\", \"job_type\": {\"__enum__\": \"InstigatorType.SENSOR\"}, \"origin_run_ids\": [], \"run_ids\": [\"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"f62982b8-3037-468e-a94e-032f68011e77\", \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"dc459868-808c-4476-adf7-548b1f42f45c\", \"e641587a-ac48-4a95-8208-81990c416d8d\", \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"a395a21d-4197-4952-914d-039258b35b4e\", \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\"], \"run_keys\": [\"bx_new_run_3:1609955736.963252\", \"bx_new_run_4:1610388763.2417717\", \"bx_new_run:1608060793.3515544\", \"bx_new_run_2:1608060796.9405777\", \"foooawoiefj:1645197413.2837281\", \"demo.1:1606341124.944769\", \"boopppp:1607487853.6962564\", \"blawiejfoj:1647625969.2538514\", \"b.out:1605834003.363826\", \"show_run_key_3:1606942458.8674\", \"show_run_key_2:1606840685.1579385\", \"a.out:1605833207.4776378\", \"boop:1607484774.6155019\", \"bxxxxffff:1607996899.666524\", \"blahfjfjf:1606840555.9826365\", \"boop3:1607484790.7801318\", \"booppppppp:1607487856.5426033\", \"bxxxxf:1607635587.0286214\", \"boop2:1607484775.9602463\", \"show_run_key:1606840644.290511\", \"bxxx:1607635580.3826091\"], \"skip_reason\": null, \"status\": {\"__enum__\": \"TickStatus.SUCCESS\"}, \"timestamp\": 1648158077.314027}','2022-03-24 14:41:17.363229','2022-03-24 14:41:17.363229',NULL),(2,'9f5c5a983fd26b908acfd25fa78a21d078c45992','SUCCESS','SCHEDULE','2022-03-25 04:41:00.000000','{\"__class__\": \"TickData\", \"cursor\": null, \"error\": null, \"failure_count\": 0, \"job_name\": \"backfill_unreliable_weekly\", \"job_origin_id\": \"9f5c5a983fd26b908acfd25fa78a21d078c45992\", \"job_type\": {\"__enum__\": \"InstigatorType.SCHEDULE\"}, \"origin_run_ids\": [], \"run_ids\": [\"eaa207df-08ba-4834-ae00-d0ca1e8cac71\"], \"run_keys\": [\"2020-01-05\"], \"skip_reason\": null, \"status\": {\"__enum__\": \"TickStatus.SUCCESS\"}, \"timestamp\": 1648158060.0}','2022-03-24 14:41:17.558333','2022-03-24 14:41:17.558333',NULL),(3,'9f5c5a983fd26b908acfd25fa78a21d078c45992','SUCCESS','SCHEDULE','2022-03-25 04:42:00.000000','{\"__class__\": \"TickData\", \"cursor\": null, \"error\": null, \"failure_count\": 0, \"job_name\": \"backfill_unreliable_weekly\", \"job_origin_id\": \"9f5c5a983fd26b908acfd25fa78a21d078c45992\", \"job_type\": {\"__enum__\": \"InstigatorType.SCHEDULE\"}, \"origin_run_ids\": [], \"run_ids\": [\"c0220f79-6278-4b74-97df-456406c27a2d\"], \"run_keys\": [\"2020-01-12\"], \"skip_reason\": null, \"status\": {\"__enum__\": \"TickStatus.SUCCESS\"}, \"timestamp\": 1648158120.0}','2022-03-24 14:42:01.033844','2022-03-24 14:42:01.033844',NULL),(4,'4ba36b86479c292cebefc94beb49c115c6b70a6b','SKIPPED','SENSOR','2022-03-25 04:42:12.607246','{\"__class__\": \"TickData\", \"cursor\": null, \"error\": null, \"failure_count\": 0, \"job_name\": \"toy_file_sensor\", \"job_origin_id\": \"4ba36b86479c292cebefc94beb49c115c6b70a6b\", \"job_type\": {\"__enum__\": \"InstigatorType.SENSOR\"}, \"origin_run_ids\": [], \"run_ids\": [], \"run_keys\": [\"bx_new_run_3:1609955736.963252\", \"bx_new_run_4:1610388763.2417717\", \"bx_new_run:1608060793.3515544\", \"bx_new_run_2:1608060796.9405777\", \"foooawoiefj:1645197413.2837281\", \"demo.1:1606341124.944769\", \"boopppp:1607487853.6962564\", \"blawiejfoj:1647625969.2538514\", \"b.out:1605834003.363826\", \"show_run_key_3:1606942458.8674\", \"show_run_key_2:1606840685.1579385\", \"a.out:1605833207.4776378\", \"boop:1607484774.6155019\", \"bxxxxffff:1607996899.666524\", \"blahfjfjf:1606840555.9826365\", \"boop3:1607484790.7801318\", \"booppppppp:1607487856.5426033\", \"bxxxxf:1607635587.0286214\", \"boop2:1607484775.9602463\", \"show_run_key:1606840644.290511\", \"bxxx:1607635580.3826091\"], \"skip_reason\": null, \"status\": {\"__enum__\": \"TickStatus.SKIPPED\"}, \"timestamp\": 1648158132.607246}','2022-03-24 14:42:12.631954','2022-03-24 14:42:12.631954',NULL);
/*!40000 ALTER TABLE `job_ticks` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `jobs`
--

DROP TABLE IF EXISTS `jobs`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `jobs` (
  `id` int NOT NULL AUTO_INCREMENT,
  `job_origin_id` varchar(255) DEFAULT NULL,
  `repository_origin_id` varchar(255) DEFAULT NULL,
  `status` varchar(63) DEFAULT NULL,
  `job_type` varchar(63) DEFAULT NULL,
  `job_body` text,
  `create_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `update_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `selector_id` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `job_origin_id` (`job_origin_id`),
  KEY `ix_jobs_job_type` (`job_type`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `jobs`
--

LOCK TABLES `jobs` WRITE;
/*!40000 ALTER TABLE `jobs` DISABLE KEYS */;
INSERT INTO `jobs` VALUES (1,'9f5c5a983fd26b908acfd25fa78a21d078c45992','759314fb52acb7177eeb83563754efc24eca7950','RUNNING','SCHEDULE','{\"__class__\": \"InstigatorState\", \"job_specific_data\": {\"__class__\": \"ScheduleInstigatorData\", \"cron_schedule\": \"* * * * *\", \"start_timestamp\": 1648158058.168217}, \"job_type\": {\"__enum__\": \"InstigatorType.SCHEDULE\"}, \"origin\": {\"__class__\": \"ExternalJobOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"job_name\": \"backfill_unreliable_weekly\"}, \"status\": {\"__enum__\": \"InstigatorStatus.RUNNING\"}}','2022-03-24 14:40:58.170111','2022-03-24 14:40:58.170111',NULL),(2,'4b7b8511ef4d115c6222eb9845793f6ce1a01b86','759314fb52acb7177eeb83563754efc24eca7950','RUNNING','SCHEDULE','{\"__class__\": \"InstigatorState\", \"job_specific_data\": {\"__class__\": \"ScheduleInstigatorData\", \"cron_schedule\": \"*/5 * * * *\", \"start_timestamp\": 1648158059.711789}, \"job_type\": {\"__enum__\": \"InstigatorType.SCHEDULE\"}, \"origin\": {\"__class__\": \"ExternalJobOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"job_name\": \"longitudinal_demo\"}, \"status\": {\"__enum__\": \"InstigatorStatus.RUNNING\"}}','2022-03-24 14:40:59.712780','2022-03-24 14:40:59.712780',NULL),(3,'4ba36b86479c292cebefc94beb49c115c6b70a6b','759314fb52acb7177eeb83563754efc24eca7950','RUNNING','SENSOR','{\"__class__\": \"InstigatorState\", \"job_specific_data\": {\"__class__\": \"SensorInstigatorData\", \"cursor\": null, \"last_run_key\": \"bxxx:1607635580.3826091\", \"last_tick_timestamp\": 1648158132.607246, \"min_interval\": 30}, \"job_type\": {\"__enum__\": \"InstigatorType.SENSOR\"}, \"origin\": {\"__class__\": \"ExternalJobOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"job_name\": \"toy_file_sensor\"}, \"status\": {\"__enum__\": \"InstigatorStatus.RUNNING\"}}','2022-03-24 14:41:03.704882','2022-03-24 14:41:03.704882',NULL);
/*!40000 ALTER TABLE `jobs` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `run_tags`
--

DROP TABLE IF EXISTS `run_tags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `run_tags` (
  `id` int NOT NULL AUTO_INCREMENT,
  `run_id` varchar(255) DEFAULT NULL,
  `key` text,
  `value` text,
  PRIMARY KEY (`id`),
  KEY `run_id` (`run_id`),
  KEY `idx_run_tags` (`key`(64),`value`(64)),
  CONSTRAINT `run_tags_ibfk_1` FOREIGN KEY (`run_id`) REFERENCES `runs` (`run_id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=134 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `run_tags`
--

LOCK TABLES `run_tags` WRITE;
/*!40000 ALTER TABLE `run_tags` DISABLE KEYS */;
INSERT INTO `run_tags` VALUES (59,'3cbf76a0-8586-41df-9a10-961353c26f1f','dagster/sensor_name','toy_file_sensor'),(60,'3cbf76a0-8586-41df-9a10-961353c26f1f','dagster/run_key','bx_new_run_3:1609955736.963252'),(61,'3cbf76a0-8586-41df-9a10-961353c26f1f','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(62,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','dagster/partition','2020-01-05'),(63,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','dagster/partition_set','unreliable_weekly'),(64,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','dagster/schedule_name','backfill_unreliable_weekly'),(65,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','.dagster/scheduled_execution_time','2022-03-24T21:41:00+00:00'),(66,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','dagster/run_key','2020-01-05'),(67,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(68,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','dagster/sensor_name','toy_file_sensor'),(69,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','dagster/run_key','bx_new_run_4:1610388763.2417717'),(70,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(71,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','dagster/sensor_name','toy_file_sensor'),(72,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','dagster/run_key','bx_new_run:1608060793.3515544'),(73,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(74,'f62982b8-3037-468e-a94e-032f68011e77','dagster/sensor_name','toy_file_sensor'),(75,'f62982b8-3037-468e-a94e-032f68011e77','dagster/run_key','bx_new_run_2:1608060796.9405777'),(76,'f62982b8-3037-468e-a94e-032f68011e77','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(77,'66d03d20-ef6b-40eb-92e3-e7c17033831a','dagster/sensor_name','toy_file_sensor'),(78,'66d03d20-ef6b-40eb-92e3-e7c17033831a','dagster/run_key','foooawoiefj:1645197413.2837281'),(79,'66d03d20-ef6b-40eb-92e3-e7c17033831a','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(80,'dc459868-808c-4476-adf7-548b1f42f45c','dagster/sensor_name','toy_file_sensor'),(81,'dc459868-808c-4476-adf7-548b1f42f45c','dagster/run_key','demo.1:1606341124.944769'),(82,'dc459868-808c-4476-adf7-548b1f42f45c','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(83,'e641587a-ac48-4a95-8208-81990c416d8d','dagster/sensor_name','toy_file_sensor'),(84,'e641587a-ac48-4a95-8208-81990c416d8d','dagster/run_key','boopppp:1607487853.6962564'),(85,'e641587a-ac48-4a95-8208-81990c416d8d','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(86,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','dagster/sensor_name','toy_file_sensor'),(87,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','dagster/run_key','blawiejfoj:1647625969.2538514'),(88,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(89,'e737f12e-dadf-4295-9ce1-ec3f43d84238','dagster/sensor_name','toy_file_sensor'),(90,'e737f12e-dadf-4295-9ce1-ec3f43d84238','dagster/run_key','b.out:1605834003.363826'),(91,'e737f12e-dadf-4295-9ce1-ec3f43d84238','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(92,'06c52e01-4d6e-41e1-997c-38207bf5c267','dagster/sensor_name','toy_file_sensor'),(93,'06c52e01-4d6e-41e1-997c-38207bf5c267','dagster/run_key','show_run_key_3:1606942458.8674'),(94,'06c52e01-4d6e-41e1-997c-38207bf5c267','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(95,'84b8c995-a9d8-40e7-9887-5188e07fc31c','dagster/sensor_name','toy_file_sensor'),(96,'84b8c995-a9d8-40e7-9887-5188e07fc31c','dagster/run_key','show_run_key_2:1606840685.1579385'),(97,'84b8c995-a9d8-40e7-9887-5188e07fc31c','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(98,'184e6db1-23a0-42a7-9bff-8ea1cf922193','dagster/sensor_name','toy_file_sensor'),(99,'184e6db1-23a0-42a7-9bff-8ea1cf922193','dagster/run_key','a.out:1605833207.4776378'),(100,'184e6db1-23a0-42a7-9bff-8ea1cf922193','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(101,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','dagster/sensor_name','toy_file_sensor'),(102,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','dagster/run_key','boop:1607484774.6155019'),(103,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(104,'16362f52-dd3d-43a5-be74-2bd3d3bca219','dagster/sensor_name','toy_file_sensor'),(105,'16362f52-dd3d-43a5-be74-2bd3d3bca219','dagster/run_key','bxxxxffff:1607996899.666524'),(106,'16362f52-dd3d-43a5-be74-2bd3d3bca219','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(107,'a395a21d-4197-4952-914d-039258b35b4e','dagster/sensor_name','toy_file_sensor'),(108,'a395a21d-4197-4952-914d-039258b35b4e','dagster/run_key','blahfjfjf:1606840555.9826365'),(109,'a395a21d-4197-4952-914d-039258b35b4e','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(110,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','dagster/sensor_name','toy_file_sensor'),(111,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','dagster/run_key','boop3:1607484790.7801318'),(112,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(113,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','dagster/sensor_name','toy_file_sensor'),(114,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','dagster/run_key','booppppppp:1607487856.5426033'),(115,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(116,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','dagster/sensor_name','toy_file_sensor'),(117,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','dagster/run_key','bxxxxf:1607635587.0286214'),(118,'c0220f79-6278-4b74-97df-456406c27a2d','dagster/partition','2020-01-12'),(119,'c0220f79-6278-4b74-97df-456406c27a2d','dagster/partition_set','unreliable_weekly'),(120,'c0220f79-6278-4b74-97df-456406c27a2d','dagster/schedule_name','backfill_unreliable_weekly'),(121,'c0220f79-6278-4b74-97df-456406c27a2d','.dagster/scheduled_execution_time','2022-03-24T21:42:00+00:00'),(122,'c0220f79-6278-4b74-97df-456406c27a2d','dagster/run_key','2020-01-12'),(123,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(124,'c0220f79-6278-4b74-97df-456406c27a2d','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(125,'64cb1e86-9461-4a54-8f1b-22042d76566f','dagster/sensor_name','toy_file_sensor'),(126,'64cb1e86-9461-4a54-8f1b-22042d76566f','dagster/run_key','boop2:1607484775.9602463'),(127,'64cb1e86-9461-4a54-8f1b-22042d76566f','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(128,'f5ea6efb-0306-4138-af6a-1087b57f10b5','dagster/sensor_name','toy_file_sensor'),(129,'f5ea6efb-0306-4138-af6a-1087b57f10b5','dagster/run_key','show_run_key:1606840644.290511'),(130,'f5ea6efb-0306-4138-af6a-1087b57f10b5','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}'),(131,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','dagster/sensor_name','toy_file_sensor'),(132,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','dagster/run_key','bxxx:1607635580.3826091'),(133,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\"}');
/*!40000 ALTER TABLE `run_tags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `runs`
--

DROP TABLE IF EXISTS `runs`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `runs` (
  `id` int NOT NULL AUTO_INCREMENT,
  `run_id` varchar(255) DEFAULT NULL,
  `snapshot_id` varchar(255) DEFAULT NULL,
  `pipeline_name` text,
  `mode` text,
  `status` varchar(63) DEFAULT NULL,
  `run_body` text,
  `partition` text,
  `partition_set` text,
  `create_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `update_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `start_time` double DEFAULT NULL,
  `end_time` double DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `run_id` (`run_id`),
  KEY `fk_runs_snapshot_id_snapshots_snapshot_id` (`snapshot_id`),
  KEY `idx_run_status` (`status`(32)),
  KEY `idx_run_range` (`status`(32),`update_timestamp`,`create_timestamp`),
  KEY `idx_run_partitions` (`partition_set`(64),`partition`(64)),
  CONSTRAINT `fk_runs_snapshot_id_snapshots_snapshot_id` FOREIGN KEY (`snapshot_id`) REFERENCES `snapshots` (`snapshot_id`)
) ENGINE=InnoDB AUTO_INCREMENT=36 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `runs`
--

LOCK TABLES `runs` WRITE;
/*!40000 ALTER TABLE `runs` DISABLE KEYS */;
INSERT INTO `runs` VALUES (13,'3cbf76a0-8586-41df-9a10-961353c26f1f','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"bx_new_run_3\"}}}}, \"run_id\": \"3cbf76a0-8586-41df-9a10-961353c26f1f\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"bx_new_run_3:1609955736.963252\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:17.730978','2022-03-24 21:41:22.337043',1648158081.754845,1648158082.337043),(14,'eaa207df-08ba-4834-ae00-d0ca1e8cac71','98186006cacd1a0524d01ea9e57d7d6e8d8f647f','unreliable_pipeline',NULL,'FAILURE','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"efeedead55de984ed179dce0ddad72ccb7fa0102\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"unreliable_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"unreliable_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"unreliable_pipeline\", \"pipeline_snapshot_id\": \"98186006cacd1a0524d01ea9e57d7d6e8d8f647f\", \"root_run_id\": null, \"run_config\": {}, \"run_id\": \"eaa207df-08ba-4834-ae00-d0ca1e8cac71\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.FAILURE\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \".dagster/scheduled_execution_time\": \"2022-03-24T21:41:00+00:00\", \"dagster/partition\": \"2020-01-05\", \"dagster/partition_set\": \"unreliable_weekly\", \"dagster/run_key\": \"2020-01-05\", \"dagster/schedule_name\": \"backfill_unreliable_weekly\"}}','2020-01-05','unreliable_weekly','2022-03-24 14:41:18.505032','2022-03-24 21:41:24.586066',1648158082.255325,1648158084.586066),(15,'ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"bx_new_run_4\"}}}}, \"run_id\": \"ea8d0b7e-1c3f-4bc9-bc11-0c100d7f8b85\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"bx_new_run_4:1610388763.2417717\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:20.381430','2022-03-24 21:41:25.281849',1648158084.666483,1648158085.281849),(16,'d4cffd6f-2e01-47ef-bb72-90d2a9e84e22','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"bx_new_run\"}}}}, \"run_id\": \"d4cffd6f-2e01-47ef-bb72-90d2a9e84e22\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"bx_new_run:1608060793.3515544\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:23.109966','2022-03-24 21:41:28.031581',1648158087.455273,1648158088.031581),(17,'f62982b8-3037-468e-a94e-032f68011e77','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"bx_new_run_2\"}}}}, \"run_id\": \"f62982b8-3037-468e-a94e-032f68011e77\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"bx_new_run_2:1608060796.9405777\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:26.107788','2022-03-24 21:41:30.480644',1648158089.905072,1648158090.480644),(18,'66d03d20-ef6b-40eb-92e3-e7c17033831a','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"foooawoiefj\"}}}}, \"run_id\": \"66d03d20-ef6b-40eb-92e3-e7c17033831a\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"foooawoiefj:1645197413.2837281\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:28.556493','2022-03-24 21:41:33.058142',1648158092.455452,1648158093.058142),(19,'dc459868-808c-4476-adf7-548b1f42f45c','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"demo.1\"}}}}, \"run_id\": \"dc459868-808c-4476-adf7-548b1f42f45c\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"demo.1:1606341124.944769\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:31.126077','2022-03-24 21:41:35.581416',1648158094.971433,1648158095.581416),(20,'e641587a-ac48-4a95-8208-81990c416d8d','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"boopppp\"}}}}, \"run_id\": \"e641587a-ac48-4a95-8208-81990c416d8d\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"boopppp:1607487853.6962564\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:33.581334','2022-03-24 21:41:38.259429',1648158097.655277,1648158098.259429),(21,'69be6d22-e418-4e86-8fd7-6bfaac2a44dd','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"blawiejfoj\"}}}}, \"run_id\": \"69be6d22-e418-4e86-8fd7-6bfaac2a44dd\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"blawiejfoj:1647625969.2538514\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:36.205308','2022-03-24 21:41:40.783340',1648158100.187199,1648158100.78334),(22,'e737f12e-dadf-4295-9ce1-ec3f43d84238','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"b.out\"}}}}, \"run_id\": \"e737f12e-dadf-4295-9ce1-ec3f43d84238\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"b.out:1605834003.363826\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:38.832670','2022-03-24 21:41:43.254156',1648158102.653951,1648158103.254156),(23,'06c52e01-4d6e-41e1-997c-38207bf5c267','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"show_run_key_3\"}}}}, \"run_id\": \"06c52e01-4d6e-41e1-997c-38207bf5c267\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"show_run_key_3:1606942458.8674\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:41.331332','2022-03-24 21:41:45.836757',1648158105.255419,1648158105.836757),(24,'84b8c995-a9d8-40e7-9887-5188e07fc31c','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"show_run_key_2\"}}}}, \"run_id\": \"84b8c995-a9d8-40e7-9887-5188e07fc31c\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"show_run_key_2:1606840685.1579385\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:43.806392','2022-03-24 21:41:48.258336',1648158107.665457,1648158108.258336),(25,'184e6db1-23a0-42a7-9bff-8ea1cf922193','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"a.out\"}}}}, \"run_id\": \"184e6db1-23a0-42a7-9bff-8ea1cf922193\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"a.out:1605833207.4776378\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:46.306912','2022-03-24 21:41:50.857271',1648158110.269762,1648158110.857271),(26,'30340bb3-53fd-4755-aac9-ca22c4b56c4f','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"boop\"}}}}, \"run_id\": \"30340bb3-53fd-4755-aac9-ca22c4b56c4f\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"boop:1607484774.6155019\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:48.934867','2022-03-24 21:41:53.407401',1648158112.805747,1648158113.407401),(27,'16362f52-dd3d-43a5-be74-2bd3d3bca219','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"bxxxxffff\"}}}}, \"run_id\": \"16362f52-dd3d-43a5-be74-2bd3d3bca219\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"bxxxxffff:1607996899.666524\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:51.482639','2022-03-24 21:41:56.008704',1648158115.414699,1648158116.008704),(28,'a395a21d-4197-4952-914d-039258b35b4e','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"blahfjfjf\"}}}}, \"run_id\": \"a395a21d-4197-4952-914d-039258b35b4e\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"blahfjfjf:1606840555.9826365\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:53.984662','2022-03-24 21:41:58.508016',1648158117.904419,1648158118.508016),(29,'2460e183-ee8c-4fa3-a963-c0fca3cf60d6','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"boop3\"}}}}, \"run_id\": \"2460e183-ee8c-4fa3-a963-c0fca3cf60d6\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"boop3:1607484790.7801318\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:56.484448','2022-03-24 21:42:00.908034',1648158120.316424,1648158120.908034),(30,'286d69c1-263f-46ca-bdeb-bdb2cff627d0','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"booppppppp\"}}}}, \"run_id\": \"286d69c1-263f-46ca-bdeb-bdb2cff627d0\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"booppppppp:1607487856.5426033\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:41:58.986084','2022-03-24 21:42:03.407641',1648158122.78754,1648158123.407641),(31,'b002ddcb-ddd5-4b57-9911-e4ea234f9b71','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"bxxxxf\"}}}}, \"run_id\": \"b002ddcb-ddd5-4b57-9911-e4ea234f9b71\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"bxxxxf:1607635587.0286214\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:42:01.554556','2022-03-24 21:42:06.511923',1648158125.906736,1648158126.511923),(32,'c0220f79-6278-4b74-97df-456406c27a2d','98186006cacd1a0524d01ea9e57d7d6e8d8f647f','unreliable_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"efeedead55de984ed179dce0ddad72ccb7fa0102\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"unreliable_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"unreliable_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"unreliable_pipeline\", \"pipeline_snapshot_id\": \"98186006cacd1a0524d01ea9e57d7d6e8d8f647f\", \"root_run_id\": null, \"run_config\": {}, \"run_id\": \"c0220f79-6278-4b74-97df-456406c27a2d\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \".dagster/scheduled_execution_time\": \"2022-03-24T21:42:00+00:00\", \"dagster/partition\": \"2020-01-12\", \"dagster/partition_set\": \"unreliable_weekly\", \"dagster/run_key\": \"2020-01-12\", \"dagster/schedule_name\": \"backfill_unreliable_weekly\"}}','2020-01-12','unreliable_weekly','2022-03-24 14:42:01.707482','2022-03-24 21:42:09.008692',1648158125.956571,1648158129.008692),(33,'64cb1e86-9461-4a54-8f1b-22042d76566f','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"boop2\"}}}}, \"run_id\": \"64cb1e86-9461-4a54-8f1b-22042d76566f\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"boop2:1607484775.9602463\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:42:04.582002','2022-03-24 21:42:09.408267',1648158128.756429,1648158129.408267),(34,'f5ea6efb-0306-4138-af6a-1087b57f10b5','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"show_run_key\"}}}}, \"run_id\": \"f5ea6efb-0306-4138-af6a-1087b57f10b5\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"show_run_key:1606840644.290511\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:42:07.309796','2022-03-24 21:42:11.957875',1648158131.382916,1648158131.957875),(35,'9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad','259222410d3088da9661ed088b7444ecd910032f','log_file_pipeline',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"9261c860c16bbeaae35488be2e0485bba78bc653\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"log_file_pipeline\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"log_file_pipeline\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"log_file_pipeline\", \"pipeline_snapshot_id\": \"259222410d3088da9661ed088b7444ecd910032f\", \"root_run_id\": null, \"run_config\": {\"solids\": {\"read_file\": {\"config\": {\"directory\": \"/Users/prha/dagster_sensor_data/\", \"filename\": \"bxxx\"}}}}, \"run_id\": \"9ea59fa4-3f69-4c0f-b5a4-f5b186a8b4ad\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpz1r_ssqm\\\"}\", \"dagster/run_key\": \"bxxx:1607635580.3826091\", \"dagster/sensor_name\": \"toy_file_sensor\"}}',NULL,NULL,'2022-03-24 14:42:10.006949','2022-03-24 21:42:14.559802',1648158133.958818,1648158134.559802);
/*!40000 ALTER TABLE `runs` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `secondary_indexes`
--

DROP TABLE IF EXISTS `secondary_indexes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `secondary_indexes` (
  `id` int NOT NULL AUTO_INCREMENT,
  `name` varchar(512) DEFAULT NULL,
  `create_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `migration_completed` datetime(6) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `name` (`name`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `secondary_indexes`
--

LOCK TABLES `secondary_indexes` WRITE;
/*!40000 ALTER TABLE `secondary_indexes` DISABLE KEYS */;
INSERT INTO `secondary_indexes` VALUES (1,'run_partitions','2022-02-01 15:01:29.389515','2022-02-01 15:01:29.362464'),(2,'run_start_end_overwritten','2022-02-01 15:01:29.519382','2022-02-01 15:01:29.489329'),(3,'asset_key_table','2022-02-01 15:01:29.772084','2022-02-01 15:01:29.745994'),(4,'asset_key_index_columns','2022-02-01 15:01:29.861465','2022-02-01 15:01:29.834494');
/*!40000 ALTER TABLE `secondary_indexes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `snapshots`
--

DROP TABLE IF EXISTS `snapshots`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `snapshots` (
  `id` int NOT NULL AUTO_INCREMENT,
  `snapshot_id` varchar(255) NOT NULL,
  `snapshot_body` blob NOT NULL,
  `snapshot_type` varchar(63) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `snapshot_id` (`snapshot_id`)
) ENGINE=InnoDB AUTO_INCREMENT=9 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `snapshots`
--

LOCK TABLES `snapshots` WRITE;
/*!40000 ALTER TABLE `snapshots` DISABLE KEYS */;
INSERT INTO `snapshots` VALUES (5,'259222410d3088da9661ed088b7444ecd910032f',_binary 'x�\�]\�s۸�W8\�N\�$A�\�ˣ�6�ob\�t:\���ņ\"U�J\�f\�\�C[�!Z���=c[$�\�b\���]\0���\�X��,\�x\�\���L!M2�\�ش\�\�\�3y��\�c���잼t��\�}U����-\�gi\Zw4\�\�\�ğ\�&p�\�l\"ty3�\�0$$��H�U�g�@6KS}�\�$�\�\����*�T.]_\'�!�36C\�4�o6�ϯ�L�L\�$o\�\���\�\�\�ߣ\�l)Xʊ��ҶQ\�R\�lb�\�5n���9��)�H��$�`\��c\�r\�xD<_�\nH�\�.�\�����\\9��\�%\�\�^\'Ȟ\�ZI�Çӝd�\�hGF>.i�*�\��\�\Zh\�\�O�szCI�i��\�/y�\��@�\�6�-�;��\�\�ū\�\��\�tt]���D]\�\�\�\�u�\�v�6\�\�F�!4\�-���Poߟ�^\�#�w\��`\Z[Ƞ�\ZP\�\�\�\�S�\�Lw\�\�@\��� ��8\�%F\�)D!|�� �\�~$�\n!qL8��z�=����\�\�\�ޝ�\�\�v:kߝ����S�̢�\�u�O��\\\"}\"�\n��G)\�*`����\�\�\��\�����\�y�� mϋ.2J(\� �<&��̓Q\��\"�\�o\��H�x�(\�ӏ\���\�:\�\�9���f\�_\�\��HTRjt͸�<7|\�=\��P\�L#/<\�֛����\�vg�\�QW\�U8 �I\�1�@\"mx�\�)F|���U, )䏵Dߚ\���\�\�*��\�D��LU\�`\�IM=fe��2\�\�*�o\�7���q��%EML��4ԺXA\�ŧ�\�P�:\�w\�h�\�\"���$\'>�\���SR�\�\�e4z|�+�\�K��c����\0BpW�\�\\��8tQD]��\�\�.}�x�\r\�.[�y\��ͫ\�\�u\�ؽ�\�)\�G!a��K\"���PL\�\'W\�e$B:�\��<��I\�x�=ǈw\�\�\�5[\�[�됈䐨\�;En�Eے,Z�u�046xw�}\�ץ\�Ϗ�t��u�\��ڱKA�\�4\�q�\�\�\�k��O)��=��\�S�Ms\�\�\�>L\�s�\'\�|2\�aL����ͽ\�\�\�6y�\�\�6�ls\�l\�ެ�s�0\�G�Hz2\�\'\�\�8۩=k\�\���\�^�{��̴\�#I��/�\�|TzAD&�qͱ<Y\�Y�5\�mquH�+OA(��\�\r�TD豒0y< n�����\�c\�\�ڡ\�lb�6Mk+8�iJ\�\�\�(\�L��4b:�!\�D*�\�\�+�\�L\�j>��\�;yeX�\Z�\�(۫vһ���zΝ\'�aK@Y���`����\�\�J\�t�\0I�I�)&\�,\�Hć]�%�	�j���YQ@V��\�3g M4W\�V\�`�\Z�2 �-�	��!W�!C3�\�vf\�C\�Y\�G�\�\��U���\n�f��\n�\0�QJ�\�:�Tl\�E�$�\',cכ��I\�C@��\"�\��v)C\����\'C�Y�b7\�B\�\�ûW�\�ů���\�k\��p�\�\�dzb�qn\�q:\��\�\�>�\r�\n<�Z߈|_yx(KYk\�8\nAD�bXIjN8\��.��G!=\��\�pt5zw\�\��j\�i~�\�\�M3�W#ɮ\�\n�\�\�\��{N}\��ÂU\�D4<���~\�(D���Q��2�\\�8*��YH}\�.7{�\�L�$��#\�E�\�\�(D���bJ\�e8Bt\�\�!OI\���ǻB�?,\�]�s;\�jf��\�\�\�o\r1[�$;\0Y�\�\0\�	�����\�p)\��\�PA�\">�@w�eј�	+\�\�\�Fe�&5�F����s�-�\�6�\�3\�+�Y]\�6�vN\��r\�6F�\0mȋ�\�3�\��\�\�PS\'/:CQ:bE:\��S.@�����\�ÔY@�\�\n\r�\�ݵ\�Ўr4l-mm\�8\��\�F�\"$ϣBEA�{�Jh�g\�\�l�\�A]\�p\�\��0Q\�\Z�k�]�\�B�,\��\�\�`a�&�O�ћ�\�4I\�Lr9K�t�ܙ�\�L:I\�Tcp\�N��\�P[7n\�\�Y}X~?\�&�\n9,LlW�~\n�X���j��\�\�Z�U4vyJ\�Q\�u����B��\�Y�K�\�h��\�a#\�A��5��M��#n�\�\�\�Y5�U�<\�n#��aXC\�a�\�\�\�z@�i�\�\�DzPESB�/=�\�@���\�dv�*��\n�\�ӟwֈY\�	��\�5cy�qFq\�4wu)�w�[�nm���\�}�C�5��p\�|\�i�_���\�ͤ��a\�zԲC����\�\�2\�\�-�ˡ��}�`�UsP�X��<`�Dg\�\�AEg�1\�G�5�\�N��\r+���~�\�O�:]lyt\����\�v	J�\�=<V O�\�\r\�zf�>�\�\�*�\���y5\')���\��Tŋgq7\�%IS�k\�,\�2ח\�\����W\�_뙺[�oNjNL�\�u\�\�7N����є47+�d:h�\��=\�ZR9_���I꺪\�\'kk��ݪk6��i�\�\���\�dzS�\�\�$/�_�/҄��y���R7r2�&\�_L�\�*��L>/+VT\�\'�+7�\��xb�\�M\�ȱ>�\�n@�\�?�\����n\�\�O\�u$�!,�^������\'��\�Uu{�z\�\�Q�+��mw{\�h\�t\��m�1~7\�Z\�e\�\�\�r&\�릂\�\�+~�l\��v\'/�\�jk2)�)��}���;�%څf��\�\�L\�VW%�z\�\���w>&z�+�\��o3�]^\�\�ﻪ�cˑ�}�ܝ*�E\�[���-\�%L��\�^N\�J\�]W7\�~\�Q�}�??2r�\��o�\�?\�$͡\�?\�\�&�=c���\�C!�۹�}\�S2���l�\�\�\�j�vd\�+��\�v\�/��R�\��\�\�ȸN-3��\�X\�\�&\�l\n9�\nfAl�\�=a\�C���B�碻k�\�;05�\�LT�bk�S\�$d\�\�+�\�ԓ\�q�}\�3�j(�	\�/L�w\�r���l:�⚙�\�\�F�\�Fw\'\�M�+�{ӤN\�s\�\�\�\�\�\�Zϣz\�\�\�\��1\�k�\�δ��\n�ٲJg\��N\�\���O�1t�$S�3��ku�\�\�c�.\�t�ىl*\�IS\��g\�+\�\�l,�P\�\�$�\��Am5�f\�\�V2\�\�\"K��?n\�L�M\���n�\�]�\\��i�\�<\�u\�N�?:�\�OF\�ur8��o\�u[F�*\�C[h�=\�\�&�k^���W\�y\�}\�K�ݢ+:Xk�s��d�\�\�\�ko\�zQt\�m&ӼL*m\�sO�\�\�\�\�\�@�\�>\�6�\rM�#\�-a�u\�ͮ��\">��,;\�\�D}5_\�$�v�Z�\�=K�\��\�\�m�x\�\�\�\�݁jq�=�Z�','PIPELINE'),(6,'9261c860c16bbeaae35488be2e0485bba78bc653',_binary 'x��R]O1�+\�ϨJ�\�\�P�T���}�\�ʜ7e�\�6\�\Z���wv\�.$AЧ�Y�3���}1\0���\0�\�s�\�\�\�\�\�pl*\��\�ၱ�ii[.�0*�N\�+J{V\�l�*CR�-��\\\n\�d=<����e�\�4%\�\�8\rH�Ms<o�f6���\�ٙ�\�):yޝ\�f3l\�|:�5K\�F}Ro1�e\��*��:��\�h,ɣ�aE\�/��ŵ\0\�/�]R\��TW\�VOkt\�P�AK%�K\�\�׫��7�f-\�\�:\���{ӌ�7#�e誇ml9�[\�\����0��+mm2\�X�ﳔh$D&,�ϝ[\�\��{�`�\�Jn%\�\�\�3>Vʻ\�!\�T\��\�\rC��DO\�mp?0�\�oCso��/O6c\�\�\�\�\�w�\�E\�Q�\��t�4�#?\n��{�\nK��%�_$U4','EXECUTION_PLAN'),(7,'98186006cacd1a0524d01ea9e57d7d6e8d8f647f',_binary 'x�\�]Ysۺ�+\���(ID\�|�4nS�N�;�\�u��\�bC�*I9q3�\��h�Ѣ�D\�Lb�\�r�\�\0���A��\�y^[�ߣ���D\\%d��\�b\�\�\Z�4�\�M����0o�ym�X���,wU[�O\�8l\�ЏCz~weg\�][C�\�&%�	.r�E�\"JU �Ʊz(�\�8�%\�T\�\�21_�|݊$L\�X\�uw\�a\��\�S�𚈲\�\Z����]�{p�\�\�\�$\�*u�*NHFƚ��s]�,\�\�\�\�jD&b\�.l\�pD���\r \�6\�\�q�/ܥ�\�c\�1\�+�V�\�:I�~\��c�F��\�\�l\'\��9ؑ�/�*�(�y��f\�\'\�Y{}I�ꠔ\�oi\Zw�@7n�\�\��\�>\Z\�y\�\�\�\�٧\r�n�uU�(\��vy���\�n�\�㔴z���\�n.��\�\�\��\�\�\�\�\�p�P\n����O=J\��\�!��\�$����\�\�+V�ِ\n\�!��E\�\�eP:B0\"�0 }�\0\��n˞c�\�$�\���\�ˋ\�\�Nc\���\�eU;�\�\�y\�M\\$\��F\�EK3\�;#\�(=�/ s�B=]i\�]?3?�;mk\nR\�<g�`�1\�p\�&�M�˂@�\�] n#�z�Q޻rj�;ek��F�9�\�\�t��9\�Zׄ:��}υ\�q1�\�4p�\�\�m��\�]A\�mw\�*5\�l	=g\�\�8P�Ǳ\'I�˔R�j\�PO\n�sc�\�\�\�\�V%�\�E8\�\�ۈ-�\"���o\�\�C���\�\�$̋L�\�㾕�(3\�\�i���I纵&V�i\�5٭\��\�lT�?$�\��\"W0*	���\�Dp2!��Z�\�\�]>!ߒ͌q\�b\�\n�O=jsׁ�J!1\�m`�H�|��\�_����ej0\�>�{\��rS<\�\�|yF��A���a�\�_6C�\��P���s:�\�QNh��z$,�\�\"\�k��7\�!\�@l�% \�Q|A�`�P�����\�#\�ϼ�B|�\�m��{2�E��9*n\�Q\r�ƚ6\�!5�\��\�jZ�\�2�S\��K\�s\�\0p�\�PM\n]_\r\�a\�(\�Ռ\�\�\�\�z\�k����9+[eL\�H�Ms\��}�\��\�<�\�i\�c�\�J��m\�}�p��\�Kz϶�l��\�f�\�jl�{_އq>\�\�q>g?ƹ\�s\�\�\�{�N\�H\�ݷ8���(4]\�%s\��\�;�մg\�|2\�4�)�	v\�H\�səo�=D\�\�X��\r\�!ۇ��\�B\�3\�6\�6E:]\�\�4��ࠦ\��\"��� \�/|W�@z\�P�R�yT�i�\�q]g\�^kү�Pa�\�\�O\�\�F�\�^�t\�%�My�\�@l�[)\�Q\�wOıg!��\�\r=h�{@+��\�:��M�L$�~h��z\�XQm�\n\�¾\�(԰!\�`���\�\�<	�h;3�\�!\�\�Q)^\r\�D\�nshCyIJF} 8ĔC*�\�\�\�\�MW�AI.B�\�\n���U:͘\�l?�\�\�$l�\�ϟ\�\�|�>�����ލ�}Lz7t)]�HG\'Ry�\�\�C����G�\�S\�9H`\�p� p]\�A}\�\�\�Xc�ő\�,%���S_QB�rh�4\��\�(ڎ\��\�\�zp~\��\�z\�qz\�\�V\�mK=��\�Nn\�Bd��/w\\\�\�\r�K	���\Z~�$R��0\0@�w��#9r]\�ᥚ�wz3�i�րW�=��\�\�}x;c��\�XUPoe��\�R&r\�\�\Z&v^\�1�ž\�\�,<5�#\��\�Hp5k\nP%r�\�8\�s\�\�\�18.X\����\�SĆ�0�a!a�R|L�\�\�)\�O\�E�5N�4�U�\�$qJ�%V1\�<	{8x?uݰnnmqk\�EGC��*\�01]x�%`b�LK�ѣBOc�TѾ��\�\��� \�\�Ε�\��6Tc#�E�$�H^>�1\�\�8*U?H\'y\�\�a\�ӌej\�^\�\�K \�\�\�\�\\[M���\0e>�F�\n\Z�2�\�H\�WYK�\�dZ���\�\"3+1\�\�a�DM0�0�!�\"�\�#\�T\�\�}$�\�k%�\�g�e�;@\�p\�\rX�;F��\�Ѭx\�;\�\�LM�=@!Vd\�1(+�\�$�*��Hai޺\�\�\�\�\�p\�\�^nn��Wd�pc,\�\�r�\\\�(\�$�=%{\�n�����\�L�\�f8��gy�w!\��*�\��\�\�xD?\�\�^XN�-\�\���,�ɩ)9ʿ�\Z\�\�\�\�e\�Ԑ]|K��\�lM�L�V\�I�)��\�\0\�w9�\�\�A�\�0�R!\�oA�����\�0�b\�\�\�9�0~ws螊��c���\�\�7LW\�\�@b��Âz\�`\�\0\�(\�wg,�܆�I�D�\��U#\�y>\�\��$�6-+�M���\�ү\�\�2���DA��6sl[R\�\���t\0��гF@\�� 9�\�z�\\r\�g\�y�\\ז�jj\�=3��`\�l�:\�BO\\�\n�pߨ\\$�����+2��\�R�r�q�㬽\�V\�`���Æi�\�O[:!\�x�\�0��9(`�@\�	0F�3&\�3N\��\�l\�\���\�R\"\��Q���\�B��7\�j\Z�Q�\�ʧ���En�LX,j\�\�C\�m\�l�sS�8�N�5\�Bƍ\�V^�%�\�Wο�<�oQ[T5Lb%s\��YB�\'�\�\�\�_\����+\��G\�j��\�U�u���~X�(���\�\�\�S��E�\���VT���\�ұE\�\Z�~�����b��~\���,N\�Q�\�\�\��*�hF��W�/\�N��b�Ew*��K�\�e0\�r,T\�*�x \�\�\�êx+r�C4P��\�a��ij\�O\��nW��o�\�r\�&\�\�*\�tryL�\�=�B\�@ZV��S\�\rAa*�C��\�\��U]^>\�\�ڊ��~Sv;\�\�t\�N\�_}\�\�\�β^%d\'\�\�\�\\j\�s2�\�\�5�潓�l^���&�\�\r\������h��\��Ԩ\�MA\�nU�\�IL\�V\�R��N#g$\�f!ժM�.]TF=YsQ\�c\�\��\�(�H����]\�X\�{*�\\�\�U\�\�\�[��\���U1/��͒\�ˍ}��a�M\�-W\�t�\�\�-\�\�~\�\�c\���-����\�6l�릫�\�\��\��6�}\�\�*��y�U\�i1\��t}\�\�v\�/�2R�\�\�\�MT�I51\�B�l��M2m\�ZW�\�\��-ry D{2sSG_\����QU�#&z\�1e\�4\�\Z㈉H�H\�\�USz1\�)7>\�(�Mъ�Z\�0M�\�\�g\�\ZG\�dZ�%1-\�u�*�*\�^��k\�;\�,b!Kc-��\�\�t��JUZwk��\�\�H\�\�\�*\�/�V�/�\0\�)\'R��\�d�4o�j��\�\�|;jC�M.��\�\\a\\[\�;	\�VYY�o��y\�\�]˔ڻ��t\��Χܻl物\'.\�\�[\�_�u\�W\'�\�]�\�l\���\����n�׻\�>��y�\�\�\��_\�\�&*$�֤�\�[\�O\�FD�ŭ*\�*F�P$Eq�7Hꭾi�;\�{��\�(���\����LFm47�\��7�Y����Q\�E\�B&��\n�r\�ĦJ�\�\�\�ǲ\�BCca�=�k�\�\�\'zx\�:j>��U\�\0��w�\�7�*\�/ַTJkl\�\�u�&	p�\�>Յ�LeO{.J[\��K1giZ����\�-i�ŎgN*J\"MW�e\�[�Ʒ\�S_��\'i\�#\�\�ޒ�\�\����\�#:\���\�zja=�\�}\�\�~\�\�\�V,\��=#�6J����\�G\�9o=��$*\�K�3\�4[\�1��\0\�&`��1�D~���\��\����\"','PIPELINE'),(8,'efeedead55de984ed179dce0ddad72ccb7fa0102',_binary 'x�\�Qo\�0ǿʔg�Z�uo\r�ڤ��,/�nV\'\�ζ2\��\�s��YFF�\��OQ\�\�\�_~m\�ǈ�8�J�?�\� .4\�\�eBŕ���\�t\�\�(�R\�%��\"9Hŕf\�,��\�\�$4,\�\�e�R�\�ל&d%�{A��\Z�D�$f0\�9$\\\0Qn6±rt6�\�g�\�,�1�\�\�ɻc6�=��Sv\�f0g\�\�\��t�ԩw�-&��5\�dkEtFJ�8\�Ϩ\�\�I�@5\�.0�}�\�˭�y�\�^���������h\�&QX\��\�\�+�N�N\�~6�FU)�ޘ)$\�\�p1�A�q�r[�\�d�\�x\�I\�O2K�\�E�M]�*G��4QP\�\";\�\�\�-,\�T�\�\�\�\�\���ʧ�J\�m\�ڌ\�J\�Y�l\n�4Ϲ�qKwM\�\�T�JPEbWVm���[����\\i	4m\�\�ۇ\�P�\�`�T��?+.�3\0�\�\�\�_\��ۏ\�.|?�P|\n�2�)\�\ZR�yQ\��l+�k\�\�K\�B\�luͭO�6]6Q\�G��\�ۭ�[�\�<nߔ\�\�r�\"\�	.FR�ip�C���\�~l\�sȩ�q\�¿\�h3ѓ]R$R\�\���/\�ux)�\"\�\�\'�\r\�P\0\�(�\�\�c\'`\\\�\0Se(2\0\�\��x\0|\����W\�\�iQ\�\��3t�=\�\�\�9U\�p\np<V�o���|�\�+e��Xj{Z\�@KG7v��&uH�1>�\�3�\0�}\�\�U\�FLiO\0\�(�\�\�b\'^\�ak��\�\��x��O\�\0-xp�\�\�\�KmO@\�h\�\�\�.�\�\��\�Ҥ�3 \�gV�\�\0\�i\�\n+�\r�Ҝ��Q\�\�\�\�N���/@�KN\�ae�\�|��\��\�|\��[�2�\���\�+-�խ�\�\�x','EXECUTION_PLAN');
/*!40000 ALTER TABLE `snapshots` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2022-03-24 14:43:09
