-- MySQL dump 10.13  Distrib 8.0.28, for macos10.15 (x86_64)
--
-- Host: localhost    Database: test
-- ------------------------------------------------------
-- Server version	8.0.28

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!50503 SET NAMES utf8mb4 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `alembic_version`
--

DROP TABLE IF EXISTS `alembic_version`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `alembic_version` (
  `version_num` varchar(32) NOT NULL,
  PRIMARY KEY (`version_num`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `alembic_version`
--

LOCK TABLES `alembic_version` WRITE;
/*!40000 ALTER TABLE `alembic_version` DISABLE KEYS */;
INSERT INTO `alembic_version` VALUES ('17154c80d885');
/*!40000 ALTER TABLE `alembic_version` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `asset_keys`
--

DROP TABLE IF EXISTS `asset_keys`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `asset_keys` (
  `id` int NOT NULL AUTO_INCREMENT,
  `asset_key` varchar(512) DEFAULT NULL,
  `last_materialization` text,
  `last_run_id` varchar(255) DEFAULT NULL,
  `asset_details` text,
  `wipe_timestamp` timestamp(6) NULL DEFAULT NULL,
  `last_materialization_timestamp` timestamp(6) NULL DEFAULT NULL,
  `tags` text,
  `create_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  PRIMARY KEY (`id`),
  UNIQUE KEY `asset_key` (`asset_key`)
) ENGINE=InnoDB AUTO_INCREMENT=25 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `asset_keys`
--

LOCK TABLES `asset_keys` WRITE;
/*!40000 ALTER TABLE `asset_keys` DISABLE KEYS */;
INSERT INTO `asset_keys` VALUES (1,'[\"table_info\"]','{\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/group_admins.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}','4b46487f-6f4b-4b78-b050-9a35fb29b0f7',NULL,NULL,'2022-02-02 08:00:34.089603',NULL,'2022-02-01 16:00:29.959940');
/*!40000 ALTER TABLE `asset_keys` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `bulk_actions`
--

DROP TABLE IF EXISTS `bulk_actions`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `bulk_actions` (
  `id` int NOT NULL AUTO_INCREMENT,
  `key` varchar(32) NOT NULL,
  `status` varchar(255) NOT NULL,
  `timestamp` timestamp(6) NOT NULL,
  `body` text,
  PRIMARY KEY (`id`),
  UNIQUE KEY `key` (`key`),
  KEY `idx_bulk_actions_status` (`status`(32)),
  KEY `idx_bulk_actions` (`key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `bulk_actions`
--

LOCK TABLES `bulk_actions` WRITE;
/*!40000 ALTER TABLE `bulk_actions` DISABLE KEYS */;
/*!40000 ALTER TABLE `bulk_actions` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `daemon_heartbeats`
--

DROP TABLE IF EXISTS `daemon_heartbeats`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `daemon_heartbeats` (
  `daemon_type` varchar(255) NOT NULL,
  `daemon_id` varchar(255) DEFAULT NULL,
  `timestamp` timestamp(6) NOT NULL,
  `body` text,
  UNIQUE KEY `daemon_type` (`daemon_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `daemon_heartbeats`
--

LOCK TABLES `daemon_heartbeats` WRITE;
/*!40000 ALTER TABLE `daemon_heartbeats` DISABLE KEYS */;
/*!40000 ALTER TABLE `daemon_heartbeats` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `event_logs`
--

DROP TABLE IF EXISTS `event_logs`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `event_logs` (
  `id` int NOT NULL AUTO_INCREMENT,
  `run_id` varchar(255) DEFAULT NULL,
  `event` text NOT NULL,
  `dagster_event_type` text,
  `timestamp` timestamp(6) NULL DEFAULT NULL,
  `step_key` text,
  `asset_key` text,
  `partition` text,
  PRIMARY KEY (`id`),
  KEY `idx_run_id` (`run_id`),
  KEY `idx_asset_key` (`asset_key`(32)),
  KEY `idx_step_key` (`step_key`(32)),
  KEY `idx_asset_partition` (`asset_key`(64),`partition`(64)),
  KEY `idx_event_type` (`dagster_event_type`(64),`id`)
) ENGINE=InnoDB AUTO_INCREMENT=124 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `event_logs`
--

LOCK TABLES `event_logs` WRITE;
/*!40000 ALTER TABLE `event_logs` DISABLE KEYS */;
INSERT INTO `event_logs` VALUES (1,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_STARTING\", \"logging_tags\": {}, \"message\": null, \"pid\": null, \"pipeline_name\": \"many_events\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": null, \"timestamp\": 1643760026.172183, \"user_message\": \"\"}','PIPELINE_STARTING','2022-02-02 08:00:26.172183',NULL,NULL,NULL),(2,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"cli_api_subprocess_init\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"65443\"}, \"label\": \"pid\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Started process for run (pid: 65443).\", \"pid\": null, \"pipeline_name\": \"many_events\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"Started process for run (pid: 65443).\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": null, \"timestamp\": 1643760027.9179368, \"user_message\": \"Started process for run (pid: 65443).\"}','ENGINE_EVENT','2022-02-02 08:00:27.917937',NULL,NULL,NULL),(3,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_START\", \"logging_tags\": {}, \"message\": \"Started execution of run for \\\"many_events\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - RUN_START - Started execution of run for \\\"many_events\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": null, \"timestamp\": 1643760029.5087218, \"user_message\": \"Started execution of run for \\\"many_events\\\".\"}','PIPELINE_START','2022-02-02 08:00:29.508722',NULL,NULL,NULL),(4,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"65443\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'raw_file_event_admins\', \'raw_file_events\', \'raw_file_fans\', \'raw_file_friends\', \'raw_file_group_admins\', \'raw_file_groups\', \'raw_file_pages\', \'raw_file_users\', \'many_table_materializations\', \'many_materializations_and_passing_expectations\', \'check_admins_both_succeed\', \'check_users_and_groups_one_fails_one_succeeds\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Executing steps in process (pid: 65443)\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - ENGINE_EVENT - Executing steps in process (pid: 65443)\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": null, \"timestamp\": 1643760029.655993, \"user_message\": \"Executing steps in process (pid: 65443)\"}','ENGINE_EVENT','2022-02-02 08:00:29.655993',NULL,NULL,NULL),(5,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": \"resources\", \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Starting initialization of resources [io_manager].\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - ENGINE_EVENT - Starting initialization of resources [io_manager].\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": null, \"timestamp\": 1643760029.69892, \"user_message\": \"Starting initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-02-02 08:00:29.698920',NULL,NULL,NULL),(6,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": \"resources\", \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": \"Initialized in 0.07ms\", \"entry_data\": {\"__class__\": \"PythonArtifactMetadataEntryData\", \"module\": \"dagster.core.storage.fs_io_manager\", \"name\": \"PickledObjectFilesystemIOManager\"}, \"label\": \"io_manager\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished initialization of resources [io_manager].\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - ENGINE_EVENT - Finished initialization of resources [io_manager].\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": null, \"timestamp\": 1643760029.7331789, \"user_message\": \"Finished initialization of resources [io_manager].\"}','ENGINE_EVENT','2022-02-02 08:00:29.733179',NULL,NULL,NULL),(7,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"raw_file_event_admins\", \"step_keys\": [\"raw_file_event_admins\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_event_admins\", \"step_key\": \"raw_file_event_admins\"}, \"message\": \"Started capturing logs for step: raw_file_event_admins.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_event_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}}, \"step_key\": \"raw_file_event_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_event_admins - LOGS_CAPTURED - Started capturing logs for step: raw_file_event_admins.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_event_admins\", \"timestamp\": 1643760029.789186, \"user_message\": \"Started capturing logs for step: raw_file_event_admins.\"}','LOGS_CAPTURED','2022-02-02 08:00:29.789186','raw_file_event_admins',NULL,NULL),(8,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_event_admins\", \"step_key\": \"raw_file_event_admins\"}, \"message\": \"Started execution of step \\\"raw_file_event_admins\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_event_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}}, \"step_key\": \"raw_file_event_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_event_admins - STEP_START - Started execution of step \\\"raw_file_event_admins\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_event_admins\", \"timestamp\": 1643760029.82894, \"user_message\": \"Started execution of step \\\"raw_file_event_admins\\\".\"}','STEP_START','2022-02-02 08:00:29.828940','raw_file_event_admins',NULL,NULL),(9,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_file_event_admins.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_event_admins\", \"step_key\": \"raw_file_event_admins\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_event_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}}, \"step_key\": \"raw_file_event_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_event_admins - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_event_admins\", \"timestamp\": 1643760029.863771, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:29.863771','raw_file_event_admins','[\"table_info\"]',NULL),(10,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Checked raw_file_event_admins exists\", \"label\": \"output_table_exists\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_event_admins\", \"step_key\": \"raw_file_event_admins\"}, \"message\": \"Checked raw_file_event_admins exists\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_event_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}}, \"step_key\": \"raw_file_event_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_event_admins - STEP_EXPECTATION_RESULT - Checked raw_file_event_admins exists\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_event_admins\", \"timestamp\": 1643760029.964532, \"user_message\": \"Checked raw_file_event_admins exists\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:29.964532','raw_file_event_admins',NULL,NULL),(11,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"raw_file_event_admins\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_event_admins\", \"step_key\": \"raw_file_event_admins\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_event_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}}, \"step_key\": \"raw_file_event_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_event_admins - STEP_OUTPUT - Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_event_admins\", \"timestamp\": 1643760029.999317, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-02-02 08:00:29.999317','raw_file_event_admins',NULL,NULL),(12,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - raw_file_event_admins - Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_event_admins/result\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_event_admins\", \"timestamp\": 1643760030.034131, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_event_admins/result\"}',NULL,'2022-02-02 08:00:30.034131','raw_file_event_admins',NULL,NULL),(13,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_event_admins\", \"step_key\": \"raw_file_event_admins\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_event_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}}, \"step_key\": \"raw_file_event_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_event_admins - HANDLED_OUTPUT - Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_event_admins\", \"timestamp\": 1643760030.068736, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-02-02 08:00:30.068736','raw_file_event_admins',NULL,NULL),(14,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 239.02803800000027}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_event_admins\", \"step_key\": \"raw_file_event_admins\"}, \"message\": \"Finished execution of step \\\"raw_file_event_admins\\\" in 239ms.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_event_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_event_admins\", \"parent\": null}}, \"step_key\": \"raw_file_event_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_event_admins - STEP_SUCCESS - Finished execution of step \\\"raw_file_event_admins\\\" in 239ms.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_event_admins\", \"timestamp\": 1643760030.1023831, \"user_message\": \"Finished execution of step \\\"raw_file_event_admins\\\" in 239ms.\"}','STEP_SUCCESS','2022-02-02 08:00:30.102383','raw_file_event_admins',NULL,NULL),(15,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"raw_file_events\", \"step_keys\": [\"raw_file_events\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_events\", \"step_key\": \"raw_file_events\"}, \"message\": \"Started capturing logs for step: raw_file_events.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}}, \"step_key\": \"raw_file_events\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_events - LOGS_CAPTURED - Started capturing logs for step: raw_file_events.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_events\", \"timestamp\": 1643760030.153903, \"user_message\": \"Started capturing logs for step: raw_file_events.\"}','LOGS_CAPTURED','2022-02-02 08:00:30.153903','raw_file_events',NULL,NULL),(16,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_events\", \"step_key\": \"raw_file_events\"}, \"message\": \"Started execution of step \\\"raw_file_events\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}}, \"step_key\": \"raw_file_events\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_events - STEP_START - Started execution of step \\\"raw_file_events\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_events\", \"timestamp\": 1643760030.192019, \"user_message\": \"Started execution of step \\\"raw_file_events\\\".\"}','STEP_START','2022-02-02 08:00:30.192019','raw_file_events',NULL,NULL),(17,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_file_events.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_events\", \"step_key\": \"raw_file_events\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}}, \"step_key\": \"raw_file_events\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_events - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_events\", \"timestamp\": 1643760030.226206, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:30.226206','raw_file_events','[\"table_info\"]',NULL),(18,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Checked raw_file_events exists\", \"label\": \"output_table_exists\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_events\", \"step_key\": \"raw_file_events\"}, \"message\": \"Checked raw_file_events exists\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}}, \"step_key\": \"raw_file_events\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_events - STEP_EXPECTATION_RESULT - Checked raw_file_events exists\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_events\", \"timestamp\": 1643760030.293391, \"user_message\": \"Checked raw_file_events exists\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:30.293391','raw_file_events',NULL,NULL),(19,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"raw_file_events\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_events\", \"step_key\": \"raw_file_events\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}}, \"step_key\": \"raw_file_events\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_events - STEP_OUTPUT - Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_events\", \"timestamp\": 1643760030.326891, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-02-02 08:00:30.326891','raw_file_events',NULL,NULL),(20,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - raw_file_events - Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_events/result\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_events\", \"timestamp\": 1643760030.366335, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_events/result\"}',NULL,'2022-02-02 08:00:30.366335','raw_file_events',NULL,NULL),(21,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_events\", \"step_key\": \"raw_file_events\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}}, \"step_key\": \"raw_file_events\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_events - HANDLED_OUTPUT - Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_events\", \"timestamp\": 1643760030.399551, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-02-02 08:00:30.399551','raw_file_events',NULL,NULL),(22,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 206.58725600000017}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_events\", \"step_key\": \"raw_file_events\"}, \"message\": \"Finished execution of step \\\"raw_file_events\\\" in 206ms.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_events\", \"parent\": null}}, \"step_key\": \"raw_file_events\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_events - STEP_SUCCESS - Finished execution of step \\\"raw_file_events\\\" in 206ms.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_events\", \"timestamp\": 1643760030.432292, \"user_message\": \"Finished execution of step \\\"raw_file_events\\\" in 206ms.\"}','STEP_SUCCESS','2022-02-02 08:00:30.432292','raw_file_events',NULL,NULL),(23,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"raw_file_fans\", \"step_keys\": [\"raw_file_fans\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_fans\", \"step_key\": \"raw_file_fans\"}, \"message\": \"Started capturing logs for step: raw_file_fans.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_fans\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}}, \"step_key\": \"raw_file_fans\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_fans - LOGS_CAPTURED - Started capturing logs for step: raw_file_fans.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_fans\", \"timestamp\": 1643760030.4847941, \"user_message\": \"Started capturing logs for step: raw_file_fans.\"}','LOGS_CAPTURED','2022-02-02 08:00:30.484794','raw_file_fans',NULL,NULL),(24,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_fans\", \"step_key\": \"raw_file_fans\"}, \"message\": \"Started execution of step \\\"raw_file_fans\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_fans\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}}, \"step_key\": \"raw_file_fans\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_fans - STEP_START - Started execution of step \\\"raw_file_fans\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_fans\", \"timestamp\": 1643760030.52261, \"user_message\": \"Started execution of step \\\"raw_file_fans\\\".\"}','STEP_START','2022-02-02 08:00:30.522610','raw_file_fans',NULL,NULL),(25,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_file_fans.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_fans\", \"step_key\": \"raw_file_fans\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_fans\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}}, \"step_key\": \"raw_file_fans\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_fans - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_fans\", \"timestamp\": 1643760030.556635, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:30.556635','raw_file_fans','[\"table_info\"]',NULL),(26,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Checked raw_file_fans exists\", \"label\": \"output_table_exists\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_fans\", \"step_key\": \"raw_file_fans\"}, \"message\": \"Checked raw_file_fans exists\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_fans\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}}, \"step_key\": \"raw_file_fans\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_fans - STEP_EXPECTATION_RESULT - Checked raw_file_fans exists\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_fans\", \"timestamp\": 1643760030.6226308, \"user_message\": \"Checked raw_file_fans exists\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:30.622631','raw_file_fans',NULL,NULL),(27,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"raw_file_fans\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_fans\", \"step_key\": \"raw_file_fans\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_fans\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}}, \"step_key\": \"raw_file_fans\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_fans - STEP_OUTPUT - Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_fans\", \"timestamp\": 1643760030.656472, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-02-02 08:00:30.656472','raw_file_fans',NULL,NULL),(28,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - raw_file_fans - Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_fans/result\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_fans\", \"timestamp\": 1643760030.690102, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_fans/result\"}',NULL,'2022-02-02 08:00:30.690102','raw_file_fans',NULL,NULL),(29,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_fans\", \"step_key\": \"raw_file_fans\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_fans\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}}, \"step_key\": \"raw_file_fans\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_fans - HANDLED_OUTPUT - Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_fans\", \"timestamp\": 1643760030.7232482, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-02-02 08:00:30.723248','raw_file_fans',NULL,NULL),(30,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 200.51053099999993}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_fans\", \"step_key\": \"raw_file_fans\"}, \"message\": \"Finished execution of step \\\"raw_file_fans\\\" in 200ms.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_fans\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_fans\", \"parent\": null}}, \"step_key\": \"raw_file_fans\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_fans - STEP_SUCCESS - Finished execution of step \\\"raw_file_fans\\\" in 200ms.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_fans\", \"timestamp\": 1643760030.756779, \"user_message\": \"Finished execution of step \\\"raw_file_fans\\\" in 200ms.\"}','STEP_SUCCESS','2022-02-02 08:00:30.756779','raw_file_fans',NULL,NULL),(31,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"raw_file_friends\", \"step_keys\": [\"raw_file_friends\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_friends\", \"step_key\": \"raw_file_friends\"}, \"message\": \"Started capturing logs for step: raw_file_friends.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_friends\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}}, \"step_key\": \"raw_file_friends\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_friends - LOGS_CAPTURED - Started capturing logs for step: raw_file_friends.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_friends\", \"timestamp\": 1643760030.810792, \"user_message\": \"Started capturing logs for step: raw_file_friends.\"}','LOGS_CAPTURED','2022-02-02 08:00:30.810792','raw_file_friends',NULL,NULL),(32,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_friends\", \"step_key\": \"raw_file_friends\"}, \"message\": \"Started execution of step \\\"raw_file_friends\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_friends\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}}, \"step_key\": \"raw_file_friends\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_friends - STEP_START - Started execution of step \\\"raw_file_friends\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_friends\", \"timestamp\": 1643760030.8485389, \"user_message\": \"Started execution of step \\\"raw_file_friends\\\".\"}','STEP_START','2022-02-02 08:00:30.848539','raw_file_friends',NULL,NULL),(33,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_file_friends.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_friends\", \"step_key\": \"raw_file_friends\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_friends\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}}, \"step_key\": \"raw_file_friends\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_friends - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_friends\", \"timestamp\": 1643760030.883382, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:30.883382','raw_file_friends','[\"table_info\"]',NULL),(34,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Checked raw_file_friends exists\", \"label\": \"output_table_exists\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_friends\", \"step_key\": \"raw_file_friends\"}, \"message\": \"Checked raw_file_friends exists\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_friends\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}}, \"step_key\": \"raw_file_friends\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_friends - STEP_EXPECTATION_RESULT - Checked raw_file_friends exists\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_friends\", \"timestamp\": 1643760030.951942, \"user_message\": \"Checked raw_file_friends exists\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:30.951942','raw_file_friends',NULL,NULL),(35,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"raw_file_friends\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_friends\", \"step_key\": \"raw_file_friends\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_friends\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}}, \"step_key\": \"raw_file_friends\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_friends - STEP_OUTPUT - Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_friends\", \"timestamp\": 1643760030.986252, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-02-02 08:00:30.986252','raw_file_friends',NULL,NULL),(36,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - raw_file_friends - Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_friends/result\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_friends\", \"timestamp\": 1643760031.019991, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_friends/result\"}',NULL,'2022-02-02 08:00:31.019991','raw_file_friends',NULL,NULL),(37,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_friends\", \"step_key\": \"raw_file_friends\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_friends\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}}, \"step_key\": \"raw_file_friends\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_friends - HANDLED_OUTPUT - Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_friends\", \"timestamp\": 1643760031.053062, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-02-02 08:00:31.053062','raw_file_friends',NULL,NULL),(38,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 204.8331919999997}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_friends\", \"step_key\": \"raw_file_friends\"}, \"message\": \"Finished execution of step \\\"raw_file_friends\\\" in 204ms.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_friends\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_friends\", \"parent\": null}}, \"step_key\": \"raw_file_friends\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_friends - STEP_SUCCESS - Finished execution of step \\\"raw_file_friends\\\" in 204ms.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_friends\", \"timestamp\": 1643760031.087838, \"user_message\": \"Finished execution of step \\\"raw_file_friends\\\" in 204ms.\"}','STEP_SUCCESS','2022-02-02 08:00:31.087838','raw_file_friends',NULL,NULL),(39,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"raw_file_group_admins\", \"step_keys\": [\"raw_file_group_admins\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_group_admins\", \"step_key\": \"raw_file_group_admins\"}, \"message\": \"Started capturing logs for step: raw_file_group_admins.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_group_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}}, \"step_key\": \"raw_file_group_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_group_admins - LOGS_CAPTURED - Started capturing logs for step: raw_file_group_admins.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_group_admins\", \"timestamp\": 1643760031.140338, \"user_message\": \"Started capturing logs for step: raw_file_group_admins.\"}','LOGS_CAPTURED','2022-02-02 08:00:31.140338','raw_file_group_admins',NULL,NULL),(40,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_group_admins\", \"step_key\": \"raw_file_group_admins\"}, \"message\": \"Started execution of step \\\"raw_file_group_admins\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_group_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}}, \"step_key\": \"raw_file_group_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_group_admins - STEP_START - Started execution of step \\\"raw_file_group_admins\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_group_admins\", \"timestamp\": 1643760031.176206, \"user_message\": \"Started execution of step \\\"raw_file_group_admins\\\".\"}','STEP_START','2022-02-02 08:00:31.176206','raw_file_group_admins',NULL,NULL),(41,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_file_group_admins.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_group_admins\", \"step_key\": \"raw_file_group_admins\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_group_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}}, \"step_key\": \"raw_file_group_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_group_admins - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_group_admins\", \"timestamp\": 1643760031.210463, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:31.210463','raw_file_group_admins','[\"table_info\"]',NULL),(42,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Checked raw_file_group_admins exists\", \"label\": \"output_table_exists\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_group_admins\", \"step_key\": \"raw_file_group_admins\"}, \"message\": \"Checked raw_file_group_admins exists\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_group_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}}, \"step_key\": \"raw_file_group_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_group_admins - STEP_EXPECTATION_RESULT - Checked raw_file_group_admins exists\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_group_admins\", \"timestamp\": 1643760031.279069, \"user_message\": \"Checked raw_file_group_admins exists\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:31.279069','raw_file_group_admins',NULL,NULL),(43,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"raw_file_group_admins\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_group_admins\", \"step_key\": \"raw_file_group_admins\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_group_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}}, \"step_key\": \"raw_file_group_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_group_admins - STEP_OUTPUT - Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_group_admins\", \"timestamp\": 1643760031.313173, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-02-02 08:00:31.313173','raw_file_group_admins',NULL,NULL),(44,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - raw_file_group_admins - Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_group_admins/result\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_group_admins\", \"timestamp\": 1643760031.347248, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_group_admins/result\"}',NULL,'2022-02-02 08:00:31.347248','raw_file_group_admins',NULL,NULL),(45,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_group_admins\", \"step_key\": \"raw_file_group_admins\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_group_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}}, \"step_key\": \"raw_file_group_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_group_admins - HANDLED_OUTPUT - Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_group_admins\", \"timestamp\": 1643760031.3807318, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-02-02 08:00:31.380732','raw_file_group_admins',NULL,NULL),(46,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 204.25370899999962}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_group_admins\", \"step_key\": \"raw_file_group_admins\"}, \"message\": \"Finished execution of step \\\"raw_file_group_admins\\\" in 204ms.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_group_admins\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_group_admins\", \"parent\": null}}, \"step_key\": \"raw_file_group_admins\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_group_admins - STEP_SUCCESS - Finished execution of step \\\"raw_file_group_admins\\\" in 204ms.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_group_admins\", \"timestamp\": 1643760031.414305, \"user_message\": \"Finished execution of step \\\"raw_file_group_admins\\\" in 204ms.\"}','STEP_SUCCESS','2022-02-02 08:00:31.414305','raw_file_group_admins',NULL,NULL),(47,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"raw_file_groups\", \"step_keys\": [\"raw_file_groups\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_groups\", \"step_key\": \"raw_file_groups\"}, \"message\": \"Started capturing logs for step: raw_file_groups.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_groups\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}}, \"step_key\": \"raw_file_groups\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_groups - LOGS_CAPTURED - Started capturing logs for step: raw_file_groups.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_groups\", \"timestamp\": 1643760031.467774, \"user_message\": \"Started capturing logs for step: raw_file_groups.\"}','LOGS_CAPTURED','2022-02-02 08:00:31.467774','raw_file_groups',NULL,NULL),(48,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_groups\", \"step_key\": \"raw_file_groups\"}, \"message\": \"Started execution of step \\\"raw_file_groups\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_groups\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}}, \"step_key\": \"raw_file_groups\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_groups - STEP_START - Started execution of step \\\"raw_file_groups\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_groups\", \"timestamp\": 1643760031.504458, \"user_message\": \"Started execution of step \\\"raw_file_groups\\\".\"}','STEP_START','2022-02-02 08:00:31.504458','raw_file_groups',NULL,NULL),(49,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_file_groups.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_groups\", \"step_key\": \"raw_file_groups\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_groups\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}}, \"step_key\": \"raw_file_groups\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_groups - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_groups\", \"timestamp\": 1643760031.539412, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:31.539412','raw_file_groups','[\"table_info\"]',NULL),(50,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Checked raw_file_groups exists\", \"label\": \"output_table_exists\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_groups\", \"step_key\": \"raw_file_groups\"}, \"message\": \"Checked raw_file_groups exists\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_groups\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}}, \"step_key\": \"raw_file_groups\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_groups - STEP_EXPECTATION_RESULT - Checked raw_file_groups exists\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_groups\", \"timestamp\": 1643760031.606389, \"user_message\": \"Checked raw_file_groups exists\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:31.606389','raw_file_groups',NULL,NULL),(51,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"raw_file_groups\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_groups\", \"step_key\": \"raw_file_groups\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_groups\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}}, \"step_key\": \"raw_file_groups\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_groups - STEP_OUTPUT - Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_groups\", \"timestamp\": 1643760031.6396952, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-02-02 08:00:31.639695','raw_file_groups',NULL,NULL),(52,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - raw_file_groups - Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_groups/result\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_groups\", \"timestamp\": 1643760031.673782, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_groups/result\"}',NULL,'2022-02-02 08:00:31.673782','raw_file_groups',NULL,NULL),(53,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_groups\", \"step_key\": \"raw_file_groups\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_groups\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}}, \"step_key\": \"raw_file_groups\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_groups - HANDLED_OUTPUT - Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_groups\", \"timestamp\": 1643760031.706825, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-02-02 08:00:31.706825','raw_file_groups',NULL,NULL),(54,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 201.55872999999946}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_groups\", \"step_key\": \"raw_file_groups\"}, \"message\": \"Finished execution of step \\\"raw_file_groups\\\" in 201ms.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_groups\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_groups\", \"parent\": null}}, \"step_key\": \"raw_file_groups\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_groups - STEP_SUCCESS - Finished execution of step \\\"raw_file_groups\\\" in 201ms.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_groups\", \"timestamp\": 1643760031.7406101, \"user_message\": \"Finished execution of step \\\"raw_file_groups\\\" in 201ms.\"}','STEP_SUCCESS','2022-02-02 08:00:31.740610','raw_file_groups',NULL,NULL),(55,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"raw_file_pages\", \"step_keys\": [\"raw_file_pages\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_pages\", \"step_key\": \"raw_file_pages\"}, \"message\": \"Started capturing logs for step: raw_file_pages.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_pages\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}}, \"step_key\": \"raw_file_pages\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_pages - LOGS_CAPTURED - Started capturing logs for step: raw_file_pages.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_pages\", \"timestamp\": 1643760031.7918222, \"user_message\": \"Started capturing logs for step: raw_file_pages.\"}','LOGS_CAPTURED','2022-02-02 08:00:31.791822','raw_file_pages',NULL,NULL),(56,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_pages\", \"step_key\": \"raw_file_pages\"}, \"message\": \"Started execution of step \\\"raw_file_pages\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_pages\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}}, \"step_key\": \"raw_file_pages\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_pages - STEP_START - Started execution of step \\\"raw_file_pages\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_pages\", \"timestamp\": 1643760031.830007, \"user_message\": \"Started execution of step \\\"raw_file_pages\\\".\"}','STEP_START','2022-02-02 08:00:31.830007','raw_file_pages',NULL,NULL),(57,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_file_pages.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_pages\", \"step_key\": \"raw_file_pages\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_pages\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}}, \"step_key\": \"raw_file_pages\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_pages - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_pages\", \"timestamp\": 1643760031.8651578, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:31.865158','raw_file_pages','[\"table_info\"]',NULL),(58,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Checked raw_file_pages exists\", \"label\": \"output_table_exists\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_pages\", \"step_key\": \"raw_file_pages\"}, \"message\": \"Checked raw_file_pages exists\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_pages\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}}, \"step_key\": \"raw_file_pages\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_pages - STEP_EXPECTATION_RESULT - Checked raw_file_pages exists\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_pages\", \"timestamp\": 1643760031.9331992, \"user_message\": \"Checked raw_file_pages exists\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:31.933199','raw_file_pages',NULL,NULL),(59,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"raw_file_pages\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_pages\", \"step_key\": \"raw_file_pages\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_pages\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}}, \"step_key\": \"raw_file_pages\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_pages - STEP_OUTPUT - Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_pages\", \"timestamp\": 1643760031.966362, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-02-02 08:00:31.966362','raw_file_pages',NULL,NULL),(60,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - raw_file_pages - Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_pages/result\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_pages\", \"timestamp\": 1643760032.0004091, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_pages/result\"}',NULL,'2022-02-02 08:00:32.000409','raw_file_pages',NULL,NULL),(61,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_pages\", \"step_key\": \"raw_file_pages\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_pages\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}}, \"step_key\": \"raw_file_pages\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_pages - HANDLED_OUTPUT - Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_pages\", \"timestamp\": 1643760032.033721, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-02-02 08:00:32.033721','raw_file_pages',NULL,NULL),(62,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 202.0963259999995}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_pages\", \"step_key\": \"raw_file_pages\"}, \"message\": \"Finished execution of step \\\"raw_file_pages\\\" in 202ms.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_pages\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_pages\", \"parent\": null}}, \"step_key\": \"raw_file_pages\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_pages - STEP_SUCCESS - Finished execution of step \\\"raw_file_pages\\\" in 202ms.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_pages\", \"timestamp\": 1643760032.0668921, \"user_message\": \"Finished execution of step \\\"raw_file_pages\\\" in 202ms.\"}','STEP_SUCCESS','2022-02-02 08:00:32.066892','raw_file_pages',NULL,NULL),(63,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"raw_file_users\", \"step_keys\": [\"raw_file_users\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_users\", \"step_key\": \"raw_file_users\"}, \"message\": \"Started capturing logs for step: raw_file_users.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_users\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}}, \"step_key\": \"raw_file_users\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_users - LOGS_CAPTURED - Started capturing logs for step: raw_file_users.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_users\", \"timestamp\": 1643760032.120246, \"user_message\": \"Started capturing logs for step: raw_file_users.\"}','LOGS_CAPTURED','2022-02-02 08:00:32.120246','raw_file_users',NULL,NULL),(64,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_users\", \"step_key\": \"raw_file_users\"}, \"message\": \"Started execution of step \\\"raw_file_users\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_users\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}}, \"step_key\": \"raw_file_users\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_users - STEP_START - Started execution of step \\\"raw_file_users\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_users\", \"timestamp\": 1643760032.1564858, \"user_message\": \"Started execution of step \\\"raw_file_users\\\".\"}','STEP_START','2022-02-02 08:00:32.156486','raw_file_users',NULL,NULL),(65,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_file_users.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_users\", \"step_key\": \"raw_file_users\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_users\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}}, \"step_key\": \"raw_file_users\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_users - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_users\", \"timestamp\": 1643760032.1902258, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:32.190226','raw_file_users','[\"table_info\"]',NULL),(66,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Checked raw_file_users exists\", \"label\": \"output_table_exists\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_users\", \"step_key\": \"raw_file_users\"}, \"message\": \"Checked raw_file_users exists\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_users\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}}, \"step_key\": \"raw_file_users\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_users - STEP_EXPECTATION_RESULT - Checked raw_file_users exists\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_users\", \"timestamp\": 1643760032.260885, \"user_message\": \"Checked raw_file_users exists\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:32.260885','raw_file_users',NULL,NULL),(67,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"raw_file_users\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_users\", \"step_key\": \"raw_file_users\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_users\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}}, \"step_key\": \"raw_file_users\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_users - STEP_OUTPUT - Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_users\", \"timestamp\": 1643760032.294938, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Any\\\". (Type check passed).\"}','STEP_OUTPUT','2022-02-02 08:00:32.294938','raw_file_users',NULL,NULL),(68,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - raw_file_users - Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_users/result\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_users\", \"timestamp\": 1643760032.328216, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/raw_file_users/result\"}',NULL,'2022-02-02 08:00:32.328216','raw_file_users',NULL,NULL),(69,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_users\", \"step_key\": \"raw_file_users\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_users\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}}, \"step_key\": \"raw_file_users\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_users - HANDLED_OUTPUT - Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_users\", \"timestamp\": 1643760032.361396, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-02-02 08:00:32.361396','raw_file_users',NULL,NULL),(70,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 205.3495879999998}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"raw_file_users\", \"step_key\": \"raw_file_users\"}, \"message\": \"Finished execution of step \\\"raw_file_users\\\" in 205ms.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"raw_file_users\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"raw_file_users\", \"parent\": null}}, \"step_key\": \"raw_file_users\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - raw_file_users - STEP_SUCCESS - Finished execution of step \\\"raw_file_users\\\" in 205ms.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"raw_file_users\", \"timestamp\": 1643760032.395203, \"user_message\": \"Finished execution of step \\\"raw_file_users\\\" in 205ms.\"}','STEP_SUCCESS','2022-02-02 08:00:32.395203','raw_file_users',NULL,NULL),(71,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"many_table_materializations\", \"step_keys\": [\"many_table_materializations\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Started capturing logs for step: many_table_materializations.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - LOGS_CAPTURED - Started capturing logs for step: many_table_materializations.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760032.447849, \"user_message\": \"Started capturing logs for step: many_table_materializations.\"}','LOGS_CAPTURED','2022-02-02 08:00:32.447849','many_table_materializations',NULL,NULL),(72,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Started execution of step \\\"many_table_materializations\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - STEP_START - Started execution of step \\\"many_table_materializations\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760032.483339, \"user_message\": \"Started execution of step \\\"many_table_materializations\\\".\"}','STEP_START','2022-02-02 08:00:32.483339','many_table_materializations',NULL,NULL),(73,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"raw_users\"}, \"label\": \"table_name\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_users\"}, \"label\": \"table_path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"name\": \"raw_users\"}}, \"label\": \"table_data\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"UrlMetadataEntryData\", \"url\": \"https://bigty.pe/raw_users\"}, \"label\": \"table_name_big\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"MarkdownMetadataEntryData\", \"md_str\": \"# h1 Heading :)\\n\\n## h2 Heading\\n\\n### h3 Heading\\n\\n#### h4 Heading\\n\\n##### h5 Heading\\n\\n###### h6 Heading\\n\\n## Horizontal Rules\\n\\n---\\n\\n## Blockquotes\\n\\n> Blockquote can be nested\\n>\\n> > indentation by arrow level\\n\\n## Unordered lists\\n\\n- One\\n- Two\\n  - Indented\\n- Three\\n\\n## Ordered lists\\n\\n1. One\\n1. Two\\n1. Three\\n\\n## Code\\n\\nInline `code`\\n\\n    // comments\\n    line 1 of code\\n    line 2 of code\\n    line 3 of code\\n\\n## Links\\n\\n[rick roll](https://www.youtube.com/watch?v=dQw4w9WgXcQ)\\n\"}, \"label\": \"table_blurb\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"IntMetadataEntryData\", \"value\": 29119888133298982934829348}, \"label\": \"big_int\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"FloatMetadataEntryData\", \"value\": NaN}, \"label\": \"float_nan\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760032.5186508, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:32.518651','many_table_materializations','[\"table_info\"]',NULL),(74,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"raw_groups\"}, \"label\": \"table_name\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_groups\"}, \"label\": \"table_path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"name\": \"raw_groups\"}}, \"label\": \"table_data\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"UrlMetadataEntryData\", \"url\": \"https://bigty.pe/raw_groups\"}, \"label\": \"table_name_big\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"MarkdownMetadataEntryData\", \"md_str\": \"# h1 Heading :)\\n\\n## h2 Heading\\n\\n### h3 Heading\\n\\n#### h4 Heading\\n\\n##### h5 Heading\\n\\n###### h6 Heading\\n\\n## Horizontal Rules\\n\\n---\\n\\n## Blockquotes\\n\\n> Blockquote can be nested\\n>\\n> > indentation by arrow level\\n\\n## Unordered lists\\n\\n- One\\n- Two\\n  - Indented\\n- Three\\n\\n## Ordered lists\\n\\n1. One\\n1. Two\\n1. Three\\n\\n## Code\\n\\nInline `code`\\n\\n    // comments\\n    line 1 of code\\n    line 2 of code\\n    line 3 of code\\n\\n## Links\\n\\n[rick roll](https://www.youtube.com/watch?v=dQw4w9WgXcQ)\\n\"}, \"label\": \"table_blurb\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"IntMetadataEntryData\", \"value\": 29119888133298982934829348}, \"label\": \"big_int\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"FloatMetadataEntryData\", \"value\": NaN}, \"label\": \"float_nan\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760032.586886, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:32.586886','many_table_materializations','[\"table_info\"]',NULL),(75,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"raw_events\"}, \"label\": \"table_name\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_events\"}, \"label\": \"table_path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"name\": \"raw_events\"}}, \"label\": \"table_data\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"UrlMetadataEntryData\", \"url\": \"https://bigty.pe/raw_events\"}, \"label\": \"table_name_big\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"MarkdownMetadataEntryData\", \"md_str\": \"# h1 Heading :)\\n\\n## h2 Heading\\n\\n### h3 Heading\\n\\n#### h4 Heading\\n\\n##### h5 Heading\\n\\n###### h6 Heading\\n\\n## Horizontal Rules\\n\\n---\\n\\n## Blockquotes\\n\\n> Blockquote can be nested\\n>\\n> > indentation by arrow level\\n\\n## Unordered lists\\n\\n- One\\n- Two\\n  - Indented\\n- Three\\n\\n## Ordered lists\\n\\n1. One\\n1. Two\\n1. Three\\n\\n## Code\\n\\nInline `code`\\n\\n    // comments\\n    line 1 of code\\n    line 2 of code\\n    line 3 of code\\n\\n## Links\\n\\n[rick roll](https://www.youtube.com/watch?v=dQw4w9WgXcQ)\\n\"}, \"label\": \"table_blurb\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"IntMetadataEntryData\", \"value\": 29119888133298982934829348}, \"label\": \"big_int\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"FloatMetadataEntryData\", \"value\": NaN}, \"label\": \"float_nan\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760032.667171, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:32.667171','many_table_materializations','[\"table_info\"]',NULL),(76,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"raw_friends\"}, \"label\": \"table_name\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_friends\"}, \"label\": \"table_path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"name\": \"raw_friends\"}}, \"label\": \"table_data\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"UrlMetadataEntryData\", \"url\": \"https://bigty.pe/raw_friends\"}, \"label\": \"table_name_big\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"MarkdownMetadataEntryData\", \"md_str\": \"# h1 Heading :)\\n\\n## h2 Heading\\n\\n### h3 Heading\\n\\n#### h4 Heading\\n\\n##### h5 Heading\\n\\n###### h6 Heading\\n\\n## Horizontal Rules\\n\\n---\\n\\n## Blockquotes\\n\\n> Blockquote can be nested\\n>\\n> > indentation by arrow level\\n\\n## Unordered lists\\n\\n- One\\n- Two\\n  - Indented\\n- Three\\n\\n## Ordered lists\\n\\n1. One\\n1. Two\\n1. Three\\n\\n## Code\\n\\nInline `code`\\n\\n    // comments\\n    line 1 of code\\n    line 2 of code\\n    line 3 of code\\n\\n## Links\\n\\n[rick roll](https://www.youtube.com/watch?v=dQw4w9WgXcQ)\\n\"}, \"label\": \"table_blurb\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"IntMetadataEntryData\", \"value\": 29119888133298982934829348}, \"label\": \"big_int\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"FloatMetadataEntryData\", \"value\": NaN}, \"label\": \"float_nan\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760032.746696, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:32.746696','many_table_materializations','[\"table_info\"]',NULL),(77,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"raw_pages\"}, \"label\": \"table_name\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_pages\"}, \"label\": \"table_path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"name\": \"raw_pages\"}}, \"label\": \"table_data\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"UrlMetadataEntryData\", \"url\": \"https://bigty.pe/raw_pages\"}, \"label\": \"table_name_big\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"MarkdownMetadataEntryData\", \"md_str\": \"# h1 Heading :)\\n\\n## h2 Heading\\n\\n### h3 Heading\\n\\n#### h4 Heading\\n\\n##### h5 Heading\\n\\n###### h6 Heading\\n\\n## Horizontal Rules\\n\\n---\\n\\n## Blockquotes\\n\\n> Blockquote can be nested\\n>\\n> > indentation by arrow level\\n\\n## Unordered lists\\n\\n- One\\n- Two\\n  - Indented\\n- Three\\n\\n## Ordered lists\\n\\n1. One\\n1. Two\\n1. Three\\n\\n## Code\\n\\nInline `code`\\n\\n    // comments\\n    line 1 of code\\n    line 2 of code\\n    line 3 of code\\n\\n## Links\\n\\n[rick roll](https://www.youtube.com/watch?v=dQw4w9WgXcQ)\\n\"}, \"label\": \"table_blurb\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"IntMetadataEntryData\", \"value\": 29119888133298982934829348}, \"label\": \"big_int\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"FloatMetadataEntryData\", \"value\": NaN}, \"label\": \"float_nan\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760032.816212, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:32.816212','many_table_materializations','[\"table_info\"]',NULL),(78,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"raw_fans\"}, \"label\": \"table_name\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_fans\"}, \"label\": \"table_path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"name\": \"raw_fans\"}}, \"label\": \"table_data\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"UrlMetadataEntryData\", \"url\": \"https://bigty.pe/raw_fans\"}, \"label\": \"table_name_big\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"MarkdownMetadataEntryData\", \"md_str\": \"# h1 Heading :)\\n\\n## h2 Heading\\n\\n### h3 Heading\\n\\n#### h4 Heading\\n\\n##### h5 Heading\\n\\n###### h6 Heading\\n\\n## Horizontal Rules\\n\\n---\\n\\n## Blockquotes\\n\\n> Blockquote can be nested\\n>\\n> > indentation by arrow level\\n\\n## Unordered lists\\n\\n- One\\n- Two\\n  - Indented\\n- Three\\n\\n## Ordered lists\\n\\n1. One\\n1. Two\\n1. Three\\n\\n## Code\\n\\nInline `code`\\n\\n    // comments\\n    line 1 of code\\n    line 2 of code\\n    line 3 of code\\n\\n## Links\\n\\n[rick roll](https://www.youtube.com/watch?v=dQw4w9WgXcQ)\\n\"}, \"label\": \"table_blurb\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"IntMetadataEntryData\", \"value\": 29119888133298982934829348}, \"label\": \"big_int\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"FloatMetadataEntryData\", \"value\": NaN}, \"label\": \"float_nan\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760032.886496, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:32.886496','many_table_materializations','[\"table_info\"]',NULL),(79,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"raw_event_admins\"}, \"label\": \"table_name\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_event_admins\"}, \"label\": \"table_path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"name\": \"raw_event_admins\"}}, \"label\": \"table_data\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"UrlMetadataEntryData\", \"url\": \"https://bigty.pe/raw_event_admins\"}, \"label\": \"table_name_big\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"MarkdownMetadataEntryData\", \"md_str\": \"# h1 Heading :)\\n\\n## h2 Heading\\n\\n### h3 Heading\\n\\n#### h4 Heading\\n\\n##### h5 Heading\\n\\n###### h6 Heading\\n\\n## Horizontal Rules\\n\\n---\\n\\n## Blockquotes\\n\\n> Blockquote can be nested\\n>\\n> > indentation by arrow level\\n\\n## Unordered lists\\n\\n- One\\n- Two\\n  - Indented\\n- Three\\n\\n## Ordered lists\\n\\n1. One\\n1. Two\\n1. Three\\n\\n## Code\\n\\nInline `code`\\n\\n    // comments\\n    line 1 of code\\n    line 2 of code\\n    line 3 of code\\n\\n## Links\\n\\n[rick roll](https://www.youtube.com/watch?v=dQw4w9WgXcQ)\\n\"}, \"label\": \"table_blurb\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"IntMetadataEntryData\", \"value\": 29119888133298982934829348}, \"label\": \"big_int\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"FloatMetadataEntryData\", \"value\": NaN}, \"label\": \"float_nan\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760032.954654, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:32.954654','many_table_materializations','[\"table_info\"]',NULL),(80,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"raw_group_admins\"}, \"label\": \"table_name\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/raw_group_admins\"}, \"label\": \"table_path\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"name\": \"raw_group_admins\"}}, \"label\": \"table_data\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"UrlMetadataEntryData\", \"url\": \"https://bigty.pe/raw_group_admins\"}, \"label\": \"table_name_big\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"MarkdownMetadataEntryData\", \"md_str\": \"# h1 Heading :)\\n\\n## h2 Heading\\n\\n### h3 Heading\\n\\n#### h4 Heading\\n\\n##### h5 Heading\\n\\n###### h6 Heading\\n\\n## Horizontal Rules\\n\\n---\\n\\n## Blockquotes\\n\\n> Blockquote can be nested\\n>\\n> > indentation by arrow level\\n\\n## Unordered lists\\n\\n- One\\n- Two\\n  - Indented\\n- Three\\n\\n## Ordered lists\\n\\n1. One\\n1. Two\\n1. Three\\n\\n## Code\\n\\nInline `code`\\n\\n    // comments\\n    line 1 of code\\n    line 2 of code\\n    line 3 of code\\n\\n## Links\\n\\n[rick roll](https://www.youtube.com/watch?v=dQw4w9WgXcQ)\\n\"}, \"label\": \"table_blurb\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"IntMetadataEntryData\", \"value\": 29119888133298982934829348}, \"label\": \"big_int\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"FloatMetadataEntryData\", \"value\": NaN}, \"label\": \"float_nan\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760033.020446, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:33.020446','many_table_materializations','[\"table_info\"]',NULL),(81,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - many_table_materializations - Solid many_table_materializations did not fire outputs {\'result\'}\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760033.087113, \"user_message\": \"Solid many_table_materializations did not fire outputs {\'result\'}\"}',NULL,'2022-02-02 08:00:33.087113','many_table_materializations',NULL,NULL),(82,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - many_table_materializations - Emitting implicit Nothing for output \\\"result\\\" on solid \\\"many_table_materializations\\\"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760033.1195421, \"user_message\": \"Emitting implicit Nothing for output \\\"result\\\" on solid \\\"many_table_materializations\\\"\"}',NULL,'2022-02-02 08:00:33.119542','many_table_materializations',NULL,NULL),(83,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"many_table_materializations\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Nothing\\\". (Type check passed).\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - STEP_OUTPUT - Yielded output \\\"result\\\" of type \\\"Nothing\\\". (Type check passed).\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760033.153107, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Nothing\\\". (Type check passed).\"}','STEP_OUTPUT','2022-02-02 08:00:33.153107','many_table_materializations',NULL,NULL),(84,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - many_table_materializations - Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/many_table_materializations/result\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760033.1866539, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/many_table_materializations/result\"}',NULL,'2022-02-02 08:00:33.186654','many_table_materializations',NULL,NULL),(85,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - HANDLED_OUTPUT - Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760033.219842, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-02-02 08:00:33.219842','many_table_materializations',NULL,NULL),(86,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 734.5096849999999}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_table_materializations\", \"step_key\": \"many_table_materializations\"}, \"message\": \"Finished execution of step \\\"many_table_materializations\\\" in 734ms.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_table_materializations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_table_materializations\", \"parent\": null}}, \"step_key\": \"many_table_materializations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_table_materializations - STEP_SUCCESS - Finished execution of step \\\"many_table_materializations\\\" in 734ms.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_table_materializations\", \"timestamp\": 1643760033.252609, \"user_message\": \"Finished execution of step \\\"many_table_materializations\\\" in 734ms.\"}','STEP_SUCCESS','2022-02-02 08:00:33.252609','many_table_materializations',NULL,NULL),(87,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"many_materializations_and_passing_expectations\", \"step_keys\": [\"many_materializations_and_passing_expectations\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Started capturing logs for step: many_materializations_and_passing_expectations.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - LOGS_CAPTURED - Started capturing logs for step: many_materializations_and_passing_expectations.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.315428, \"user_message\": \"Started capturing logs for step: many_materializations_and_passing_expectations.\"}','LOGS_CAPTURED','2022-02-02 08:00:33.315428','many_materializations_and_passing_expectations',NULL,NULL),(88,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Started execution of step \\\"many_materializations_and_passing_expectations\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - STEP_START - Started execution of step \\\"many_materializations_and_passing_expectations\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.352156, \"user_message\": \"Started execution of step \\\"many_materializations_and_passing_expectations\\\".\"}','STEP_START','2022-02-02 08:00:33.352156','many_materializations_and_passing_expectations',NULL,NULL),(89,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/users.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.386637, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:33.386637','many_materializations_and_passing_expectations','[\"table_info\"]',NULL),(90,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Row count passed for users\", \"label\": \"users.row_count\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Row count passed for users\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - STEP_EXPECTATION_RESULT - Row count passed for users\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.4540539, \"user_message\": \"Row count passed for users\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:33.454054','many_materializations_and_passing_expectations',NULL,NULL),(91,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/groups.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.487731, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:33.487731','many_materializations_and_passing_expectations','[\"table_info\"]',NULL),(92,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Row count passed for groups\", \"label\": \"groups.row_count\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Row count passed for groups\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - STEP_EXPECTATION_RESULT - Row count passed for groups\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.554719, \"user_message\": \"Row count passed for groups\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:33.554719','many_materializations_and_passing_expectations',NULL,NULL),(93,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/events.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.588015, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:33.588015','many_materializations_and_passing_expectations','[\"table_info\"]',NULL),(94,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Row count passed for events\", \"label\": \"events.row_count\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Row count passed for events\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - STEP_EXPECTATION_RESULT - Row count passed for events\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.653735, \"user_message\": \"Row count passed for events\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:33.653735','many_materializations_and_passing_expectations',NULL,NULL),(95,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/friends.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.6872902, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:33.687290','many_materializations_and_passing_expectations','[\"table_info\"]',NULL),(96,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Row count passed for friends\", \"label\": \"friends.row_count\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Row count passed for friends\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - STEP_EXPECTATION_RESULT - Row count passed for friends\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.75357, \"user_message\": \"Row count passed for friends\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:33.753570','many_materializations_and_passing_expectations',NULL,NULL),(97,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/pages.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.786426, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:33.786426','many_materializations_and_passing_expectations','[\"table_info\"]',NULL),(98,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Row count passed for pages\", \"label\": \"pages.row_count\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Row count passed for pages\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - STEP_EXPECTATION_RESULT - Row count passed for pages\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.855099, \"user_message\": \"Row count passed for pages\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:33.855099','many_materializations_and_passing_expectations',NULL,NULL),(99,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/fans.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.889305, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:33.889305','many_materializations_and_passing_expectations','[\"table_info\"]',NULL),(100,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Row count passed for fans\", \"label\": \"fans.row_count\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Row count passed for fans\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - STEP_EXPECTATION_RESULT - Row count passed for fans\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.956456, \"user_message\": \"Row count passed for fans\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:33.956456','many_materializations_and_passing_expectations',NULL,NULL),(101,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/event_admins.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760033.990211, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:33.990211','many_materializations_and_passing_expectations','[\"table_info\"]',NULL),(102,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Row count passed for event_admins\", \"label\": \"event_admins.row_count\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Row count passed for event_admins\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - STEP_EXPECTATION_RESULT - Row count passed for event_admins\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760034.0565271, \"user_message\": \"Row count passed for event_admins\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:34.056527','many_materializations_and_passing_expectations',NULL,NULL),(103,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepMaterializationData\", \"asset_lineage\": [], \"materialization\": {\"__class__\": \"AssetMaterialization\", \"asset_key\": {\"__class__\": \"AssetKey\", \"path\": [\"table_info\"]}, \"description\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"PathMetadataEntryData\", \"path\": \"/path/to/group_admins.raw\"}, \"label\": \"table_path\"}], \"partition\": null, \"tags\": {}}}, \"event_type_value\": \"ASSET_MATERIALIZATION\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Materialized value table_info.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - ASSET_MATERIALIZATION - Materialized value table_info.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760034.0896032, \"user_message\": \"Materialized value table_info.\"}','ASSET_MATERIALIZATION','2022-02-02 08:00:34.089603','many_materializations_and_passing_expectations','[\"table_info\"]',NULL),(104,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Row count passed for group_admins\", \"label\": \"group_admins.row_count\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Row count passed for group_admins\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - STEP_EXPECTATION_RESULT - Row count passed for group_admins\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760034.155489, \"user_message\": \"Row count passed for group_admins\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:34.155489','many_materializations_and_passing_expectations',NULL,NULL),(105,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - many_materializations_and_passing_expectations - Solid many_materializations_and_passing_expectations did not fire outputs {\'result\'}\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760034.1885738, \"user_message\": \"Solid many_materializations_and_passing_expectations did not fire outputs {\'result\'}\"}',NULL,'2022-02-02 08:00:34.188574','many_materializations_and_passing_expectations',NULL,NULL),(106,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 20, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - many_materializations_and_passing_expectations - Emitting implicit Nothing for output \\\"result\\\" on solid \\\"many_materializations_and_passing_expectations\\\"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760034.2212968, \"user_message\": \"Emitting implicit Nothing for output \\\"result\\\" on solid \\\"many_materializations_and_passing_expectations\\\"\"}',NULL,'2022-02-02 08:00:34.221297','many_materializations_and_passing_expectations',NULL,NULL),(107,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepOutputData\", \"metadata_entries\": [], \"step_output_handle\": {\"__class__\": \"StepOutputHandle\", \"mapping_key\": null, \"output_name\": \"result\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"type_check_data\": {\"__class__\": \"TypeCheckData\", \"description\": null, \"label\": \"result\", \"metadata_entries\": [], \"success\": true}, \"version\": null}, \"event_type_value\": \"STEP_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Yielded output \\\"result\\\" of type \\\"Nothing\\\". (Type check passed).\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - STEP_OUTPUT - Yielded output \\\"result\\\" of type \\\"Nothing\\\". (Type check passed).\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760034.255244, \"user_message\": \"Yielded output \\\"result\\\" of type \\\"Nothing\\\". (Type check passed).\"}','STEP_OUTPUT','2022-02-02 08:00:34.255244','many_materializations_and_passing_expectations',NULL,NULL),(108,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": null, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - many_materializations_and_passing_expectations - Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/many_materializations_and_passing_expectations/result\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760034.288604, \"user_message\": \"Writing file at: /Users/prha/dagster/storage/4b46487f-6f4b-4b78-b050-9a35fb29b0f7/many_materializations_and_passing_expectations/result\"}',NULL,'2022-02-02 08:00:34.288604','many_materializations_and_passing_expectations',NULL,NULL),(109,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"HandledOutputData\", \"manager_key\": \"io_manager\", \"metadata_entries\": [], \"output_name\": \"result\"}, \"event_type_value\": \"HANDLED_OUTPUT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - HANDLED_OUTPUT - Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760034.322401, \"user_message\": \"Handled output \\\"result\\\" using IO manager \\\"io_manager\\\"\"}','HANDLED_OUTPUT','2022-02-02 08:00:34.322401','many_materializations_and_passing_expectations',NULL,NULL),(110,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 969.0015509999998}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"many_materializations_and_passing_expectations\", \"step_key\": \"many_materializations_and_passing_expectations\"}, \"message\": \"Finished execution of step \\\"many_materializations_and_passing_expectations\\\" in 969ms.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"many_materializations_and_passing_expectations\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"many_materializations_and_passing_expectations\", \"parent\": null}}, \"step_key\": \"many_materializations_and_passing_expectations\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - many_materializations_and_passing_expectations - STEP_SUCCESS - Finished execution of step \\\"many_materializations_and_passing_expectations\\\" in 969ms.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"many_materializations_and_passing_expectations\", \"timestamp\": 1643760034.355242, \"user_message\": \"Finished execution of step \\\"many_materializations_and_passing_expectations\\\" in 969ms.\"}','STEP_SUCCESS','2022-02-02 08:00:34.355242','many_materializations_and_passing_expectations',NULL,NULL),(111,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"check_admins_both_succeed\", \"step_keys\": [\"check_admins_both_succeed\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"check_admins_both_succeed\", \"step_key\": \"check_admins_both_succeed\"}, \"message\": \"Started capturing logs for step: check_admins_both_succeed.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_admins_both_succeed\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"check_admins_both_succeed\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_admins_both_succeed\", \"parent\": null}}, \"step_key\": \"check_admins_both_succeed\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - check_admins_both_succeed - LOGS_CAPTURED - Started capturing logs for step: check_admins_both_succeed.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"check_admins_both_succeed\", \"timestamp\": 1643760034.407012, \"user_message\": \"Started capturing logs for step: check_admins_both_succeed.\"}','LOGS_CAPTURED','2022-02-02 08:00:34.407012','check_admins_both_succeed',NULL,NULL),(112,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"check_admins_both_succeed\", \"step_key\": \"check_admins_both_succeed\"}, \"message\": \"Started execution of step \\\"check_admins_both_succeed\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_admins_both_succeed\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"check_admins_both_succeed\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_admins_both_succeed\", \"parent\": null}}, \"step_key\": \"check_admins_both_succeed\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - check_admins_both_succeed - STEP_START - Started execution of step \\\"check_admins_both_succeed\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"check_admins_both_succeed\", \"timestamp\": 1643760034.445083, \"user_message\": \"Started execution of step \\\"check_admins_both_succeed\\\".\"}','STEP_START','2022-02-02 08:00:34.445083','check_admins_both_succeed',NULL,NULL),(113,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": null, \"label\": \"Group admins check out\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"check_admins_both_succeed\", \"step_key\": \"check_admins_both_succeed\"}, \"message\": \"Expectation Group admins check out passed\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_admins_both_succeed\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"check_admins_both_succeed\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_admins_both_succeed\", \"parent\": null}}, \"step_key\": \"check_admins_both_succeed\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - check_admins_both_succeed - STEP_EXPECTATION_RESULT - Expectation Group admins check out passed\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"check_admins_both_succeed\", \"timestamp\": 1643760034.479754, \"user_message\": \"Expectation Group admins check out passed\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:34.479754','check_admins_both_succeed',NULL,NULL),(114,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": null, \"label\": \"Event admins check out\", \"metadata_entries\": [], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"check_admins_both_succeed\", \"step_key\": \"check_admins_both_succeed\"}, \"message\": \"Expectation Event admins check out passed\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_admins_both_succeed\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"check_admins_both_succeed\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_admins_both_succeed\", \"parent\": null}}, \"step_key\": \"check_admins_both_succeed\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - check_admins_both_succeed - STEP_EXPECTATION_RESULT - Expectation Event admins check out passed\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"check_admins_both_succeed\", \"timestamp\": 1643760034.513525, \"user_message\": \"Expectation Event admins check out passed\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:34.513525','check_admins_both_succeed',NULL,NULL),(115,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 67.92961599999892}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"check_admins_both_succeed\", \"step_key\": \"check_admins_both_succeed\"}, \"message\": \"Finished execution of step \\\"check_admins_both_succeed\\\" in 67ms.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_admins_both_succeed\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"check_admins_both_succeed\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_admins_both_succeed\", \"parent\": null}}, \"step_key\": \"check_admins_both_succeed\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - check_admins_both_succeed - STEP_SUCCESS - Finished execution of step \\\"check_admins_both_succeed\\\" in 67ms.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"check_admins_both_succeed\", \"timestamp\": 1643760034.54737, \"user_message\": \"Finished execution of step \\\"check_admins_both_succeed\\\" in 67ms.\"}','STEP_SUCCESS','2022-02-02 08:00:34.547370','check_admins_both_succeed',NULL,NULL),(116,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"ComputeLogsCaptureData\", \"log_key\": \"check_users_and_groups_one_fails_one_succeeds\", \"step_keys\": [\"check_users_and_groups_one_fails_one_succeeds\"]}, \"event_type_value\": \"LOGS_CAPTURED\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"check_users_and_groups_one_fails_one_succeeds\", \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\"}, \"message\": \"Started capturing logs for step: check_users_and_groups_one_fails_one_succeeds.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_users_and_groups_one_fails_one_succeeds\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"check_users_and_groups_one_fails_one_succeeds\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_users_and_groups_one_fails_one_succeeds\", \"parent\": null}}, \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - check_users_and_groups_one_fails_one_succeeds - LOGS_CAPTURED - Started capturing logs for step: check_users_and_groups_one_fails_one_succeeds.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\", \"timestamp\": 1643760034.600946, \"user_message\": \"Started capturing logs for step: check_users_and_groups_one_fails_one_succeeds.\"}','LOGS_CAPTURED','2022-02-02 08:00:34.600946','check_users_and_groups_one_fails_one_succeeds',NULL,NULL),(117,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"STEP_START\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"check_users_and_groups_one_fails_one_succeeds\", \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\"}, \"message\": \"Started execution of step \\\"check_users_and_groups_one_fails_one_succeeds\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_users_and_groups_one_fails_one_succeeds\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"check_users_and_groups_one_fails_one_succeeds\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_users_and_groups_one_fails_one_succeeds\", \"parent\": null}}, \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - check_users_and_groups_one_fails_one_succeeds - STEP_START - Started execution of step \\\"check_users_and_groups_one_fails_one_succeeds\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\", \"timestamp\": 1643760034.639379, \"user_message\": \"Started execution of step \\\"check_users_and_groups_one_fails_one_succeeds\\\".\"}','STEP_START','2022-02-02 08:00:34.639379','check_users_and_groups_one_fails_one_succeeds',NULL,NULL),(118,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Battery of expectations for user\", \"label\": \"user_expectations\", \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"columns\": {\"name\": {\"average_length\": 3.394893, \"empty\": 0, \"nulls\": 0, \"values\": 123}, \"time_created\": {\"average\": 1231283, \"empty\": 2, \"nulls\": 1, \"values\": 120}}}}, \"label\": \"table_summary\"}], \"success\": true}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"check_users_and_groups_one_fails_one_succeeds\", \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\"}, \"message\": \"Battery of expectations for user\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_users_and_groups_one_fails_one_succeeds\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"check_users_and_groups_one_fails_one_succeeds\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_users_and_groups_one_fails_one_succeeds\", \"parent\": null}}, \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - check_users_and_groups_one_fails_one_succeeds - STEP_EXPECTATION_RESULT - Battery of expectations for user\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\", \"timestamp\": 1643760034.674027, \"user_message\": \"Battery of expectations for user\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:34.674027','check_users_and_groups_one_fails_one_succeeds',NULL,NULL),(119,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepExpectationResultData\", \"expectation_result\": {\"__class__\": \"ExpectationResult\", \"description\": \"Battery of expectations for groups\", \"label\": \"groups_expectations\", \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"JsonMetadataEntryData\", \"data\": {\"columns\": {\"name\": {\"average_length\": 3.394893, \"empty\": 0, \"nulls\": 1, \"values\": 122}, \"time_created\": {\"average\": 1231283, \"empty\": 2, \"nulls\": 1, \"values\": 120}}}}, \"label\": \"table_summary\"}], \"success\": false}}, \"event_type_value\": \"STEP_EXPECTATION_RESULT\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"check_users_and_groups_one_fails_one_succeeds\", \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\"}, \"message\": \"Battery of expectations for groups\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_users_and_groups_one_fails_one_succeeds\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"check_users_and_groups_one_fails_one_succeeds\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_users_and_groups_one_fails_one_succeeds\", \"parent\": null}}, \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - check_users_and_groups_one_fails_one_succeeds - STEP_EXPECTATION_RESULT - Battery of expectations for groups\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\", \"timestamp\": 1643760034.707816, \"user_message\": \"Battery of expectations for groups\"}','STEP_EXPECTATION_RESULT','2022-02-02 08:00:34.707816','check_users_and_groups_one_fails_one_succeeds',NULL,NULL),(120,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"StepSuccessData\", \"duration_ms\": 67.89423000000028}, \"event_type_value\": \"STEP_SUCCESS\", \"logging_tags\": {\"pipeline_name\": \"many_events\", \"pipeline_tags\": \"{\'.dagster/grpc_info\': \'{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\', \'dagster/solid_selection\': \'*\'}\", \"resource_fn_name\": \"None\", \"resource_name\": \"None\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_name\": \"check_users_and_groups_one_fails_one_succeeds\", \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\"}, \"message\": \"Finished execution of step \\\"check_users_and_groups_one_fails_one_succeeds\\\" in 67ms.\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_users_and_groups_one_fails_one_succeeds\", \"parent\": null}, \"step_handle\": {\"__class__\": \"StepHandle\", \"key\": \"check_users_and_groups_one_fails_one_succeeds\", \"solid_handle\": {\"__class__\": \"SolidHandle\", \"name\": \"check_users_and_groups_one_fails_one_succeeds\", \"parent\": null}}, \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\", \"step_kind_value\": \"COMPUTE\"}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - check_users_and_groups_one_fails_one_succeeds - STEP_SUCCESS - Finished execution of step \\\"check_users_and_groups_one_fails_one_succeeds\\\" in 67ms.\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": \"check_users_and_groups_one_fails_one_succeeds\", \"timestamp\": 1643760034.7415638, \"user_message\": \"Finished execution of step \\\"check_users_and_groups_one_fails_one_succeeds\\\" in 67ms.\"}','STEP_SUCCESS','2022-02-02 08:00:34.741564','check_users_and_groups_one_fails_one_succeeds',NULL,NULL),(121,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": [{\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"65443\"}, \"label\": \"pid\"}, {\"__class__\": \"EventMetadataEntry\", \"description\": null, \"entry_data\": {\"__class__\": \"TextMetadataEntryData\", \"text\": \"[\'raw_file_event_admins\', \'raw_file_events\', \'raw_file_fans\', \'raw_file_friends\', \'raw_file_group_admins\', \'raw_file_groups\', \'raw_file_pages\', \'raw_file_users\', \'many_table_materializations\', \'many_materializations_and_passing_expectations\', \'check_admins_both_succeed\', \'check_users_and_groups_one_fails_one_succeeds\']\"}, \"label\": \"step_keys\"}]}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Finished steps in process (pid: 65443) in 5.09s\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - ENGINE_EVENT - Finished steps in process (pid: 65443) in 5.09s\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": null, \"timestamp\": 1643760034.781069, \"user_message\": \"Finished steps in process (pid: 65443) in 5.09s\"}','ENGINE_EVENT','2022-02-02 08:00:34.781069',NULL,NULL,NULL),(122,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": null, \"event_type_value\": \"PIPELINE_SUCCESS\", \"logging_tags\": {}, \"message\": \"Finished execution of run for \\\"many_events\\\".\", \"pid\": 65443, \"pipeline_name\": \"many_events\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 10, \"message\": \"many_events - 4b46487f-6f4b-4b78-b050-9a35fb29b0f7 - 65443 - RUN_SUCCESS - Finished execution of run for \\\"many_events\\\".\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": null, \"timestamp\": 1643760034.8146088, \"user_message\": \"Finished execution of run for \\\"many_events\\\".\"}','PIPELINE_SUCCESS','2022-02-02 08:00:34.814609',NULL,NULL,NULL),(123,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','{\"__class__\": \"EventLogEntry\", \"dagster_event\": {\"__class__\": \"DagsterEvent\", \"event_specific_data\": {\"__class__\": \"EngineEventData\", \"error\": null, \"marker_end\": null, \"marker_start\": null, \"metadata_entries\": []}, \"event_type_value\": \"ENGINE_EVENT\", \"logging_tags\": {}, \"message\": \"Process for run exited (pid: 65443).\", \"pid\": null, \"pipeline_name\": \"many_events\", \"solid_handle\": null, \"step_handle\": null, \"step_key\": null, \"step_kind_value\": null}, \"error_info\": null, \"level\": 20, \"message\": \"Process for run exited (pid: 65443).\", \"pipeline_name\": \"many_events\", \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"step_key\": null, \"timestamp\": 1643760034.945476, \"user_message\": \"Process for run exited (pid: 65443).\"}','ENGINE_EVENT','2022-02-02 08:00:34.945476',NULL,NULL,NULL);
/*!40000 ALTER TABLE `event_logs` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `instance_info`
--

DROP TABLE IF EXISTS `instance_info`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `instance_info` (
  `run_storage_id` text
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `instance_info`
--

LOCK TABLES `instance_info` WRITE;
/*!40000 ALTER TABLE `instance_info` DISABLE KEYS */;
INSERT INTO `instance_info` VALUES ('146b2f8d-c180-490a-a830-be4d8714ea42');
/*!40000 ALTER TABLE `instance_info` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `job_ticks`
--

DROP TABLE IF EXISTS `job_ticks`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `job_ticks` (
  `id` int NOT NULL AUTO_INCREMENT,
  `job_origin_id` varchar(255) DEFAULT NULL,
  `status` varchar(63) DEFAULT NULL,
  `type` varchar(63) DEFAULT NULL,
  `timestamp` timestamp(6) NULL DEFAULT NULL,
  `tick_body` text,
  `create_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `update_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  PRIMARY KEY (`id`),
  KEY `idx_job_tick_timestamp` (`job_origin_id`,`timestamp`),
  KEY `idx_job_tick_status` (`job_origin_id`(32),`status`(32)),
  KEY `ix_job_ticks_job_origin_id` (`job_origin_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `job_ticks`
--

LOCK TABLES `job_ticks` WRITE;
/*!40000 ALTER TABLE `job_ticks` DISABLE KEYS */;
/*!40000 ALTER TABLE `job_ticks` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `jobs`
--

DROP TABLE IF EXISTS `jobs`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `jobs` (
  `id` int NOT NULL AUTO_INCREMENT,
  `job_origin_id` varchar(255) DEFAULT NULL,
  `repository_origin_id` varchar(255) DEFAULT NULL,
  `status` varchar(63) DEFAULT NULL,
  `job_type` varchar(63) DEFAULT NULL,
  `job_body` text,
  `create_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `update_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  PRIMARY KEY (`id`),
  UNIQUE KEY `job_origin_id` (`job_origin_id`),
  KEY `ix_jobs_job_type` (`job_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `jobs`
--

LOCK TABLES `jobs` WRITE;
/*!40000 ALTER TABLE `jobs` DISABLE KEYS */;
/*!40000 ALTER TABLE `jobs` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `run_tags`
--

DROP TABLE IF EXISTS `run_tags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `run_tags` (
  `id` int NOT NULL AUTO_INCREMENT,
  `run_id` varchar(255) DEFAULT NULL,
  `key` text,
  `value` text,
  PRIMARY KEY (`id`),
  KEY `run_id` (`run_id`),
  KEY `idx_run_tags` (`key`(64),`value`(64)),
  CONSTRAINT `run_tags_ibfk_1` FOREIGN KEY (`run_id`) REFERENCES `runs` (`run_id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `run_tags`
--

LOCK TABLES `run_tags` WRITE;
/*!40000 ALTER TABLE `run_tags` DISABLE KEYS */;
INSERT INTO `run_tags` VALUES (1,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','dagster/solid_selection','*'),(2,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','.dagster/grpc_info','{\"host\": \"localhost\", \"socket\": \"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\"}');
/*!40000 ALTER TABLE `run_tags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `runs`
--

DROP TABLE IF EXISTS `runs`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `runs` (
  `id` int NOT NULL AUTO_INCREMENT,
  `run_id` varchar(255) DEFAULT NULL,
  `snapshot_id` varchar(255) DEFAULT NULL,
  `pipeline_name` text,
  `mode` text,
  `status` varchar(63) DEFAULT NULL,
  `run_body` text,
  `partition` text,
  `partition_set` text,
  `create_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `update_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `start_time` float DEFAULT NULL,
  `end_time` float DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `run_id` (`run_id`),
  KEY `fk_runs_snapshot_id_snapshots_snapshot_id` (`snapshot_id`),
  KEY `idx_run_status` (`status`(32)),
  KEY `idx_run_range` (`status`(32),`update_timestamp`,`create_timestamp`),
  KEY `idx_run_partitions` (`partition_set`(64),`partition`(64)),
  CONSTRAINT `fk_runs_snapshot_id_snapshots_snapshot_id` FOREIGN KEY (`snapshot_id`) REFERENCES `snapshots` (`snapshot_id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `runs`
--

LOCK TABLES `runs` WRITE;
/*!40000 ALTER TABLE `runs` DISABLE KEYS */;
INSERT INTO `runs` VALUES (1,'4b46487f-6f4b-4b78-b050-9a35fb29b0f7','bc9e5b12d5a07c7a7f6e4a4ebf247a9b5824b51a','many_events',NULL,'SUCCESS','{\"__class__\": \"PipelineRun\", \"execution_plan_snapshot_id\": \"2bfd776d592b56a6090099f4aaa1d3aa3be33a07\", \"external_pipeline_origin\": {\"__class__\": \"ExternalPipelineOrigin\", \"external_repository_origin\": {\"__class__\": \"ExternalRepositoryOrigin\", \"repository_location_origin\": {\"__class__\": \"ManagedGrpcPythonEnvRepositoryLocationOrigin\", \"loadable_target_origin\": {\"__class__\": \"LoadableTargetOrigin\", \"attribute\": null, \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"module_name\": \"dagster_test.toys.repo\", \"package_name\": null, \"python_file\": null, \"working_directory\": null}, \"location_name\": \"dagster_test.toys.repo\"}, \"repository_name\": \"toys_repository\"}, \"pipeline_name\": \"many_events\"}, \"mode\": \"default\", \"parent_run_id\": null, \"pipeline_code_origin\": {\"__class__\": \"PipelinePythonOrigin\", \"pipeline_name\": \"many_events\", \"repository_origin\": {\"__class__\": \"RepositoryPythonOrigin\", \"code_pointer\": {\"__class__\": \"ModuleCodePointer\", \"fn_name\": \"toys_repository\", \"module\": \"dagster_test.toys.repo\", \"working_directory\": \"/Users/prha/code/dagster\"}, \"container_image\": null, \"entry_point\": [\"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\", \"-m\", \"dagster\"], \"executable_path\": \"/Users/prha/.pyenv/versions/3.8.7/envs/dagster-3.8.7/bin/python3.8\"}}, \"pipeline_name\": \"many_events\", \"pipeline_snapshot_id\": \"bc9e5b12d5a07c7a7f6e4a4ebf247a9b5824b51a\", \"root_run_id\": null, \"run_config\": {}, \"run_id\": \"4b46487f-6f4b-4b78-b050-9a35fb29b0f7\", \"solid_selection\": null, \"solids_to_execute\": null, \"status\": {\"__enum__\": \"PipelineRunStatus.SUCCESS\"}, \"step_keys_to_execute\": null, \"tags\": {\".dagster/grpc_info\": \"{\\\"host\\\": \\\"localhost\\\", \\\"socket\\\": \\\"/var/folders/ls/p35278613w573s8j1fn7_c4m0000gn/T/tmpu2sidx67\\\"}\", \"dagster/solid_selection\": \"*\"}}',NULL,NULL,'2022-02-01 16:00:26.167557','2022-02-02 00:00:34.911961',1643760000,1643760000);
/*!40000 ALTER TABLE `runs` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `secondary_indexes`
--

DROP TABLE IF EXISTS `secondary_indexes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `secondary_indexes` (
  `id` int NOT NULL AUTO_INCREMENT,
  `name` varchar(512) DEFAULT NULL,
  `create_timestamp` datetime(6) DEFAULT CURRENT_TIMESTAMP(6),
  `migration_completed` datetime(6) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `name` (`name`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `secondary_indexes`
--

LOCK TABLES `secondary_indexes` WRITE;
/*!40000 ALTER TABLE `secondary_indexes` DISABLE KEYS */;
INSERT INTO `secondary_indexes` VALUES (1,'run_partitions','2022-02-01 15:01:29.389515','2022-02-01 15:01:29.362464'),(2,'asset_key_table','2022-02-01 15:01:29.772084','2022-02-01 15:01:29.745994'),(3,'asset_key_index_columns','2022-02-01 15:01:29.861465','2022-02-01 15:01:29.834494');
/*!40000 ALTER TABLE `secondary_indexes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `snapshots`
--

DROP TABLE IF EXISTS `snapshots`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `snapshots` (
  `id` int NOT NULL AUTO_INCREMENT,
  `snapshot_id` varchar(255) NOT NULL,
  `snapshot_body` blob NOT NULL,
  `snapshot_type` varchar(63) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `snapshot_id` (`snapshot_id`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `snapshots`
--

LOCK TABLES `snapshots` WRITE;
/*!40000 ALTER TABLE `snapshots` DISABLE KEYS */;
INSERT INTO `snapshots` VALUES (1,'bc9e5b12d5a07c7a7f6e4a4ebf247a9b5824b51a',_binary 'x�\�][s���+\�<\�@H\�͛Mκ�\�ފ��6)JW�\rs�q֛\�?��\�X��1�\'U��D��\�Vw�\�|��!�I��\�\�\'k\�{4q��\�\�򻴘��&,Mdt\�\�NLI�7O~���\�}W��.��\�\'q6c\�\�!}���r��\�k���YI����eѬ�\�D5H\�q�n�d>\r\�I<�\�D\�W�o�{��	�\n=�~��Y�}q%�&�r����\�o\�.�;��\�\�\�$\�.\�;\n\�*���L\����\�\�gYF\�^ߑ�x.l8�!\0�c;q�rB}\\\�I�w\����\\Dya�\�\�\��^��\�5�\��^#\��x�\���\�I\�g=�\�i\Z\�\�|?\�Uo[\�oqi��\�wgg[\�\�\�lQ\���\�\�\�Ս\�qJ:\��\�L�^�\�\�\�z@6|��:�y�\�\���_�\�As5 \�/�\���DM쭆濮E,X�fo�@9>u\�{�I #�>s�\�0v��#\�\�uKt\0\�\�b�\�\��\�\�~\�\�\��I��)�Re�s\�M\\,\\\�\�\�\�,�^���\03H��\���@\��x�\�>�|vhڶ�\�y9E\� �v�\�&���\�2\�W=:�\��Q��\��6��S�%�\�\"��\�\��\r�[\� в&8�\���(\0\0b&�����m\�M�\��([��1q���n�\�\�0$��o\�\�\0\�6\�\�>\�P�H ��A?^�*\�<.\�Y�\�G\\h\�\�\\�<)GI���I��\�\�\�N��<\�\��\�QV&I�\�\�\Z_�G9��z\�\�AF\�\�r\�\�	�Bjs D��\�l\�l\"�2`v�\�9���\� S���\�\r.S�y\��\�\�U�?\�h�� \n ���@:5/\�rǱ]\�@D�+�mKu9*\�7�\���M��1�D\��\"*c,ic�SҐ{.\'\�%Цx�p�9@��$\�ǡ\�\\�mۧ:_\�I��i�	%.�\�W���W\�՟��\"J4YL\�y��`�\�b�\�YC!0�M8B\�D�`@�������u\Z�ͳL$��i��b\�TQ\�d��\�%�I�6+��y@\�DI\�K\�!�\�\ns=3�\�1\�\�]\�ZT=F;$ E.Uz!]\\\�\�6��\nE]\�\�]΂�\��Sq\�5�\�k�/�x�3+ۜ����U\�\�\�\�!T\�sI\'\�<�\�0�Y\�\��u\�\�y\�C\�\�3\'O�y\�\�at�\�\�\Z+\���҇P\�gNT��\�\�(羙��\'���H�Bk\�n\�\�\�Rh�T�-��1\�p\\Y\�v>�v\Z�\�W\��Rx\\r\�\�\�	 &�\�fj�\�\�v\0�\�\�e�(a}��6�֥H�\Z���C5K�8�z\�\�|\�\���*�$��-�/��\0\�\�ǈ�\�2$qD\�\�\��I�\�Q���t��\��\�n�ͫ|}/,\�\�vS \�|<w^�z\���\'���j� \��#�J,��z�\�(�Q\�#\�\�MAS�АGY�z�\�3&\��M\�n\�\�\�@�0\�R�P;>����}H\�{\�\�q\�\�dg\�\�\��\�\�էI\�ͱ8�\rcq/\��c�M�ONn\�Bd��/�\�8\����ե�P\�s<�&�Tk&\�Gx��\�s 9v]֣:��7\��\�ۺ\rx\�ޯ�Ruo���;�\�Kמ7����\n�\�>��aW�L\�j\�-L\�Q��\�\�~P�\�\�\�Ƃs��\n��\0�AW�\�8\�Š�v�,��#c	S\��\�\� 1lpO��\'�\�,=��=�\�Tx�	�1($<s\�\nNSV\�u�\�(y�Q\�(\�7�\��\�b6/�\�\�z}�hwc`\��ˁ�\n����-�`\�ǃ\�GB�@�\�^�]۪�$\���E�K\�θi\�*\�\��Ξ�v]&\�\�\�׳�!\�KGE8�ؓ�/1�\��C\�y�H\0w$`\� �6WY�	J\�u�k5ŭ5�\'lob\�EG\�6a�\�\�.\�H�\�+jc0`̈\��)�c~п\�?\r�$!�b;i�_�acq$�6�� \��!\�\0��\�gS\�0\�\�\r#\�yT\�	�#Ob\'\�\�羊�d\�wmI�#��kC�\�\0�6z6�t\'ؗ�\�i�\�!M��0�3&�>\�4\�1\�7�\�d\�\�\�$<�\�\��,\�D��Dq\��z�\�a�\�P+\�Z��E\n��ݷb\�L��b�P�=SN\\\�\�\�r�\�k\�^\�t3\�5����P6��\��}�\�I�`�/{���pJ\�X&]��̱\\{^�BV�싞\�L��/{��\�\�\�\Z\�n�q�L\�1XR\�	D|\����S\�2|\�<o�\�\�G\\|Z9�\�iY!\�`\�\�&�\�>�`�\n�����\"� \"d3`ے\"�\��t%p���\�l\�$\�25W\'o\�\�}��\�yY�\�uƇi�n\�3>�\�j��\�k�0q\�m�\�j�_{H�l\�\�\�w=n{��ƶە�\�\�d\�A\�z\�\��\\[\��|�\���_�r���ː��?\�2djAƔO��A��\�K\�\�GCP�����0>\ZhL�0�\�}a\Z`\��x\�G\�;��������<sr��\�t�=OR\�l��\�c�)o~R\�lǇn�wt�\�a|��\�iNTu\�a9��V>#L\���_���˦�\��\rj\��+\�\��\�YL6p@Y\n:�\�\"J��j���K+o]��8%\\\�_�\"\�S>G\\:�\�\�\�\�\�\�Ƽ[P�\���Ln\�\��\�\'\�o�y\��s� ��\��f�]�\�8\�/\��e\�\��\���\��\'\">��\�@\�\�\�e}\�\�\��I����\�\�C1�<\�\�\�K��z%}Y\����+��Dpyu\�k\�U�ɠ&���u�*�8\�\�\�e\�r\�\���G\\�� \�)��\�\�t[�P9;b�C�9+\�\�NG\�D\�E\���֫.N�\��\�>ee֧\Z�%��\�\r\�\�\ZG\�l^�%1\�u�*\�:.�+\�\Z\�\�\�݈�\�+\�<\\��\�35c�xQU\�w�\�|�+Ix�\0c\�e�s��=��.����d6[\�\�U��x\�β�urvW\�(\�Wa\�V\�\�$�Kk���6	\�S\�s�\�2�^\"ܿ\�\�I0;	q{\�v���\�\�f\�g���*�aF�j�\\\0\r\�\�,e@\�,^\�ۘt񙛲C����\�Y�g\"����(�� �)�ۥLc sY\�\���\Z��\�k&�>�%x�.j\�v�/# tQ\Z�\��X#\�\�\��Ԅ\n���5�\�\�*\�Ha=��%\�Y��\�\r\�m�%\�z�t�>��N�\�\"q�\�Z_�\�N\r\"�{�E\�<�d�Ms���SQN\nR���Ģ\�\"EAT���\"ս�o5���\�m�;Kæ)URX���lO\�Eٳ˫�M5�Eȝi���h\�0e����M̰*ӽ&\�W�m\�\�(x\�\����[u5�U\��\�\�\�v�A\�47\���]S��S`\�F\�&�\�=��\�\�-��l\�Ҵh~��_yΚ�6\�waԢ$�\�\�\�^iJY6]M\�t:K\�P�`a&\�,k\�\�\��g<zdS\�ά��\��k�O�2\�J\�\�3�sQR��\�8�Y���WG\�Kk��_��\�߉�*x_C\�\�`�l��aZ�0�\���}B\�&\�X���\�\�w��ʼ݈бGr\�����r+��\�X��\Z)+\0��\�cn}Uޚ��\�;-I+���՝o`D� UXb\Z�+�\'\nA\nJeR�\�$�ӗX9yP��S���\���ڹ�8K(�����F\� ؚ\�y\"\�ˈbE�;O6��G\�O\n\�B\\���bY�[\r�e�N�%\�\�fiµ6\�@l\�\�l\�	�?<2ϓ���)�a�#o��]\\k\�[�Y\�\�\�t\��V�\��\�*�:S��\�T]#w\�\�\�\�t`$�0\��0�\���fsᄟ׃�j�\�pZ\���P\�jP��sv0(mnǝ\�\��\�t`$�0\��0Tn9B�\r\��^\r�\�4����,x9*+#���-#(\�','PIPELINE'),(2,'2bfd776d592b56a6090099f4aaa1d3aa3be33a07',_binary 'x�\�]o\�0��\n\�5Blj)\��!\Z�4�B�\�&��\�\�	��Q��w\�\�I��	u�8�n�}�^?9I�\�\�C\�1\�y\�^x׿�O�\�]�\�=\�	_\�\�{�\�\�L�9\�G	0N��@�,9	�U\�\�(7���\�>p�l	%�\��h�HX�E4\rC9��BBq\r\�ٛ�W0�]\\c�z\�O\�d�Fx��\�h��f㷗�\���\0�\�\�-�\��B\rH\�\n\��\�9��?<�ќ��\��@8�\�2�Oԇ\�xg͜�A}l�\�49\�0��%x\���\��\�H�\�\Z	<�c�T�I\�\�o�\���ޝ@�\�\'\�.d�	���\�\�t^h�%\�\�\�\�r2�9\�sE1UE�0�K�\�\�T+˕�O\r�\�\�\n�|��T�u\�g��0	\�B�`H�P;�V�Y\�\�\�t��D�et\�8e�\Zډ\�őr~�\n\�]�����d�CEv\�ǐh)\���W��\�ɭ|ZUN0�Li\�7�q�Ys�2�*Z��D\�q������\"<\r\�B\�E�F\r�٨,%	��\�\�\�as�n�ڸu#V�Zi�iT%�EN��p{s\��۵�j�@\�\0���(+yZ�_~\�&E\��\�\�Y�m�]�wL5}��t\�rT�\�w\�\�yl\�t]`�.`�9�:�AJ�v��\�J��\�\�wϥ�4<�\�C��5s\�;\�mP\�bR]�!\�\�\�[� �؍Z\�U�ϲp\�Al#\�Q��މ_d\�3%l��P���a�%%����MCG6\�kޒO�1�D�^S����$��l\r/3\�7��\�w]�ƾ-w}\���\��\�Ι\�ܜb\r�\�$\'\�\�\�\�<\'\�\���N�\�5\�Ot�b�a\�3\�d\�?�p�w\�J�\�o��?{�\�󓃭x\�m\�V�\�e+�n�\�\�˺�\�\�+����Q\��g���;��zsl\�o=xivr\�)K�\��+=\��d\�\�\�\'<\�\�\�\���w��ǁ\�hn�t��>\�\�c\�@\0��n\'\�v��P�\�x9L�bZ\�niav���>\�\�\�\���P��VʛBZY�\�閗�\n\�\�\�\�\�:d�\"�+�!��\�g��\�Ϻ��\�<�\'�\�	�]\�j\�\�\��S����bZڝAi壗:g����c\�*���vg0Z�襄\Z�\�\�\n\�\�','EXECUTION_PLAN');
/*!40000 ALTER TABLE `snapshots` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2022-02-01 16:01:32
